!---------------------------------------------------------------!
!   Library Name: ConZon  for AJAX				!
!   Writen by: H.E. Willoughby, AOML/HRD       			!
!   Latest update:	24MAR95		By:	HEW		!
!   Function: Generates a constant zonal environmental flow 
!   for use in vortex motion simulations			!
!---------------------------------------------------------------!

	subroutine ReadEnv
!---------------------------------------------------------------!
!  Reads environmental flow parameters from file "conzon.dat"   !
!---------------------------------------------------------------!
        parameter (IzMx=2)
	common /EnvCOM/Uenv(IzMx),UenvMx(IzMx),Tenv,EnvID 
        common /RUDID/RunID,FloID
        character EnvID*12
        call OpenEnv
	read(4,'(A12)')EnvID
	read(4,*) Uenv
	read(4,*) Tenv
        UenvMx(1) = Uenv(1)
        UenvMx(2) = Uenv(2)
        close(4)
!---------------------------------------------------------------!
!                 VARIABLE DICTIONARY: ReadEnv			!
!  EnvID	String identifying environmetal flow		!
!  Uenv		Zonal componet of constant flow			!
!  Tenv         Time period to ramp zonal flow up to Uenv       ! 
!---------------------------------------------------------------!
	return
	end

	subroutine ShoEnv(IsEnv,NLU)
!---------------------------------------------------------------!
!  Displays environmental flow parameters on file designated by !
!  NLU								!
!---------------------------------------------------------------!
	parameter (IzMx=2,sqr2=1.414)
	common /EnvCOM/Uenv(IzMx),UenvMx(IzMx),Tenv,EnvID 
	character*12 EnvID
	logical IsEnv
	if (IsEnv)then
	  write(NLU,'('' Environmental flow ID: '',A12)')EnvID
	  write(NLU,'('' Environmental zonal flow: '',2(f6.2,1x))')
     1                   UenvMx
	  write(NLU,'('' Ramp period for Uenv: '',f6.2,'' h'')')Tenv
	endif
	return
	end	  


	subroutine MakEnv(IsEnv,TIMEh,XCen,XCen0,FCor0,FCor,BRos,Rho,
     2                    C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,IsNL)
!-----------------------------------------------------------------------!
!  Generates constant environmental flow if IsEnv is .T.		!
!  All other parameters are included for consistency with more 		!
!  complicated environmental flows and are set to zero			!
!-----------------------------------------------------------------------!  
        complex eye
        parameter (IzMx=2,IrMain=2001, eye=(0.0,1.0),Gee=9.8)
	parameter (sqr2=1.414,NX=3,NX1=NX+1,NMode=3)
	common /EnvCOM/Uenv(IzMx),UenvMx(IzMx),Tenv,EnvID 
        common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx),
     1          VMaxR(IzMx),aLAT,DEPTH(IzMx)
	character*12 EnvID
        save IsFirst
	logical IsEnv,IsNL, IsFirst
	complex CEnvL(NMode,IzMx,0:IrMain),CEnvR(NMode,IzMx,0:IrMain),
     1          HEnv(NMode,IzMx,0:IrMain)
        complex dHdy,d2Hdy2,CCen,CEnv
	real XCen(IzMx,2),XCen0(2),H0Env(IzMx,0:IrMain),dHdy1(IzMx),
     1       C0Env(IzMx,0:IrMain),HSym(IzMx),Rho(IzMx+1),dHdy2(IzMx)
        data IsFirst/.TRUE./

        if(IsFirst)then
          write(6,'('' Zeroing Environment'')')
         do Iz = 1,IzMx
          HSym(Iz) = DEPTH(Iz)
          do Ir = 1, IrMain  
	    C0Env(Iz,Ir) = 0.0
            do N = 1, NMode
	     CEnvL(N,Iz,Ir) = (0.0,0.0)
             CEnvR(N,Iz,Ir) = (0.0,0.0)
            enddo
            H0Env(Iz,Ir)   = 0.0
            do N = 1, NMode
            HEnv(N,Iz,Ir)  = (0.0,0.0)
            enddo
          enddo   !Ir
         enddo   !Iz
        endif

c do only if flow is switched on
	if (IsEnv)then
c Compute Uenv from UenvMx
        do Iz = 1,IzMx
          TFac = 1.0
          If(Tenv .gt. 0.0) then
            TFac = TIMEh/Tenv
          endif          
          If(TFac .lt. 1.0) then
            Uenv(Iz) = UenvMx(Iz)*TFac
          else
            Uenv(Iz) = UenvMx(Iz)
          endif
        enddo

c Loop over layers
         do Iz = 1,IzMx
          HafZ0Env=0.0
	  CEnv = -cmplx(Uenv(Iz),0.0)
          if(Iz .eq. 1) then
            dHdy1(Iz) = -FCor/gee*(Rho(1)*Uenv(1) - Rho(2)*Uenv(2))/
     1                 (Rho(1) - Rho(2))
          else
            dHdy1(Iz) = -dHdy1(1) - FCor/gee*Rho(2)*Uenv(2)/
     1                 (Rho(2) - Rho(3))
          endif
          dHdy = cmplx(dHdy1(Iz),0.0)

         if(IsNL) then
          d2Hdy2 = -BRos*Uenv(Iz)/Gee
         endif
c above is one layer d2Hdy2 below may be the correct 2 layer version??
c          if(Iz .eq. 1) then
c            d2Hdy2 = -BRos/Gee*(Rho(1)*Uenv(1) - Rho(2)*Uenv(2))/
c     1              (Rho(1) - Rho(2))
c          else
c            d2Hdy2 = -d2Hdy2 -BRos/gee*Rho(2)*Uenv(2)/(Rho(2) - Rho(3))
c          endif

          Ym = 1000.0*(XCen(1,2)-XCen0(2))
          if(BRos .gt. 0.0) then
           if(FCor .eq. FCor0) Ym = 0.0   !Zero depth change when IsFt false
          endif    ! this corrects for f plane case
          if(Iz .eq. 1) then
            dHdy2(Iz) = -(FCor0 + 0.5*BRos*Ym)*Ym/gee*(Rho(1)*Uenv(1) -
     1                   Rho(2)*Uenv(2))/(Rho(1) - Rho(2))
          else
            dHdy2(Iz) = -dHdy2(1) - (FCor0 + 0.5*BRos*Ym)*Ym/gee*
     1                   Rho(2)*Uenv(2)/(Rho(2) - Rho(3))
          endif
          HSym(Iz) = DEPTH(Iz) + dHdy2(Iz)

c set uniform flow
          do Ir=0,IrMain
            rm = RADIUS(Ir)
	    CEnvR(1,Iz,Ir) = eye*CEnv
            CEnvL(1,Iz,Ir) = CEnv
            H0Env(Iz,Ir)   = 0.25*rm*rm*d2Hdy2
            HEnv(1,Iz,Ir)  = rm*dHdy
            HEnv(2,Iz,Ir)  = cmplx(H0Env(Iz,Ir),0.0)
          enddo    !Ir
         enddo    !Iz
        endif  
        IsFirst=.FALSE.
	return
	end
