	program TrakGraf
!---------------------------------------------------------------!
!	Program name: TRAKGRAF 					!
!	Written by: H.E. WIlloughby AOML/HRD			!
!	Latest update:	21JUL94	by:	HEW			!
!	Function: Uses trakXXX.out file to plot storm track	!
!	plus up to 4 reference tracks. Optionally makes a second!
!	plot of the primary track's direction and speed		!
!---------------------------------------------------------------!
	parameter (ItMax=115200)
	real*4 T(8,0:ItMax),X(8,0:ItMax),Y(8,0:ItMax),CX(0:ItMax),
     1         CY(0:ItMax)
	character IDString(8)*20,FDate(8)*9,FTime(8)*8,
     1            TITLE*25,TITLE1*30,TITLE2*25,IDif(8)*6
        integer*4  NPos(8),ItStart(8),ItEnd(8),NSym(8),LURay(8)
	logical IPort,ITrak1,IsVel,IsDif
        data LURay/5,3,7,8,9,10,11,12/

c Read set-up from file trakXXX.set
        call GetParms(NPos,ItStart,ItEnd,
     1          NSym,XMin,XInt,XMax,YMin,YInt,YMax,
     2          XRat,CInt,CMax,TInt,TRat,TITLE,TITLE1,TITLE2,IPort,
     3          NTrak,IsVel,IsDif)


c Loop over trak files
        KTrak = max(NTrak,1)
        do k = 1, KTrak
c Read track data
 	  call ReadTrak(NPos,T,X,Y,CX,CY,k,
     1               IDString,FDate,FTime,IDif,IsDif,LURay(k))

c Show file identification and data every 6 hours
	  write(6,'(1x,A20,1x,A8,1x,A9,1x,A6)')
     1                    IDString(k),FTime(k),FDate(k),IDif(k)

	  do It = ItStart(k), ItEnd(k),720
	    write(6,22)It,T(k,It),X(k,It),Y(k,It),CX(It),CY(It)
	  enddo
        enddo


c Plot 
        call TrakPlot(T,X,Y,CX,CY,TITLE,TITLE1,TITLE2,
     1               IDString,FDate,FTime,IDif,
     2               XMin,XInt,XMax,YMin,YInt,YMax,
     3               XRat,CInt,CMax,TInt,TRat,
     4               ItStart,ItEnd,NSym,IPort,NTrak,IsVel)

 22	format(1x,i5,5(1x,g10.3))

        CALL GCLOSE

	stop
	end

	subroutine ReadTrak(NPos,T,X,Y,CX,CY,k,
     1               IDString,FDate,FTime,IDif,IsDif,LU)
	parameter (ItMax=115200)
	real*4 T(8,0:ItMax),X(8,0:ItMax),Y(8,0:ItMax),CX(0:ItMax),
     1         CY(0:ItMax)
	real*4 T1(0:ItMax),X1(0:ItMax),Y1(0:ItMax),CX1(0:ItMax),
     1         CY1(0:ItMax)
	character IDString(8)*20,FDate(8)*9,FTime(8)*8,
     1            Stringer*60,IDif(8)*6
        integer*4 NPos(8)
        logical IsDif

        write(6,'('' Reading LU '',I2)')LU
c End of loop less than array dimension
	NPos(k) = MIN(NPos(k),ItMax)

c FInd marker for start of data
	read(LU,'(a60)',end=98)Stringer
	IdxStr = index(Stringer,'##########')
	do while(IdxStr .eq. 0)
	   read(LU,'(a60)',end=98)Stringer
	   IdxStr = index(Stringer,'##########')
	enddo

c Read date/time stamps and run ID
	read(LU,'(1x,A20,1x,A8,1x,A9,1x,A6)')IDString(K),FTime(K),
     1                                       FDate(K),IDif(K)

c Read data
	do It = 0, NPos(k)
          NLast = It
	  read(LU,*,end=98)NN,T(k,It),NN,X(k,It),Y(k,It),
     1                        CX(It),CY(It)
	  read(LU,*,end=98)NN,T1(It),NN,X1(It),Y1(It),
     1                        CX1(It),CY1(It)
	enddo

 98	NPos(k) = MIN(NPos(k),NLast)

        if(IsDif)then
          do It = 0, NPos(k)
            X(k,It) = X1(It) - X(k,It)
            Y(k,It) = Y1(It) - Y(k,It)
          enddo
        endif

	return 
	end
     
      subroutine TrakPlot(T,X,Y,CX,CY,TITLE,TITLE1,TITLE2,
     1              IDString,FDate,FTime,IDif,
     2              XMin,XInt,XMax,YMin,YInt,YMax,
     3              XRat,CInt,CMax,TInt,TRat,
     4              ItStart,ItEnd,NSym,IPort,NTrak,IsVel)
      parameter (ItMax=115200)
      real*4 T(8,0:ItMax),X(8,0:ItMax),Y(8,0:ItMax),CX(0:ItMax),
     1       CY(0:ItMax),ARay(0:ItMax),TRay(0:ItMax),
     3       XDum(0:ItMax),YDum(0:ItMax),ALineW(8)
      character IDString(8)*20,FDate(8)*9,FTime(8)*8,TITLE*25,
     1          TITLE1*30,TITLE2*25,CBuffer*21,IDif(8)*6
      integer*4 ItStart(8),ItEnd(8),NSym(8),KLineSt(8),KSymSt(8)
      PARAMETER(HafCSz=2.0,VSmCSz=1.5*HafCSz,SmCSz=2.*HafCSz)
      PARAMETER (BgCSz=3.0*HafCSz)
      PARAMETER(XLong=20.,XShort=35.)
      logical IPort,IsVel,IBreak
      data KLineSt/0,1,5,10,3,7,8,9/
      data KSymSt/-768,-850,-840,-856,-854,-852,-830,-820/
      data ALineW/0.5,1.0,0.5,0.5,1.0,0.5,0.5,0.5/

c Activeate graphics
      CALL groute('select hposta; ex')

      CALL GOPEN
      if(IPort)then
        call rorien(2)
      else
        call rorien(1)
      endif
      call grpsiz(XXMax,YYMax)
      CALL GPRINT( 0 )

C Assign locations for components of graf
      YTop = YYMax - 9.0*HafCSz
      YLR = YTop + HafCSz
      XCtr = XXMax/2. 
      if(IPort)then
        XLft=XShort
        XRt =  XXMax - 4.0*HafCSz
        XWide = XRt - XLft
        YHi = XWide*(YMax-YMin)/(XRat*(XMax-XMin))
        YBot = YTop - YHi
      else
        YBot = XShort
        YHi = YTop - YBot
        XWide = YHi*XRat*(XMax-XMin)/(YMax-YMin)
        XLft = 0.5*(XXMax-XWide)
        XRt = XXMax - XLft
      endif 

c Select character font
      call rtxesc(-5,' ')
      call rtxfon('COMP',1)


c Plot track?
      if(NTrak.ne.0)then
        CALL GSEGCR( 1 )

C Plot headers on graph
        CALL GCHARJ( 7 )
        CALL GCHAR( TITLE, XCtr, YYMax-HafCSz, BgCSz)
        CALL GCHARJ( 0 )
        CALL GCHAR( 'Time: $' , XLft, YLR, SmCSz )
        call gnumb(T(3,ItStart(3)),9999.,9999.,SmCSz,0)
        call gchar(' to $',9999.,9999.,SmCSz)     
        Tmmax = 0
       do i = 1,NTrak
        if(T(i,ItEnd(i)) .gt. Tmmax)Tmmax = T(i,ItEnd(i))
       enddo
        call gnumb(Tmmax,9999.,9999.,SmCSz,0)
        call gchar(' h$',9999.,9999.,SmCSz)     
        CALL GCHARJ( 2 )
        NSymInt = (T(1,ItEnd(1)) - T(1,ItStart(1)))/
     1     (ItEnd(1) - ItStart(1))*NSym(1)
        Write(CBuffer,'(''NSym ='',I3,'' h$'')')NSymInt
        CALL GCHAR( CBuffer, XRt, YLR, SmCSz )
c        CALL GCHAR( TITLE2, XRt, YLR, SmCSz )

C Turn on full display of error messages
        CALL GSHMES( 'DIS', 'DIS' )

C Set where you want graph to be on plot
        CALL BGRAF( XLft, YBot, XWide, YHi)

C Set up X-Axis
        call bloglb(1.0,2,1)
        CALL BAXLAB( SmCSz, SmCSz, 0, 0 )
        CALL BAXIS( 1, XMin, XInt, XMax, 'X  (km)$' )

C Set up Y-Axis

        call bloglb(1.0,2,1)
        CALL BAXLAB( SmCSz, SmCSz, 0, 0 )
        CALL BAXIS( 2, YMin, YInt, YMax , 'Y (km)$' )    
 
c Loop over tracks
        do k = 1, NTrak
C Set up line characteristics
          CALL BLIWDH( ALineW(k) )
          CALL BDASH( KLineSt(k) )
          call gcharj(4)
          call bmarkh(SmCSz)
          call bmark(KSymSt(k),NSym(k))

c Move primary track into dummy arrays
          call MovRays(X,Y,XDum,YDum,k,ItStart(k),ItEnd(k),Kount)

C Plot Track

          CALL BLINE( XDum, YDum, Kount )
        enddo

c Plot more lables
        CBuffer = IDString(1)//'$'
        call GCHARJ(0)
        call GCHAR(TITLE2,0.0,HafCsz,VSmCSz)


        CBuffer = FTime(1)//' '//FDate(1)//'$'
        call GCHARJ(2)
        call GCHAR(CBuffer,XRt,HafCSz,VSmCSz)

        CBuffer = IDif(1)//'$'
        If(NTrak.gt.1) CBuffer = IDif(1)//' '//IDif(2)//'$'
        CALL GCHARJ(1)
        CALL GCHAR( TITLE1, XCtr, HafCSz, VSmCSz)

c Close trak plot segment
        CALL GSEGCL( 1 )
        call gclose
      endif 


c Plotting speed and direction of primary track?
      if(IsVel)then
         
c Activeate graphics
      CALL groute('select hposta; ex')

      CALL GOPEN
      call rorien(1)
      call grpsiz(XXMax,YYMax)

c Open speed and direction plot segment
        CALL GSEGCR( 2 )

C Assign locations for components of graf

        YBot=  XShort
        YHi = YYMax - 2*YBot
        XWide = TRat*YHi
        XLft = 0.5*(XXMax-XWide)
        XRt =  XLft + XWide 
        YTop = YBot + YHi
        YLR = YTop + HafCSz
        XCtr = XXMax/2.
        YHed = YLR + 1.5*BgCSz

c Select character font
       call rtxesc(-5,' ')
       call rtxfon('COMP',1)


C Plot headers on graph

        CALL GCHARJ( 1 )
        CALL GCHAR( TITLE, XCtr, YHed, BgCSz)
        CALL GCHARJ( 0 )

        CALL GCHARJ( 0 )
        CALL GCHAR( 'Time: $' , XLft, YLR, SmCSz )
        call gnumb(T(1,ItStart(1)),9999.,9999.,SmCSz,0)
        call gchar(' to $',9999.,9999.,SmCSz)     
        call gnumb(T(1,ItEnd(1)),9999.,9999.,SmCSz,0)
        call gchar(' h$',9999.,9999.,SmCSz)     

        CALL GCHARJ( 2 )
        CALL GCHAR( TITLE2, XRt, YLR, SmCSz )

C Set where you want graph to be on plot
        CALL BGRAF( XLft, YBot, XWide, YHi)

C Set up t-Axis
        CALL BAXLAB( SmCSz, SmCSz, 0, 0 )
        Tstart = ANINT(T(1,ItStart(1)))
        Tend = ANINT(T(1,ItEnd(1)))
        CALL BAXIS( 1, Tstart, TInt, Tend, 't (hr) $' )

C Set up speed-axis
        CALL BAXLAB( SmCSz, SmCSz, 0, 0 )
        CALL BAXIS( 2, 0.0, CInt, CMax , '^223C^223 (ms>->1)$' )

C Set up line characteristics
        CALL BLIWDH( 0.5 )
        CALL BDASH( 0 )

C Plot speed and direction vs. t

c Calculate speed and move time to dummy arrays
        Kount = 0
        do Ir = ItStart(1), ItEnd(1)
          XDum(Kount) = T(1,Ir)
          YDum(Kount) = sqrt(CX(Ir)**2 + CY(Ir)**2)
          Kount = Kount + 1
        enddo

c Plot speed
        CALL BLINE(XDum,YDum,Kount)

C Set up direction-Axis
        call baxori(XRt,YBot)
        call BAXLAB(SmCSz,SmCSz, 0, 0 )
        CALL BAXIS( -2, 0.0,45.0,360.0, '^2137<C (deg)$' )

C Plot direction vs. T
        k = -1
        do Ir = ItStart(1), ItEnd(1)
          if((Cx(Ir).ne.0.0).and.(Cy(Ir).ne.0.0))then
            k = k + 1
            ARay(k) = 57.296 * atan2(CX(Ir),CY(Ir))
            TRay(k) = T(1,Ir)
          endif
          if(ARay(k).lt.0.0)ARay(k)=360.+ARay(k)
          if(k.gt.1)then
            IBreak = (ARay(k).gt.345.).and.(ARay(k-1).lt.15.)
     1         .or.(ARay(k).lt.15.).and.(ARay(k-1).gt.345.)
     2         .or.(Ir.eq.ItEnd(1))
          else
            IBreak = .false.
          endif
          if(IBreak)then
            CALL BLIWDH( 1.0 )
            CALL BDASH( 1 )
            CALL BLINE( TRay, ARay, k )
            k = -1
          endif
        enddo


        CBuffer = IDString(1)//'$'
        call GCHARJ(0)
        call GCHAR(CBuffer,XLft,HafCsz,VSmCSz)
        CBuffer = FTime(1)//' '//FDate(1)//'$'
        call GCHARJ(2)
        call GCHAR(CBuffer,XRt,HafCSz,VSmCSz)
        CBuffer = IDif(1)//'$'
        CALL GCHARJ(1)
        CALL GCHAR( CBuffer, XCtr, HafCSz, VSmCSz)
        CALL GSEGCL( 2 )
      endif
      RETURN
      END


        subroutine GetParms(NPos,ItStart,ItEnd,
     1              NSym,XMin,XInt,XMax,YMin,YInt,YMax,
     2              XRat,CInt,CMax,TInt,TRat,TITLE,TITLE1,TITLE2,
     3              IPort,NTrak,IsVel,IsDif)
	character TITLE*25,TITLE1*30,TITLE2*25
        integer NPos(8),ItStart(8),ItEnd(8),NSym(8)
	logical IPort,IsVel,IsDif
	read(4,*)IPort,NTrak,IsVel,IsDif
	read(4,'(A25)')TITLE
	read(4,'(A25)')TITLE2
	read(4,'(A30)')TITLE1
        KTrak = max(NTrak,1)
        do K = 1, KTrak
	  read(4,*)ItFirst,ItBegin,ItLast,NSym(k)
          NPos(k) = ItLast-ItFirst
          ItStart(k) = ItBegin - ItFirst
          ItEnd(k) = NPos(k)
        enddo
	read(4,*)XMin,XInt,XMax
	read(4,*)YMin,YInt,YMax,XRat
	read(4,*)CInt,CMax
	read(4,*)TInt,TRat
	return
	end

        subroutine MovRays(X,Y,XDum,YDum,K,ItFirst,ItLast,Kount)
        parameter (ItMax=115200)
        real*4 X(8,0:ItMax),Y(8,0:ItMax),XDum(0:ItMax),YDum(0:ItMax)
        Kount=0
        do It = ItFirst,ItLast
          XDum(Kount)=X(K,It)
          YDum(Kount)=Y(K,It)
          Kount=Kount+1
        enddo
        return
        end
