*************************************************************************
*       FixSol has all wavenumber corrections added 12/15/97            *
*	PROGRAM NAME: AJAX						*
*	WRITTEN BY:	HUGH WILLOUGHBY, HRD/AOML			*
*	LATEST UPDATE:	11Nov09 	BY:	RWJ			*
*	(Improved wave-wave algorithm, environmental 			*
*        representation)						*
*	FUNCTION: Prognostic, 2-mode vortex motion model with diagnostic*
*	mean axisymmetric vortex.					*
*************************************************************************
	Program AJAX
	parameter (IzMx=2,IrMain=1001,IRVor=125,NX=2,NMode=3)
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         XRay(IzMx,2,0:NX),DXCen(IzMx,2),XCen(IzMx,2),XCen0(2),
     2         H0Env(IzMx,0:IrMain),C0Env(IzMx,0:IrMain),HSym(IzMx),
     3         Cgr(IzMx),Rho(IzMx+1),QDuff(IzMx,0:IrMain)
	logical IsBeta,IsEnv,IsNL,IsQn,IsRead,IsShoVor,IsDyMo,IsIC
     1          ,IsVORt,IsFt,IsGau,IsDNM,IsApp,IsRNK,IsMRnK
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1       HA(NMode,3,IzMx,0:IrMain),YA(IzMx,0:IrVor),AlfaCen(IzMx),
     2       CEnvL(NMode,IzMx,0:IrMain),CEnvR(NMode,IzMx,0:IrMain),
     3       CCenR(NMode,IzMx),CCenL(NMode,IzMx),
     4       HEnv(NMode,IzMx,0:IrMain),CCen(IzMx),
     5       Y0IC,H0IC,ROIC,WIC,RxIC


c Recover run specification form runstring
        call GetRun

c Read parameters from ajaxXXX.dat
	call ReadSet(Njts,XRay,XCen,IsDyMo,FCor0,FCor,XCen0,BRos,Cgr
     1       ,Rho,AK,FAK,TIMEh,Ijts0,NSho,NBeg,IsBeta,IsEnv,IsQn,IsRead
     2       ,IsShoVor,IsIC,IsNL,IsVORt,IsFt,IsGau,IsDNM,TDNM,IsRNK
     3       ,IsMRnK,Y0IC,H0IC,R0IC,WIC,RxIC)


        IsApp = IsRead.and.(.not.IsIC)

c Set initial positions. Lower vortex starts at zero
        XCen(1,1) = 0.0
        XCen(1,2) = 0.0
        XCen0(1) = 0.0
        XCen0(2) = 0.0
        XCen(2,1) = XRay(2,1,0)
        XCen(2,2) = XRay(2,2,0)

c Change function RADIUS to do computes in meters 
        call RFix  !dr to meters

c compute environmental flow parameters. 
        call MakEnv(IsEnv,TIMEh,XCen,XCen0,FCor,FCor0,BRos,Rho,
     2                C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,IsNL)

        call RUnFix  !dr to kilometers to compute vortex
c Set up mean vortex
	call VorSet(U0,V0,H0,Rho,FCor0,HSym,IsRead,IsGau,IsRNK,IsMRnK)

c Change function RADIUS to do computes in meters 
        call RFix  !dr to meters

c Initialize: sets UA,VA, and HA to zero and sets I1,I2,I3,IS1,IS2,IS3
	call InitSol(UA,VA,HA,U0,V0,H0,XRay,I1,I2,I3,
     1              IS1,IS2,IS3,
     2              FCor,FCor0,TIMEh,Ijts0,IsRead,
     3              IsIC,Y0IC,H0IC,R0IC,WIC,RxIC)

c Set up alpha gyre for displaced upper vortex 
        AlfaCen(2) = 1000*cmplx(XCen(2,1),XCen(2,2))
        DXCen(2,1) = XCen(2,1) - XCen(1,1)
        DXcen(2,2) = XCen(2,2) - XCen(1,2)

c Add alpha gyre to upper layer for displaced upper vortex
	  call FixVor(UA,VA,HA,I1,I2,I3,IS3,AlfaCen,U0,V0,H0,Cgr,
     1                                 FCor,IsDyMo,IsNL)


c Record parameters on "AJAX.log"
        call ShoSet(6,FCor0,BRos,Cgr,Rho,AK,FAK,Njts,IsDyMo,IsBeta
     1               ,IsEnv,IsQn,IsNL,IsVORt,IsFt,IsDNM,TDNM
     2               ,XCen,IsIC,Y0IC,H0IC,R0IC,WIC,RxIC)

c Record parameters on "setXXX.out"
        call OpenOut(10,'SET ',.FALSE.)
	call ShoSet(10,FCor0,BRos,Cgr,Rho,AK,FAK,Njts,IsDyMo,IsBeta
     1                 ,IsEnv,IsQn,IsNL,IsVORt,IsFt,IsDNM,TDNM
     2                 ,XCen,IsIC,Y0IC,H0IC,R0IC,WIC,RxIC)


        if(IsApp)then

c Lable restarts with original ID and date/time stamps
          call ShoFlag(6)
          write(6,'(''                  ###### RESTART ######'')')
	  write(6,'(1x,10(''######''))')
          call ShoFlag(10)
          write(10,'(''                 ###### RESTART ######'')')
	  write(10,'(1x,10(''######''))')
        else

c Record vortex setup on log file
	 call ShoVor(6,U0,V0,H0,UA,VA,HA,IS2,AK,FAK,
     1                 .FALSE.,IsGau,IsRNK,IsMRnK)

c Record vortex setup on setXXX.out
	 call ShoVor(10,U0,V0,H0,UA,VA,HA,IS2,AK,FAK,
     1                 .FALSE.,IsGau,IsRNK,IsMRnK)

        endif

c Record initial vortex structure or setup on vortXXX.out 
        if(.not.IsApp)then
          call OpenOut(29,'VORT ',.FALSE.)
	  call ShoVor(29,U0,V0,H0,UA,VA,HA,IS2,AK,FAK,
     1                 IsShoVor,IsGau,IsRNK,IsMRnK)
          close (29)
        endif

c Open and write header on diagXXX.out file
        call OpenOut(9,'DIAG ',IsApp)

c Open and write header on enerXXX.out and enegXXX file
        call OpenOut(20,'ENER ',IsApp)
        call OpenOut(21,'ENEG ',IsApp)

c Open and write header on trakXXX.out file
        call OpenOut(7,'TRAK ',IsApp)

c Open and initialize UVHXXX.out files
        call OpenUVH(.TRUE.,IsApp)

c Record initial timestep on AJAX.log, setXXX, and TrakXXX
        if(.not.IsApp)then

	  call ShoStep(UA,VA,HA,U0,V0,H0,I1,I2,I3,IS2,IS3,Ijts0,Ijts0
     1               ,NSho,NBeg,TIMEh,FCOR,BROS,XRay,DXCen,
     2                XCen,CCenL,CCenR,QDuff,
     3                C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,
     4                AK,FAK,IsEnv,IsQn,IsIC,IsVORt,IsFt)

        endif

c Close setup file
        close (10)

c Loop over major time steps
	do Ijts = Ijts0+1, Ijts0+Njts

c Extrapolate storm track
	  call TrakX(XRay,TIMEh,IsDyMo,Ijts0,Ijts)

c Compute new motion and environmental flow
          call MakXC(.TRUE.,XRay,XCen,CCenL,CCenR)
          call MakEnv(IsEnv,TIMEh,XCen,XCen0,FCor0,FCor,BRos,Rho,
     2                C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,IsNL)

c March solutions forward
	  call March(UA,VA,HA,QDuff,I1,I2,I3,U0,V0,H0,IS1,IS2,IS3,
     1         FCor,FCor0,XCen0,BRos,Cgr,Rho,AK,FAK,Ijts,
     2         XCen,CCenL,CCenR,
     3         C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,
     4         IsQn,IsEnv,IsNL,IsVORt,IsFt,IsDNM,TDNM,TIMEh)

c Calculate wavenumber one streamfunction
	  call Fish1(UA,VA,I3,YA,Ijts,NSho,TIMEh)

c Find corrected center position
	  call FindCen(YA,V0,IS3,AlfaCen,DXCen)

c Print streamfunction for track
c	  call ShoDiag(29,YA,Ijts,NSho,TIMEh)

c Find corrected track
	  call NewTrak(XRay,DXCen,XCen,IsDyMo)

c Correct solution to new track
	  call FixSol(UA,VA,HA,I1,I2,I3,IS3,AlfaCen,U0,V0,H0,
     1                                 FCor,IsDyMo,IsNL)


c Record current time step on "AJAX.log","trackXXX.out","uvhXXX.out"
	  call ShoStep(UA,VA,HA,U0,V0,H0,I1,I2,I3,IS2,IS3,Ijts,Ijts0
     1                 ,NSho,NBeg,TIMEh,FCOR,BROS,XRay,DXCen,
     2                  XCen,CCenL,CCenR,QDuff,
     3                  C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,
     4                  AK,FAK,IsEnv,IsQn,IsIC,IsVORt,IsFt)
	enddo   !Ijts

c Record maximum amplitudes on "setXXX.out"
        call OpenOut(10,'SET ',.TRUE.) 
	call Finis(10,XCen,CCenL)
        close (10)

c Record maximum amplitudes on "AJAX.log" 
	call Finis(6,XCen,CCenL)

c Close remaining files
        close (7)
        close (9)
        close (20)
        close (21)

!---------------------------------------------------------------!
!               VARIABLE DICTIONARY MAIN PROGRAM		!
!								!
!  AK       	Diffusion constant				!
!  AlfaCen	Complex center position error (XError,YError)	!
!  BRos 	Rossby parameter				!
!  Cgr		Shallow-water gravity wave speed		!
!  DxCen	Array center postion error 1 is X, 2 is Y       !
!  FCor		Coriolis parameter				!
!  H0		Array of mean flow depth			!
!  H0IC		Amplitude of IC cartoon depth perturbation 	!
!  HA		Complex array of perturbation depths		!
!  I1,I2,I3     Indices of time levels for leap frog differencing
!  Ijts		Counter for loop over major time steps		!
!  Ijts0	Number of initial time step			!
!  IsBeta       TRUE means beta effect active			!
!  IsDymo       TRUE means dynamic centering active             !
!  IsEnv        TRUE means environmental flow active            !
!  IsNL         TRUE means nonlinear terms are active		!
!  IsIC         TRUE means initial condition active             !
!  IsQn         TRUE means mass source-sink active		!
!  IsRead       TRUE means read IC from file (not implemented)  !
!  IsShoVor     TRUE means mean vortex written to diagnostic file
!  IsDNM        TRUE means dampling active on highest mode      !
!  Njts		Number of major time steps simulated            !
!  NSho		Number of major time steps between output to    !
!		"uvhXXX.out" file				!
!  Rho          Density                                         !
!  ROIC		Radius of max streamfunction and depth in IC 	!
!		cartoons					!
!  RxIC		Exponential decay constant in outer tail of IC	!
!  SV02		Summed squares of mean-flow winds		!
!  TIMEh	Simulated time in hours				!
!  TDNM         Time constant for highest mode damping in days  !
!  UA		Complex array of perturbation radial wind	!
!  V0		Array of mean flow swirling wind		!
!  VA		Complex array of perturbation tangential wind	!
!  WIC		Nominal width of quadratic transition in IC 	!
!		cartoons 					!
!  XRay		Coefficient array for extrapolated track	!
!  Y0IC		Amplitude of IC cartoon streamfunction		!
!  YA		Complex array of wavenumber-one streamfunction  !
!---------------------------------------------------------------!
	Stop
	End

	subroutine ShoFlag(NLU)
!-----------------------------------------------------------!
! Writes a header of ############## plus ID strings and     !
! date time stamp on the logical unit NLU                   !
!-----------------------------------------------------------!
        COMMON /STAMP/ FDATE,FTIME,IDString,IDif
        CHARACTER FDATE*9,FTIME*8,IDString*20,IDif*6
	write(NLU,'(1x,10(''######''))')
	write(NLU,'(1x,A20,1x,A8,1x,A9,1x,A6)')IDSTRING,FTIME,
     1                                         FDATE,IDif
	return
	end

	subroutine InitSol(UA,VA,HA,U0,V0,H0,XRay,I1,I2,I3,
     1                    IS1,IS2,IS3,
     1                    FCor,FCor0,TIMEh,Ijts0,IsRead,
     2                    IsIC,Y0IC,H0IC,R0IC,WIC,RxIC)
!-----------------------------------------------------------!
! Initializes perturbation variables. IF IsIC=.T. makes  a  !
! cartoon of the normal mode solutions, ELSE initializes    !
! the variables to zero                                     !
!-----------------------------------------------------------!
	parameter (IzMx=2,IrMain=1001,IrFirst=2,IrLast=IrMain-1,
     1             NMode=3,eps=1.0e-08,ItRead=12,Nx=2)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1          HA(NMode,3,IzMx,0:IrMain),Y0IC,H0IC,YIC(0:IrMain),eye
        real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     2         XRay(IzMx,2,0:NX)
        logical IsIC,IsRead,IsBad
        parameter (eye=(0.0,1.0))
        character StartNam*55

c Generate dr and 2*dr in meters
        drm = RADIUS(4) - RADIUS(3)
        twodrm = 2.0*drm

c set Iz to 1 to avoid vertical do loops where not presently needed
          Iz = 1

c Set Coriolis parameter to initial value
          FCor = FCor0

c Decide between zero IC or cartoons of normal modes-one layer-not used
          if(IsIC) then

c Make normal-mode depth 
            call MakYIC(YIC,H0IC,R0IC,WIC,RxIC)

c Loop over radii, put normal mode depth in perturbation depth array
            do Ir = 0, IrMain
              HA(1,1,Iz,Ir) = YIC(Ir)
            enddo

c Make normal mode streamfunction
            call MakYIC(YIC,Y0IC,R0IC,WIC,RxIC)

c Loop over radii, put nm wind components in perturbation arrays
            do Ir = 1, IrLast
              UA(1,1,Iz,Ir) = eye*YIC(Ir)/RADIUS(Ir)
              VA(1,1,Iz,Ir) = (YIC(Ir+1)-YIC(Ir-1))/twodrm
            enddo

c Tidey up boundary conditions
            UA(1,1,Iz,0) = UA(1,1,Iz,1)
            UA(1,1,Iz,IrMain) = eye*YIC(IrMain)/RADIUS(IrMain)
            VA(1,1,Iz,0) = VA(1,1,Iz,1)
            VA(1,1,Iz,IrMain) = (YIC(IrMain)-YIC(IrLast))/drm

c Move initial fields to other time levels
            do It = 2,3
              do Ir = 0, IrMain 
	        VA(1,It,Iz,Ir)=VA(1,1,Iz,Ir)
	        UA(1,It,Iz,Ir)=UA(1,1,Iz,Ir)
	        HA(1,It,Iz,Ir)=HA(1,1,Iz,Ir)
              enddo
            enddo

c Zero other wave numbers
            do N = 2,NMode
              do It = 1,3
	        do Ir = 0, IrMain
	          VA(N,It,Iz,Ir)=(0.0,0.0)
	          UA(N,It,Iz,Ir)=(0.0,0.0)
	          HA(N,It,Iz,Ir)=(0.0,0.0)
                enddo
              enddo
	    enddo

c ELSE branch of IF statement, initial uvh equal to ZERO
          else

c Loop over radii and time levels, put in zeros
            do N = 1,3
              do It = 1,3
                do Iz = 1,IzMx
	          do Ir = 0, IrMain
	            VA(N,It,Iz,Ir)=(0.0,0.0)
	            UA(N,It,Iz,Ir)=(0.0,0.0)
	            HA(N,It,Iz,Ir)=(0.0,0.0)
                  enddo
                enddo
              enddo
	    enddo

          endif

c Initialize indices for leap frog time levels
          I1 = 1
          I2 = 2
          I3 = 3
          IS1= 1
          IS2= 2
          IS3= 3
	return
!---------------------------------------------------------------!
!                 VARIABLE DICTIONARY: INITSOL			!
!  drm	Radial grid interval  in meters				!
!  In	Index of time levles					!
!  Ir   Index of radial grid intervals				!
!  IsIC	TRUE means IC derives from cartoons			!
!       FALSE means IC is all zeros				!
!  								!
!  <<<<<<<<<<<See MAIN dictionary for other variables>>>>>>>>>> !
!---------------------------------------------------------------!
	end


       subroutine MakYIC(YIC,Y0IC,R0IC,WIC,RxIC)
!-----------------------------------------------------------!
! Genrates radial structure for cartoons of normal mode     !
! depth and streamfunction. Cartoons increase linearly from !
! r=0 to R2, have a quadratic transition between r=R2  and  !
! r=R3. If RxIC is zero the cartoon is zero beyond R2, but  !
! if RxIC is nonzero the cartoon's structure decays with    !
! e-folding distance RxIC beyond R2.                        !
!-----------------------------------------------------------! 

       parameter (IzMx=2,IrMain=1001)
       real*4 ROIC,WIC,RxIC
       complex*8 YIC(0:IrMain),Y0IC,A,B
       logical IsTail
       parameter (eps=1.0e-03)

c Calculate inner transition radius
       R2 = sqrt(R0IC*R0IC - WIC*WIC)

c Calculate value at inner transition radius
       A = Y0IC*(1.0 - ((R2 - R0IC)/WIC)**2)/R2

c Nonzero decay rate implies an outer tail
       IsTail = (RxIC.gt.eps)

       if(IsTail)then

c Tail exists: calculate outer transition and value there
         R3 = R0IC + sqrt(RxIC*RxIC + WIC*WIC) - RxIC
         B = Y0IC*(1.0 - ((R3 - R0IC)/WIC)**2)
       else

c No tail, calculate outer radius beyond which value is zero
         R3 = R0IC + WIC
         B =  (0.0,0.0)
       endif

c Center value is zero
       YIC(0) = (0.0,0.0)

c Loop over radii to calculate values
       do Ir = 1,IrMain
         R = RADIUS(Ir)

c Inner region, values increase linearly
         if(R.LT.R2)then
           YIC(Ir) = A*R

c Transiton region, quadratic variation 
         else if(R.LT.R3)then
           YIC(Ir) = Y0IC*(1.0 - ((R - R0IC)/WIC)**2)

c Outer region
         else

c Exponential decay with radius
           if (IsTail)then
             YIC(Ir) = B*exp(-(R-R3)/RxIC)

c OR zero outside
           else
             YIC(Ir) = 0.0
           endif
         endif
       enddo
       return
!---------------------------------------------------------------!
!              VARIABLE DICTIONARY: MAKYIC                      !
!								!
!  A 		Amplitude at inner joining radius		!
!  B    	Amplitude at outer joining radius		!
!  IsTail	TRUE means cartoon has an outer exponential tail!
!  R0IC		Radius of maximum streamfunction or height	!
!  R2		Inner transition radius				!
!  R3		Outer transition radius				!
!  RxIC		Exponential decay beyond R3			!
!		Width of quadratic transition zone around max.	!
!  YIC		Complex array of initial streamfunction or height
!								!
! <<<<See MAIN and INITSOL DICTIONARIES FOR OTHER VARAIBLES>>>> !
!---------------------------------------------------------------!
       end

	subroutine SyMar(UA,VA,HA,I1,I2,I3,U0,V0,H0,QDuff,
     1         IS1,IS2,IS3,CCenL,CCenR,CEnvL,CEnvR,HEnv,
     2         FCor,BRos,HSym,H0Env,Cgr,Rho,AK,FAK,
     3         IsQn,IsEnv,IsNL,IsVORt,IsFt,IsDNM,TDNM,TIMEh)
!--------------------------------------------------------------!
! Marches axisymmetric swirling wind forward one major time    !
! step and diagnoses axisymmetric radial wind and geopotential !
! at the IS2 level.					       !
!--------------------------------------------------------------!

	parameter (IzMx=2,IrMain=1001,IrLast=IrMain-1,NMode=3
     1              ,NX=2,Parm=0.10,Parm0=1.0-2.0*Parm
     2              ,Gee=9.8,GeeHaf=0.5/Gee)
	parameter (rmEnv=20.25e06)
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         QMass(IzMx,0:IrMain),QLr(IzMx,0:IrMain),
     2         QDuFF(IzMx,0:IrMain),
     3         A(IzMx,0:IrMain),B(IzMx,0:IrMain),C(IzMx,0:IrMain),
     4         RO2I(IzMx,0:IrMain),F(IzMx,0:IrMain),F0(IzMx,0:IrMain),
     5         ALPHA(IzMx,0:IrMain),BETA(IzMx,0:IrMain),
     6         DEN(IzMx,0:IrMain),E0(IzMx,0:IrMain),Z0(IzMx,0:IrMain),
     7         XRay(IzMx,2,0:NX),XCen(IzMx,2),H0Env(IzMx,0:IrMain),
     8         HSym(IzMx),Cgr(IzMx),Rho(IzMx+1),AK0(IzMx,0:IrMain)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain)
     1           ,HA(NMode,3,IzMx,0:IrMain),CCen(IzMx),eye,Qn(IzMx)
     3           ,Faze(IzMx,NMode),HBarP(IzMx),HBar0(IzMx)
     4           ,HBarM(IzMx),HEnv(NMode,IzMx,0:IrMain)
     5           ,CEnvR(NMode,IzMx,0:IrMain),CEnvL(NMode,IzMx,0:IrMain)
     6           ,UPr,VPrP,VPrM,UPrP,UPrM,UAbP,UAbM
     7           ,CCenR(NMode,IzMx),CCenL(NMode,IzMx)
     8           ,UPrM1,UPrP1,VPrM1,VPrP1,UPrM2,UPrP2,VPrM2,VPrP2
     9           ,UPrM3,UPrP3,VPrM3,VPrP3,HP,HM
        real*8 TempAc
        parameter (eye=(0.0,1.0),VORMAX=2.5e-4)
 	logical IsEnv,IsNL,IsQn,Qon,IsVORt,IsFt,IsDNM
        logical DoEnv
 	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
        common /Diags/QDbeta(IzMx,0:IrMain),QDuaha(IzMx,0:IrMain)
     1           ,QDmix(IzMx,0:IrMain),QDuvh(IzMx,0:IrMain)
     2           ,QDsym(IzMx,0:IrMain),QDfcor(IzMx,0:IrMain)
     3           ,QDuf(IzMx,0:IrMain),QDHsym(IzMx,0:IrMain)
     4           ,QDuv(IzMx,0:IrMain),QDuvhs(IzMx,0:IrMain)
     5           ,QDuvor(IzMx,0:IrMain),QDuvoh(IzMx,0:IrMain)
     6           ,DEN3(IzMx,0:IrMain)
        common /ExMix/Amix,Smix,Incr

        if(.not.IsVORt)RETURN

        do Iz = 1,2
        do Ir = 0,IrMain
          AK0(Iz,Ir) = FAK*AK
        enddo
        enddo

c Compute maximun wind radius and wind for upper and lower vortices
        do Iz = 1,2
          drk = drm/1000.
          RMaxW = RMWR(Iz)
          if(RMW(Iz) .gt. RMWR(Iz)) RMaxW = RMW(Iz)
          IRMW = RMaxW/drk

c need loop to seek final RMW, below is just one step
          IPM = 0
          if(V0(IS2,Iz,IRMW-1) .gt. V0(IS2,Iz,IRMW)) IPM = -1
          if(V0(IS2,Iz,IRMW+1) .gt. V0(IS2,Iz,IRMW)) IPM = 1
          IRMW = IRMW + IPM
          RMWR(Iz) = Radius(IRMW)/1000.
          VMaxR(Iz) = V0(IS2,Iz,IRMW)
          Ir = IRMW
c      write(9,11)IPM,V0(IS2,Iz,Ir),V0(IS2,Iz,Ir+1),V0(IS2,Iz,Ir-1)
        enddo

        do Iz = 1,2
          LpIndx = RMWR(Iz)/drk
          LpIndx = LpIndx - Incr
        do i = 1,LpIndx
          AK0(Iz,i) = Smix*AK0(Iz,i)
        enddo
          AK0(Iz,LpIndx+1) = Smix*.8*AK0(Iz,LpIndx+1)
          AK0(Iz,LpIndx+2) = Smix*.6*AK0(Iz,LpIndx+2)
          AK0(Iz,LpIndx+3) = Smix*.4*AK0(Iz,LpIndx+3)
          AK0(Iz,LpIndx+4) = Smix*.2*AK0(Iz,LpIndx+4)
        enddo

        do Iz = 1,2
        do i = 1,1
          AK0(Iz,i) = AK0(Iz,i)*4.
        enddo
        enddo
        do Iz =1,2
          AK0(Iz,2) = AK0(Iz,2)*3.
          AK0(Iz,3) = AK0(Iz,3)*2.
          AK0(Iz,4) = AK0(Iz,4)*1.
        enddo

        twodtj = twodts*Nnts

c Set indices of time levels: Initial level is I1, derivatives
c plus radial flow and geopotential are calcualted (mostly) at I2,
c and predicted values are stored at I3

        call SwapI(IS1,IS2,IS3)

c Set up sigma's
        Sig11 = (Rho(1) - Rho(2))/Rho(1)
        Sig12 = (Rho(2) - Rho(3))/Rho(1)
        Sig22 = (Rho(2) - Rho(3))/Rho(2)

c Calculating depth from gradient wind realtion
c Set depth and height gradaient at vortex boundary

       do Iz = IzMx,1,-1
c Initialize height gradaient, depth at vortex boundary, and
c sum of squares of swirling wind
	rm = RADIUS(IrMain)
	GradO = V0(IS2,Iz,IrMain)*(V0(IS2,Iz,IrMain)/rm + FCor)
        if(Iz .eq. 2) then
	  H0(Iz,IrMain) = HSym(2) + HSym(1)
        else
	  H0(Iz,IrMain) = HSym(1)
        endif

c Loop inward over grid points to calculate mean height, assuming
c gradient balance, and sum of squares of swirling wind
	do Ir = IrMain - 1, 1, -1
	  rm = RADIUS(Ir)
	  GradN = V0(IS2,Iz,Ir)*(V0(IS2,Iz,Ir)/rm + FCor)
          if(Iz .eq.2) then
	    H0(Iz,Ir) = H0(Iz,Ir+1) - GeeHaf*drm*(GradO + GradN)/Sig22
          else
  	    H0(Iz,Ir) = H0(Iz,Ir+1) - GeeHaf*drm*(GradO + GradN)/Sig11
     1                + (H0(2,Ir+1) - H0(2,Ir))*Sig12/Sig11
          endif
	  GradO = GradN
	enddo    !Ir

c Mean-flow height at vortex center
        if(Iz .eq. 2) then
	  H0(Iz,0) = H0(Iz,1) - GeeHaf*drm*GradO/Sig22
        else
	  H0(Iz,0) = H0(Iz,1) - GeeHaf*drm*GradO/Sig11
     1               + (H0(2,1) - H0(2,0))*Sig12/Sig11
        endif

c calculate h2 from h1+h2 and h1
        if(Iz .eq. 1)then
         do Ir = 0,IrMain
          H0(2,Ir) = H0(2,Ir) - H0(1,Ir) 
         enddo
        endif
       enddo     ! end Iz loop for balanced H0's

c Begin Iz loop to compute forcing for U0 and V0
       do Iz = 1,IzMx
          do Ir = 1, IrLast

c Calculate radius in meters
            rm = RADIUS(Ir)
	    DoEnv = IsEnv.and.(rm.lt.rmEnv)
c Calculate  mass source sink at this radius
            call MakQnR(N,Qn,rm,Faze,Qon)

c Calculate  indices and radii of nearby grid points
            Irp = Ir + 1
            Irm = Ir - 1
            rmi = 1.0/rm
            rmi2 = rmi*rmi
            rmp = rm + drm
            rmm = rm - drm
            rmp2= rmp*rmp
            rmm2= rmm*rmm
            DENI  = 1.0/(rm*twodrm) 
            DEN2I = DENI/(rm*H0(Iz,Ir))

c Initilize mass and momentum forcings
            QMass(Iz,Ir) = 0.0
            QDuf(Iz,Ir) = 0.0
            QDsym(Iz,Ir) = 0.0
            QDfcor(Iz,Ir) = 0.0
            QDHsym(Iz,Ir) = 0.0
            QDuv(Iz,Ir) = 0.0
            QDuvhs(Iz,Ir)= 0.0
            QDuvor(Iz,Ir) = 0.0
            QDuvoh(Iz,Ir) = 0.0
            TempAc = 0.0            
            do N2 = 2, NMode
              N1=N2-1
              TempAc=TempAc+real(UA(N2,I2,Iz,Ir) *conjg(HA(N1,I2,Iz,Ir))
     1                   + conjg(UA(N1,I2,Iz,Ir))*      HA(N2,I2,Iz,Ir))
            enddo
            QDuFF(Iz,Ir)=-0.5*BRos*rm*(real(UA(1,I2,Iz,Ir))+0.5*
     1                     TempAc/H0(Iz,Ir))

            QDbeta(Iz,Ir)=-0.5*BRos*rm*(real(UA(1,I2,Iz,Ir)))
            QDuaha(Iz,Ir)=-0.25*BRos*rm*TempAc/H0(Iz,Ir)

            TempAc = 0.0
            do N1 = 2,NMode
              UPrP1 = UA(N1,I2,Iz,Irp)-CCenR(N1,1)+CEnvR(N1,Iz,Irp)
              UPrM1 = UA(N1,I2,Iz,Irm)-CCenR(N1,1)+CEnvR(N1,Iz,Irm)
              VPrP1 = VA(N1,I2,Iz,Irp)-CCenL(N1,1)+CEnvL(N1,Iz,Irp)
              VPrM1 = VA(N1,I2,Iz,Irm)-CCenL(N1,1)+CEnvL(N1,Iz,Irm)
              do N2 = 1,N1-1
                UPrP2 = UA(N2,I2,Iz,Irp)-CCenR(N2,1)+CEnvR(N2,Iz,Irp)
                UPrM2 = UA(N2,I2,Iz,Irm)-CCenR(N2,1)+CEnvR(N2,Iz,Irm)
                VPrP2 = VA(N2,I2,Iz,Irp)-CCenL(N2,1)+CEnvL(N2,Iz,Irp)
                VPrM2 = VA(N2,I2,Iz,Irm)-CCenL(N2,1)+CEnvL(N2,Iz,Irm)
                N3 = N1-N2
                UPrP3 = UA(N3,I2,Iz,Irp)-CCenR(N3,1)+CEnvR(N3,Iz,Irp)
                UPrM3 = UA(N3,I2,Iz,Irm)-CCenR(N3,1)+CEnvR(N3,Iz,Irm)
                VPrP3 = VA(N3,I2,Iz,Irp)-CCenL(N3,1)+CEnvL(N3,Iz,Irp)
                VPrM3 = VA(N3,I2,Iz,Irm)-CCenL(N3,1)+CEnvL(N3,Iz,Irm)
                TempAc = TempAc + real(
     1           rmp2*(    HA(N2,I2,Iz,Irp) *      UPrP3 *conjg(VPrP1)+
     2                     HA(N3,I2,Iz,Irp) *conjg(UPrP1)*      VPrP2 +
     3               conjg(HA(N1,I2,Iz,Irp))*      UPrP2 *      VPrP3 )
     4          -rmm2*(    HA(N2,I2,Iz,Irp) *      UPrM3 *conjg(VPrM1)+
     5                     HA(N3,I2,Iz,Irp) *conjg(UPrM1)*      VPrM2 +
     6               conjg(HA(N1,I2,Iz,Irp))*      UPrM2 *      VPrM3 ))
!234567890123456789012345678901234567890123456789012345678901234567890123
!        1         2         3         4         5         6         7
              enddo
            enddo
            QDuFF(Iz,Ir)=QDuff(Iz,Ir) + 0.25*TempAc*DEN2I             

            QDuvh(Iz,Ir)=0.25*TempAc*DEN2I
      
c Loop over wavenumbers to calculate mass and momentum forcing
            do N1 = 1,NMode 
              UAbP = UA(N1,I2,Iz,Irp) - CCenL(N1,1)
              UAbM = UA(N1,I2,Iz,Irm) - CCenL(N1,1)
              UPr =  UA(N1,I2,Iz,Ir)  - CCenR(N1,1)+CEnvR(N1,Iz,Ir)
              UPrP = UA(N1,I2,Iz,Irp) - CCenR(N1,1)+CEnvR(N1,Iz,Irp)
              UPrM = UA(N1,I2,Iz,Irm) - CCenR(N1,1)+CEnvR(N1,Iz,Irm)
              VPrP = VA(N1,I2,Iz,Irp) - CCenL(N1,1)+CEnvL(N1,Iz,Irp)
              VPrM = VA(N1,I2,Iz,Irm) - CCenL(N1,1)+CEnvL(N1,Iz,Irm)
              HP   = HA(N1,I2,Iz,Irp) + HEnv(N1,Iz,Irp)
              HM   = HA(N1,I2,Iz,Irm) + HEnv(N1,Iz,Irm)
!-----------------------------------------------------------------------
      QMass(Iz,Ir) = QMass(Iz,Ir) - 0.5*real(
     1            rmp*conjg(UPrP)*HP 
     2           -rmm*conjg(UPrM)*HM)*DENI
      if(DoEnv)then
        QMass(Iz,Ir) = QMass(Iz,Ir) - 0.5*real(
     1              rmp*conjg(UAbP)*HEnv(N1,Iz,Irp)
     2             -rmm*conjg(UAbM)*HEnv(N1,Iz,Irm)   )*DENI
      endif
      QDuFF(Iz,Ir) = QDuFF(Iz,Ir)   - 0.5*real(
     1          ( rmp2*H0(Iz,Irp)*conjg(UPrP)*VPrP 
     2          - rmm2*H0(Iz,Irm)*conjg(UPrM)*VPrM 
     3          + rmp2*U0(Iz,Irp)*conjg(HP  )*VPrP
     4          - rmm2*U0(Iz,Irm)*conjg(HM  )*VPrM )*DEN2I
     5          + FCOR*UA(N1,I2,Iz,Ir)*conjg(HA(N1,I2,Iz,Ir))/H0(Iz,Ir))

      QDsym(Iz,Ir) =  QDsym(Iz,Ir) - 0.5*real(
     1          ( rmp2*H0(Iz,Irp)*conjg(UPrP)*VPrP 
     2          - rmm2*H0(Iz,Irm)*conjg(UPrM)*VPrM 
     3          + rmp2*U0(Iz,Irp)*conjg(HP  )*VPrP
     4          - rmm2*U0(Iz,Irm)*conjg(HM  )*VPrM )*DEN2I  )

      QDHsym(Iz,Ir) = QDHsym(Iz,Ir) - 0.5*real(
     1          ( rmp2*H0(Iz,Irp)*conjg(UPrP)*VPrP 
     2          - rmm2*H0(Iz,Irm)*conjg(UPrM)*VPrM )*DEN2I  ) 

      QDuv(Iz,Ir) = QDuv(Iz,Ir) - 0.5*real(
     1          ( conjg(UPrP)*VPrP - conjg(UPrM)*VPrM )/twodrm )

      QDuvhs(Iz,Ir) = QDuvhs(Iz,Ir) - 0.5*real(
     1          ( 0.5*(conjg(UPrP)*VPrP + conjg(UPrM)*VPrM)/H0(Iz,Ir)
     2            *(rmp*H0(Iz,Ir+1) - rmm*H0(Iz,Ir-1)) )*DENI )

      QDuvor(Iz,Ir) = QDuvor(Iz,Ir) - 0.5*real(
     1          (conjg(UPrP)*VPrP + conjg(UPrM)*VPrM)*rmi )     

      QDuvoh(Iz,Ir) = QDuvoh(Iz,Ir) - 0.5*real(
     1          ( 0.5*(conjg(UPrP)*VPrP + conjg(UPrM)*VPrM)/H0(Iz,Ir)*
     2          (H0(Iz,Ir+1) - H0(Iz,Ir-1))/twodrm ) )

      QDfcor(Iz,Ir) = QDfcor(Iz,Ir)  - 0.5*real(
     5          + FCOR*UA(N1,I2,Iz,Ir)*conjg(HA(N1,I2,Iz,Ir))/H0(Iz,Ir))

!-----------------------------------------------------------------------
            enddo      !N1
!-----------------------------------------------------------------------
      QMass(Iz,Ir) = QMass(Iz,Ir) +
     1        AK0(Iz,Ir)*((H0(Iz,Irp)+H0(Iz,Irm)-2.0*H0(Iz,Ir))/drm2
     2                +(H0(Iz,Irp)-H0(Iz,Irm))/(rm*twodrm)        )

      QDuFF(Iz,Ir) = QDuFF(Iz,Ir)  +
     1        AK0(Iz,Ir)*((V0(IS2,Iz,Irp)+V0(IS2,Iz,Irm)-V0(IS1,Iz,Ir))
     2             /drm2 +(V0(IS2,Iz,Irp)-V0(IS2,Iz,Irm))/(rm*twodrm)
     3             - 0.5*V0(IS1,Iz,Ir)*rmi2                       )

      QDmix(Iz,Ir) =  
     1        AK0(Iz,Ir)*((V0(IS2,Iz,Irp)+V0(IS2,Iz,Irm)-V0(IS1,Iz,Ir))
     2             /drm2 +(V0(IS2,Iz,Irp)-V0(IS2,Iz,Irm))/(rm*twodrm)
     3             - 0.5*V0(IS1,Iz,Ir)*rmi2                       )

      QLr(Iz,Ir) = QDuFF(Iz,Ir) + 
     1        AK0(Iz,Ir)*((V0(IS1,Iz,Ir)-2.0*V0(IS2,Iz,Ir))/drm2
     2               +(0.5*V0(IS1,Iz,Ir) -   V0(IS2,Iz,Ir))*rmi2)
!-----------------------------------------------------------------------
c Loop over wavenumbers to calculate mass and momentum forcing
c and save mass and momentum forcing with U0 terms
            do N1 = 1,NMode 
              VPrP = VA(N1,I2,Iz,Irp) - CCenL(N1,1)+CEnvL(N1,Iz,Irp)
              VPrM = VA(N1,I2,Iz,Irm) - CCenL(N1,1)+CEnvL(N1,Iz,Irm)
              HP   = HA(N1,I2,Iz,Irp) + HEnv(N1,Iz,Irp)
              HM   = HA(N1,I2,Iz,Irm) + HEnv(N1,Iz,Irm)
!-----------------------------------------------------------------------
      QDuf(Iz,Ir) = QDuf(Iz,Ir)  - 0.5*real(
     1          ( rmp2*U0(Iz,Irp)*conjg(HP  )*VPrP
     2          - rmm2*U0(Iz,Irm)*conjg(HM  )*VPrM )*DEN2I )

!-----------------------------------------------------------------------
            enddo      !N1
          enddo        !Ir
       enddo          !Iz 

c Set forcings at boundaries
          QMass(1,0) = 0.0
          QMass(2,0) = 0.0
          QDuFF(1,0) = 0.0
          QDuFF(2,0) = 0.0
          QDuf(1,0) = 0.0
          QDuf(2,0) = 0.0
          QLr(1,0)   = 0.0
          QLr(2,0)   = 0.0
          QMass(1,IrMain) = 0.0
          QDuFF(1,IrMain) = 0.0
          QLr(1,IrMain)   = 0.0
          QMass(2,IrMain) = 0.0
          QDuFF(2,IrMain) = 0.0
          QLr(2,IrMain)   = 0.0

c Loop from center out to calculate alpha for Linzen--Kuo 
       do Iz = 1,IzMx
          if(Iz .eq. 1) then
            Sigfac = 1.0/Sig11
          else
            Sigfac = (Sig11 + Sig12)/(Sig11*Sig22)
          endif
          do Ir = 1, IrMain
            Irp = Ir + 1
            Irm = Ir - 1
            rm = RADIUS(Ir)
            rmi = 1.0/rm
            rmp = rm + drm
            rmm = rm - drm
            E0(Iz,Ir) = 2.0*V0(IS2,Iz,Ir)*rmi + FCor
             if(Ir .lt. 5) then
              Z0(Iz,Ir) = (V0(IS2,Iz,Irp)-V0(IS2,Iz,Irm))/twodrm 
     1               + V0(IS2,Iz,Ir)*rmi + FCor
             else
              Z0(Iz,Ir) = (rmp*V0(IS2,Iz,Irp) - rmm*V0(IS2,Iz,Irm))/
     1                  (rm*twodrm) + FCor
             endif
          enddo
          Z0(Iz,IrMain) = Z0(Iz,IrLast)  
          ALPHA(Iz,0) = 0.0
          do Ir = 1,IrMain
            rm = RADIUS(Ir)
            RO2I(Iz,Ir) = Sigfac*E0(Iz,Ir)*Z0(Iz,Ir)/(Gee*H0(Iz,Ir))
            A(Iz,Ir) = (1.0/drm2 - 1.0/(rm*twodrm))
            B(Iz,Ir) =-(2.0/drm2 + RO2I(Iz,Ir))
            C(Iz,Ir) = (1.0/drm2 + 1.0/(rm*twodrm))
            DEN(Iz,Ir) = B(Iz,Ir) + C(Iz,Ir)*ALPHA(Iz,Ir-1)
            ALPHA(Iz,Ir) = -A(Iz,Ir)/DEN(Iz,Ir)
          enddo     !Ir

       enddo      !Iz

c Calculate BETA for Lindzen-Kuo and iterate U0 by F upgrades Nmax -1 times
      Nmax = 2
      do N = 1,Nmax
!-----------------------------------------------------------------------

       do Iz = 1,IzMx
          if(Iz .eq. 1) then
            Sigfac = 1.0/Sig11
          else
            Sigfac = (Sig11 + Sig12)/(Sig11*Sig22)
          endif
          Do Ir = 1,IrMain
            rm = RADIUS(Ir)
            F0(Iz,Ir) = rm*((QMass(Iz,Ir+1)-QMass(Iz,Ir-1))/twodrm
     2                 - Sigfac*E0(Iz,Ir)/Gee*QLr(Iz,Ir))
          enddo       !Ir
       enddo          !Iz
       do Iz = 1,IzMx
          if(Iz .eq. 1) then
            Sigfac = Sig12/(Sig11*Sig22)
          else
            Sigfac = 1.0/Sig11
          endif
          BETA(Iz,0)  = 0.0
          K = 3 - Iz
          do Ir = 1,IrLast
            rm = RADIUS(Ir)
            F(Iz,Ir) = F0(Iz,Ir) + Sigfac*rm*E0(K,Ir)*(Qlr(K,Ir)  
     1                           -    Z0(K,Ir)*U0(K,Ir))/Gee
          enddo

          do Ir = 1,IrMain
            BETA(Iz,Ir)  = (F(Iz,Ir)-C(Iz,Ir)*BETA(Iz,Ir-1))/DEN(Iz,Ir)
          enddo      !Ir


c Calculate radial mass flux at domain boundary
          DEN4 = ALPHA(Iz,IrMain) - 1.0
          if (DEN4.lt. 1.0E-05)then
            PsiLast = 0.0
          else
            PsiLast = BETA(Iz,IrMain)/DEN4
          endif
    
c Loop inward to diagnose radial velocity and to forecast
c swirling velocity
          U0(Iz,0) = 0.0
          U0(Iz,IrMain) = 0.0
          do Ir = IrLast,1,-1
            rm = RADIUS(Ir)
            PsiLast = ALPHA(Iz,Ir)*PsiLast + BETA(Iz,Ir)
            U0(Iz,Ir) = PsiLast/(rm*H0(Iz,Ir))              !01MAR95
c           U0(Iz,Ir) = PsiLast/(rm*(H0(Iz,Ir)+H0Env(Iz,Ir)))
          enddo     !Ir
       enddo        !Iz

c Calculate new forcing for QDuFF and QLR from new U0's for N < Nmax
       if(N .ge. Nmax) go to 20 
       do Iz = 1,IzMx
          do Ir = 1,IrLast
c Calculate radius in meters
            rm = RADIUS(Ir)

c Calculate  indices and radii of nearby grid points
            Irp = Ir + 1
            Irm = Ir - 1
            rmp = rm + drm
            rmm = rm - drm
            rmp2= rmp*rmp
            rmm2= rmm*rmm
            DENI  = 1.0/(rm*twodrm) 
            DEN2I = DENI/(rm*H0(Iz,Ir))

c Remove mass and momentum forcing for old U0's
            QDuFF(Iz,Ir) = QDuFF(Iz,Ir) - QDuf(Iz,Ir)
            QLr(Iz,Ir) = QLr(Iz,Ir) - QDuf(Iz,Ir)
            QDuf(Iz,Ir) = 0.0	
c Loop over wavenumbers to calculate corrected mass and momentum forcing
            do N1 = 1,NMode 
              VPrP = VA(N1,I2,Iz,Irp) - CCenL(N1,1)+CEnvL(N1,Iz,Irp)
              VPrM = VA(N1,I2,Iz,Irm) - CCenL(N1,1)+CEnvL(N1,Iz,Irm)
              HP   = HA(N1,I2,Iz,Irp) + HEnv(N1,Iz,Irp)
              HM   = HA(N1,I2,Iz,Irm) + HEnv(N1,Iz,Irm)
!-----------------------------------------------------------------------
      QDuf(Iz,Ir) = QDuf(Iz,Ir)  - 0.5*real(
     1          ( rmp2*U0(Iz,Irp)*conjg(HP  )*VPrP
     2          - rmm2*U0(Iz,Irm)*conjg(HM  )*VPrM )*DEN2I )

!-----------------------------------------------------------------------
            enddo      !N1
c Add corrected mass and momentum forcing
            QDuFF(Iz,Ir) = QDuFF(Iz,Ir) + QDuf(Iz,Ir)
            QLr(Iz,Ir) = QLr(Iz,Ir) + QDuf(Iz,Ir)
          enddo       !Ir
       enddo          !Iz
 20    continue
      enddo     !N

c Calculate V0
       do Iz = 1,IzMx
          V0(IS3,Iz,0)=0.0
          V0(IS3,Iz,IrMain)=0.0
          do Ir = 1,IrLast
            rm = RADIUS(Ir)
            if(BRos . gt. 0.0) then
             rmp500=rm+500000.0
            else
             rmp500=rm-504000.0
            endif
	    dtjs=0.5*twodtj
            call DoDen0(rm,dtjs,DEN0)
           DEN3(Iz,Ir) = DEN0 + AK0(Iz,Ir)*twodtj*(1.0/drm2+0.5/(rm*rm))
           V0(IS3,Iz,Ir) = (V0(IS1,Iz,Ir) 
     1          +twodtj*(-Z0(Iz,Ir)*U0(Iz,Ir)+QDuFF(Iz,Ir)))/DEN3(Iz,Ir)


c Apply Robert philtre
            V0(IS2,Iz,Ir)=Parm0*V0(IS2,Iz,Ir)
     1               +Parm*(V0(IS1,Iz,Ir)+V0(IS3,Iz,Ir))

c       if(Ir.lt.9.and.Ir.gt.3) then
c        if(Ir.eq.4) write(9,11)Iz,TIMEh
c        write(9,11)Iz,DEN3(Iz,Ir),U0(Iz,Ir),Z0(Iz,Ir),QDuff(Iz,Ir)
c        write(9,11)Iz,V0(IS3,Iz,Ir),V0(IS1,Iz,Ir),V0(IS2,Iz,Ir)
c       endif
c       if(Ir.lt.91.and.Ir.gt.85) then
c        write(9,11)Iz,DEN3(Iz,Ir),U0(Iz,Ir),Z0(Iz,Ir),QDuff(Iz,Ir)
c        write(9,11)Iz,V0(IS3,Iz,Ir),V0(IS1,Iz,Ir),V0(IS2,Iz,Ir)
c       endif

          enddo     !Ir

c boundary value for V0 (constant extrapolation)
        V0(IS3,Iz,IrMain) = V0(IS3,Iz,IrLast)

       enddo     !end Iz loop for V0 

   11 Format(1x,I2,4(g14.7,1x))

       return
       end
     
	subroutine March(UA,VA,HA,QDuff,I1,I2,I3,U0,V0,H0,IS1,IS2,IS3,
     1         FCor,FCor0,XCen0,BRos,Cgr,Rho,AK,FAK,Ijts,
     2         XCen,CCenL,CCenR,
     3         C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,
     4         IsQn,IsEnv,IsNL,IsVORt,IsFt,IsDNM,TDNM,TIMEh)
!-----------------------------------------------------------!
! Marches primitive equation forward in time to predict wind!
! and depth Nnts minor time steps in the future. Uses leap  !
! frog marching scheme with Dufort-Frankel differenceing for!
! diffusion terms and backward time steps for Newtonian     !
! damping. Eliminates computational mode with a Asselin/    !
! Robert filter and maintains longer time step with pressure!
! force avearaging                                          !
!-----------------------------------------------------------!

	parameter (IzMx=2,IrMain=1001,IrLast=IrMain-1,NMode=3
     1              ,NX=2,HParm=0.25,HParm0=1.0-2.0*HParm)
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain)
     1         ,XCen(IzMx,2),XCen0(2),HSym(IzMx),Cgr(IzMx),Rho(IzMx+1)
     2         ,H0Env(IzMx,0:IrMain),C0Env(IzMx,0:IrMain)
     3         ,QDuff(IzMx,0:IrMain),AK0(IzMx,0:IrMain)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain)
     1           ,HA(NMode,3,IzMx,0:IrMain),DU,DV,DH,eye,Qn
     3           ,Faze(NMode),HBarP(IzMx),HBar0(IzMx)
     4           ,HBarM(IzMx),Hgrad,Hgrad0,HEnv(NMode,IzMx,0:IrMain)
     5           ,CEnvR(NMode,IzMx,0:IrMain),CEnvL(NMode,IzMx,0:IrMain)
     6           ,DIVN1,DIVN2,UPr1,VPr1,UPr2,VPr2
     7           ,UA1,VA1,UA2,VA2,CCenR(NMode,IzMx),CCenL(NMode,IzMx)
     8           ,DDL1,DDL2,VTot
        parameter (eye=(0.0,1.0),gee=9.8,VORMAX=2.5e-4)
	parameter (rmEnv=20.25e06)
 	logical IsEnv,IsNL,IsQn,Qon,IsVORt,IsFt,IsDNM
	logical IsEven,IsPlus,IsMinus,DoEnv
 	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
        common /ExMix/Amix,Smix,Incr

c Set up mixing
        do Iz = 1,2
        do i = 0,IrMain 
          AK0(Iz,i) = AK
        enddo
        enddo

c Compute maximun wind radius and wind for upper and lower vortices
        do Iz = 1,2
          drk = drm/1000.
          RMaxW = RMWR(Iz)
          if(RMW(Iz) .gt. RMWR(Iz)) RMaxW = RMW(Iz)
          IRMW = RMaxW/drk

c need loop to seek final RMW, below is just one step
          IPM = 0
          if(V0(IS2,Iz,IRMW-1) .gt. V0(IS2,Iz,IRMW)) IPM = -1
          if(V0(IS2,Iz,IRMW+1) .gt. V0(IS2,Iz,IRMW)) IPM = 1
          IRMW = IRMW + IPM
          RMWR(Iz) = Radius(IRMW)/1000.
          VMaxR(Iz) = V0(IS2,Iz,IRMW)
        enddo

        do Iz = 1,2
          LpIndx = RMWR(Iz)/drk
          LpIndx = LpIndx - Incr
        do i = 0,LpIndx
          AK0(Iz,i) = Amix*AK0(Iz,i)
        enddo
          AK0(Iz,LpIndx+1) = Amix*.8*AK0(Iz,LpIndx+1)
          AK0(Iz,LpIndx+2) = Amix*.6*AK0(Iz,LpIndx+2)
          AK0(Iz,LpIndx+3) = Amix*.4*AK0(Iz,LpIndx+3)
          AK0(Iz,LpIndx+4) = Amix*.2*AK0(Iz,LpIndx+4)
        enddo

        do Iz = 1,2
        do i = 1,1
          AK0(Iz,i) = AK0(Iz,i)*4.
        enddo
        enddo
        do Iz =1,2
          AK0(Iz,2) = AK0(Iz,2)*3.
          AK0(Iz,3) = AK0(Iz,3)*2.
          AK0(Iz,4) = AK0(Iz,4)*1.
        enddo


c Set up damping for highest mode
        if(IsDNM)then
          EXTRA3 =  twodts/(86400.0*TDNM)
        else
          EXTRA3 = 0.0
        endif

c Set up sigma's
        Sig11 = (Rho(1) - Rho(2))/Rho(1)
        Sig12 = (Rho(2) - Rho(3))/Rho(1)
        Sig22 = (Rho(2) - Rho(3))/Rho(2)

c Calculate Coriolis param if it is allowed to change
          if(IsFt)FCor = FCor0 + 1000.0*BRos*(XCen(1,2)-XCen0(2))

c Compute symmetric vortex.
	  call SyMar(UA,VA,HA,I1,I2,I3,U0,V0,H0,QDuff,
     1         IS1,IS2,IS3,CCenL,CCenR,CEnvL,CEnvR,HEnv,
     2         FCor,BRos,HSym,H0Env,Cgr,Rho,AK,FAK,
     3         IsQn,IsEnv,IsNL,IsVORt,IsFt,IsDNM,TDNM,TIMEh)

c Loop over minor time steps
	do It = 1, Nnts    
                                                            

c Set indices of time levels: Initial level is I1, derivatives
c are calcualted (mostly) at I2, and predicted values are stored
c at I3
          call SwapI(I1,I2,I3)

c Calculate time in HOURS since end of last major time step
          TCen = dts*It/3600.0

c Calculate time variation of mass source-sink
          call MakQnT(Faze,Qon,IsQn,TIMEh,TCen)

c Loop over tangential wave numbers
          do N = 1,NMode

c Set up floating point tangential wavenumber
           if(N .eq. 1)then
            IrFirst = N 
           else
            IrFirst = N + 1            
           endif
            EN = float(N)
            ENSQ = EN*EN

c Set up control parms for wave-wave algorithm
	    Nhaf=int(0.5*N)
	    IsEven = mod(N,2).eq.0
	    Nstart = Nhaf+1
	    Nend = NMode - N
	    Nm1  = N - 1
   	    IsPlus = N.gt.2
	    IsMinus= N.lt.NMode

c Set extra dissipation for highest wave number
            if (N.eq.NMode)then
              EXTRA = EXTRA3
            else
              EXTRA = 0.0
            endif  ! N.eq.NMode

c Loop over vertical grid points to predict depth
           do Iz = 1,IzMx
c Loop over radial grid points to predict depth
            do Ir = IrFirst, IrLast


c Calculate radius in meters
              rm = RADIUS(Ir)
	      DoEnv = IsEnv.and.(rm.lt.rmEnv)
c Calculate  mass source sink at this radius
              call MakQnR(N,Qn,rm,Faze,Qon)

c Calculate  indicies and radii of nearby grid points
              Irp = Ir + 1
              Irm = Ir - 1
              rmi = 1.0/rm
              rmi2 = rmi*rmi
              rmp = rm + drm
              rmm = rm - drm

c Calculate  denominator for backwards differences
              call DoDen0(rm,twodts,DEN0)

c Calculate linear depth tendency
!---------------------------------------------------------------------
        AKmix = AK0(Iz,Ir)
        DH = eye*EN*(V0(IS2,Iz,Ir)             *HA(N,I2,Iz,Ir) 
     1              +VA(N,I2,Iz,Ir)            *H0(Iz,Ir)  )*rmi
     2     -   (rmp*(H0(Iz,Irp)     *UA(N,I2,Iz,Irp)
     3         +     HA(N,I2,Iz,Irp)*U0(Iz,Irp)     )     
     4        - rmm*(H0(Iz,Irm)     *UA(N,I2,Iz,Irm)
     5         +     HA(N,I2,Iz,Irm)*U0(Iz,Irm)     ))/(rm*twodrm)
     6 +(CCenR(N,1)-CEnvR(N,Iz,Ir))*(H0(Iz,Irp)-H0(Iz,Irm))/twodrm + Qn
     7 +AKmix*((HA(N,I2,Iz,Irp)+HA(N,I2,Iz,Irm)-HA(N,I1,Iz,Ir))/drm2
     8            +(HA(N,I2,Iz,Irp)-HA(N,I2,Iz,Irm))/(rm*twodrm)
     9                   - 0.5*ENSQ*HA(N,I1,Iz,Ir)*rmi2       )

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,12)Ijts,It
c       endif
   12   Format(1x,'Big Step:',I4,'  Small Step: ',I3)

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DH,CCenR(n,1),CEnvR(N,Iz,Ir),Qn
c       endif



!---------------------------------------------------------------------
!234567890123456789012345678901234567890123456789012345678901234567890
!        1         2         3         4         5         6         7

              if(DoEnv)then
!--------------------------------------------------------------------
                 DH = DH -(  -eye*EN*
     1 ( C0Env(Iz,Ir)*HA(N,I2,Iz,Ir)+V0(IS2,Iz,Ir)*HEnv(N,Iz,Ir) )*rmi 
     2 +    (         U0(Iz,Ir)*(HEnv(N,Iz,Irp )-HEnv(N,Iz,Irm ) )
     3 + UA(N,I2,IZ,Ir)*(H0Env(Iz,Irp)  -H0Env(Iz,Irm)  ))/twodrm  )
!--------------------------------------------------------------------
              endif  ! DoEnv

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DH,HEnv(N,Iz,Ir),V0(IS2,Iz,Ir),rmi
c        write(9,11)Iz,HA(N,I2,Iz,Ir),C0Env(Iz,Ir),H0Env(Iz,Ir)
c       endif


c Calculate nonlinear terms

              if(IsEven.and.IsNL)then
!234567890123456789012345678901234567890123456789012345678901234567890
!        1  ^ | ^ ^3^ ^      4         5         6         7         8
                N1=Nhaf
                DDL1 = -eye*float(N1)*rmi
                UA1 = UA(N1,I2,Iz,Ir) 
                VA1 = VA(N1,I2,Iz,Ir) 
                UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1)
                VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1)
                DIVN1 = (rmp*UA(N1,I2,Iz,Irp)
     1                  -rmm*UA(N1,I2,Iz,Irm))/(rm*twodrm) 
     2                +  VA(N1,I2,Iz,Ir)*DDL1

C Interactions on diagonal of forcing matrix
!-----------------------------------------------------------------------
      DH = DH - 0.5*(
     1   UPr1*(HA(N1,I2,Iz,Irp)-HA(N1,I2,Iz,Irm))/twodrm
     2  +VPr1* HA(N1,I2,Iz,Ir)*DDL1
     3  +      HA(N1,I2,Iz,Ir)*DIVN1                              )
!-----------------------------------------------------------------------
                if(DoEnv)then
!-----------------------------------------------------------------------
      DH = DH - 0.5*(
     1   UA1*(HEnv(N1,Iz,Irp)-HEnv(N1,Iz,Irm))/twodrm
     2 + VA1* HEnv(N1,Iz,Ir)*DDL1                     )
!-----------------------------------------------------------------------
                endif ! DoEnv
              endif   ! IsEven

              if(IsPlus.and.IsNL)then
c Interactions forcing higher wavenumbers
                do N1 = Nstart, Nm1
!234567890123456789012345678901234567890123456789012345678901234567890
!        1  ^ | ^ ^3^ ^      4         5         6         7         8

                  DDL1 = -eye*float(N1)*rmi
                  UA1 = UA(N1,I2,Iz,Ir) 
                  VA1 = VA(N1,I2,Iz,Ir)
                  UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1)
                  VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1) 
                  DIVN1 = (rmp*UA(N1,I2,Iz,Irp)
     1                  -rmm*UA(N1,I2,Iz,Irm))/(rm*twodrm) 
     2                +  VA(N1,I2,Iz,Ir)*DDL1


                  N2 = N-N1
                  DDL2 = - eye*float(N2)*rmi
                  UA2 = UA(N2,I2,Iz,Ir) 
                  VA2 = VA(N2,I2,Iz,Ir)
                  UPr2 = UA2 + CEnvR(N2,Iz,Ir) - CCenR(N2,1) 
                  VPr2 = VA2 + CEnvL(N2,Iz,Ir) - CCenL(N2,1) 
                  DIVN2 = (rmp*UA(N2,I2,Iz,Irp)
     1                    -rmm*UA(N2,I2,Iz,Irm))/(rm*twodrm) 
     2                  +  VA(N2,I2,Iz,Ir)*DDL2

!-----------------------------------------------------------------------
      DH = DH - 0.5*(
     1   (UPr1*(HA(N2,I2,Iz,Irp)-HA(N2,I2,Iz,Irm))
     2   +UPr2*(HA(N1,I2,Iz,Irp)-HA(N1,I2,Iz,Irm)))/twodrm
     3   +VPr1*HA(N2,I2,Iz,Ir)*DDL2 + VPr2*HA(N1,I2,Iz,Ir)*DDL1
     5   +HA(N1,I2,Iz,Ir)*DIVN2     + HA(N2,I2,Iz,Ir)*DIVN1     )
!-----------------------------------------------------------------------
                  if(DoEnv)then
!-----------------------------------------------------------------------
      DH = DH - 0.5*(
     1  + (UA1*(HEnv(N2,Iz,Irp)-HEnv(N2,Iz,Irm))
     2  +  UA2*(HEnv(N1,Iz,Irp)-HEnv(N1,Iz,Irm)))/twodrm
     6  +  VA1*HEnv(N2,Iz,Ir)*DDL2 + VA2*HEnv(N1,Iz,Ir)*DDL1 )
!-----------------------------------------------------------------------
                  endif  ! DoEnv 
                enddo !N1
 	      endif !IsPlus


              if(IsMinus.and.IsNL)then
c Interactions forcing lower wavenumbers
                do N1 = 1,Nend

!234567890123456789012345678901234567890123456789012345678901234567890
!        1  ^ | ^ ^3^ ^      4         5         6         7         8

                  DDL1 = -eye*float(N1)*rmi
                  UA1 = UA(N1,I2,Iz,Ir)
                  VA1 = VA(N1,I2,Iz,Ir)
                  UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1) 
                  VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1) 
                  DIVN1 = (rmp*UA(N1,I2,Iz,Irp)
     1                  -rmm*UA(N1,I2,Iz,Irm))/(rm*twodrm) 
     2                +  VA(N1,I2,Iz,Ir)*DDL1


                  N2 = N+N1
                  DDL2 = - eye*float(N2)*rmi
                  UA2 = UA(N2,I2,Iz,Ir)
                  VA2 = VA(N2,I2,Iz,Ir)
                  UPr2 = UA2 + CEnvR(N2,Iz,Ir) - CCenR(N2,1) 
                  VPr2 = VA2 + CEnvL(N2,Iz,Ir) - CCenL(N2,1) 
                  DIVN2 = (rmp*UA(N2,I2,Iz,Irp)
     1                    -rmm*UA(N2,I2,Iz,Irm))/(rm*twodrm) 
     2                  +  VA(N2,I2,Iz,Ir)*DDL2

!-----------------------------------------------------------------------
       DH = DH - 0.5*(
     1    (conjg(UPr1)*      (HA(N2,I2,Iz,Irp)-HA(N2,I2,Iz,Irm))
     2   +       UPr2 * conjg(HA(N1,I2,Iz,Irp)-HA(N1,I2,Iz,Irm)))/twodrm
     3   + conjg(VPr1)*       HA(N2,I2,Iz,Ir)*DDL2
     4   +       VPr2 * conjg(HA(N1,I2,Iz,Ir)*DDL1)
     5   + conjg(HA(N1,I2,Iz,Ir))*      DIVN2
     6   +       HA(N2,I2,Iz,Ir) *conjg(DIVN1)         )
!-----------------------------------------------------------------------
                  if(DoEnv)then
!-----------------------------------------------------------------------
       DH = DH - 0.5*(
     1 +(conjg(UA1)*      (HEnv(N2,Iz,Irp)-HEnv(N2,Iz,Irm))
     2 +       UA2 * conjg(HEnv(N1,Iz,Irp)-HEnv(N1,Iz,Irm)) )/twodrm
     3 + conjg(VA1)*       HEnv(N2,Iz,Ir)*DDL2 
     4 +       VA2 * conjg(HEnv(N1,Iz,Ir)*DDL1)                  )
!-----------------------------------------------------------------------
                  endif ! DoEnv
                enddo  !N1
              endif !IsMinus
!234567890123456789012345678901234567890123456789012345678901234567890
!        1  ^ | ^ ^3^ ^      4         5         6         7         8

c Add DuFort-Frankel terms to denominator
              DEN = DEN0 + EXTRA
     1             + (1.0/drm2 + 0.5*ENSQ*rmi2)*AK0(Iz,Ir)*twodts

c March depth forward one minor time step
              HA(N,I3,Iz,Ir) = (HA(N,I1,Iz,Ir) + DH*twodts)/DEN

!234567890123456789012345678901234567890123456789012345678901234567890
!        1         2         3         4         5         6         7
            enddo      !Ir
           enddo      !Iz
!*****************************************************************************
c Impose boundary conditions on depth
	    call DoBCH(HA,I2,I3,N,Cgr) !Depth array predicted

c Loop over vertical grid points to calculate wind components
           do Iz = 1,IzMx
c Set up time averaged depth near center 
            do I = 1,IzMx
              HBarP(I)=HParm0*HA(N,I2,I,IrFirst)
     1           + HParm*(HA(N,I1,I,IrFirst)+HA(N,I3,I,IrFirst))
              HBar0(I)=HParm0*HA(N,I2,I,IrFirst-1) 
     1           + HParm*(HA(N,I1,I,IrFirst-1)+HA(N,I3,I,IrFirst-1))
            enddo   ! short Iz loop

c Loop over radial grid points to calculate wind components
            do Ir = IrFirst, IrLast

c Radius in meters and its inverse and inverse squared
              Irp = Ir + 1
              Irm = Ir - 1
              rm = RADIUS(Ir)
	      DoEnv = IsEnv.and.(rm.lt.rmEnv)
              rmi = 1.0/rm
              rmi2 = rmi*rmi
              rmp = rm + drm
              rmm = rm - drm

c Move old time averaged winds "down" and calculate new one
              HBarM(1)=HBar0(1)
              HBarM(2)=HBar0(2)
              HBar0(1)=HBarP(1)
              HBar0(2)=HBarP(2)
              HBarP(1)=HParm0*HA(N,I2,1,Irp)
     1             +HParm*(HA(N,I1,1,Irp)+HA(N,I3,1,Irp))
              HBarP(2)=HParm0*HA(N,I2,2,Irp)
     1             +HParm*(HA(N,I1,2,Irp)+HA(N,I3,2,Irp))

c Calculate mean-flow vorticity and inertia parameter
            if(Ir .lt. 5) then
              Z0 = (V0(IS2,Iz,Irp)-V0(IS2,Iz,Irm))/twodrm + 
     1             V0(IS2,Iz,Ir)*rmi + FCor
            else
              Z0 = (rmp*V0(IS2,Iz,Irp)-rmm*V0(IS2,Iz,Irm))/(rm*twodrm)
     1             + FCor
            endif
              E0 = 2.0*V0(IS2,Iz,Ir)*rmi + FCor

c set up pressure force for UA
              if(Iz .eq.1) then
                Hgrad = (Sig12 + Sig11)*(HBarP(1) - HBarM(1)) +
     1                  Sig12*(HBarP(2) - HBarM(2))
              else
                Hgrad = Sig22*(HBarP(1) - HBarM(1)) +
     1                  Sig22*(HBarP(2) - HBarM(2))
              endif

c set up pressure force for VA
              if(Iz .eq. 1) then
                Hgrad0 = (Sig12 + Sig11)*HBar0(1) +
     1                   Sig12*HBar0(2)
              else
                Hgrad0 = Sig22*HBar0(1) +
     1                   Sig22*HBar0(2)
              endif


!---------------------------------------------------------------------
c Calculate linear radial wind tendency
       AKmix = AK0(Iz,Ir)
       DU = -(U0(Iz,Ir)*     (UA(N,I2,Iz,Irp)-UA(N,I2,Iz,Irm))
     *       +UA(N,I2,Iz,Ir)*(U0(Iz,Irp)-U0(Iz,Irm)          ))/twodrm 
     1      + eye*EN*V0(IS2,Iz,Ir)*UA(N,I2,Iz,Ir)*rmi 
     2      + E0*VA(N,I2,Iz,Ir) - gee*Hgrad/twodrm
     3      +(CCenR(N,1)-CEnvR(N,Iz,Ir))*(U0(Iz,Irp)-U0(Iz,Irm))/twodrm
     4      - (CCenL(N,1)-CEnvL(N,Iz,Ir))*V0(IS2,Iz,Ir)*rmi
     5 + AKmix*((UA(N,I2,Iz,Irp)+UA(N,I2,Iz,Irm)-UA(N,I1,Iz,Ir))/drm2
     6      +(UA(N,I2,Iz,Irp)-UA(N,I2,Iz,Irm))/(rm*twodrm)
     7         +( 2.0*EN*eye*VA(N,I2,Iz,Ir)
     8       -0.5*(ENSQ+1.0)*UA(N,I1,Iz,Ir) )*rmi2           )


c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DU,CCenL(N,1),CEnvL(N,Iz,Ir),E0
c        write(9,11)Iz,Hgrad,UA(N,I2,Iz,Ir),U0(Iz,Ir),twodrm
c      endif
   11 Format(1x,I2,8(g10.3,1x))



!---------------------------------------------------------------------
c Calculate linear tangential wind tendency
        AKmix = AK0(Iz,Ir)
        DV = - U0(Iz,Ir)*(rmp*VA(N,I2,Iz,Irp)-rmm*VA(N,I2,Iz,Irm)) 
     1       /(rm*twodrm) + eye*EN*V0(IS2,Iz,Ir)*VA(N,I2,Iz,Ir)*rmi 
     2       - Z0*UA(N,I2,Iz,Ir) + gee*eye*EN*Hgrad0*rmi
     3       + (CCenR(N,1)-CEnvR(N,Iz,Ir))*
     4         (V0(IS2,Iz,Irp)-V0(IS2,Iz,Irm))/twodrm
     5       + (CCenL(N,1)-CEnvL(N,Iz,Ir))* U0(Iz,Ir)*rmi
     6  +AKmix*((VA(N,I2,Iz,Irp)+VA(N,I2,Iz,Irm)-VA(N,I1,Iz,Ir))/drm2
     7        +(VA(N,I2,Iz,Irp)-VA(N,I2,Iz,Irm))/(rm*twodrm)
     8         -  ( 2.0*EN*eye*UA(N,I2,Iz,Ir) 
     9         +0.5*(ENSQ+1.0)*VA(N,I1,Iz,Ir) )*rmi2         ) 

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DV,CCenR(N,1),CEnvR(N,Iz,Ir),Z0
c        write(9,11)Iz,Hgrad0,VA(N,I2,Iz,Ir),V0(IS2,Iz,Ir),rmi
c       endif


!---------------------------------------------------------------------
!234567890123456789012345678901234567890123456789012345678901234567890
!        1         2         3         4         5         6         7

               if(DoEnv)then
               C0Envt = C0Env(Iz,Ir)
!---------------------------------------------------------------------
        DU = DU-(-C0Envt*(eye*EN*UA(N,I2,Iz,Ir)+VA(N,I2,Iz,Ir))*rmi+
     1           +U0(Iz,Ir)*(CEnvR(N,Iz,Irp)-CEnvR(N,Iz,Irm))/twodrm
     2         -V0(IS2,Iz,Ir)*rmi*(CEnvL(N,Iz,Ir)+eye*EN*CEnvR(N,Iz,Ir))
     3         -VA(N,I2,Iz,Ir)*C0Envt*rmi)


c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DU
c      endif


        DV = DV-(-C0Envt*(eye*EN*VA(N,I2,Iz,Ir)-UA(N,I2,Iz,Ir))*rmi
     1         +U0(Iz,Ir)*(CEnvL(N,Iz,Irp)-CEnvL(N,Iz,Irm))/twodrm
     2         +V0(IS2,Iz,Ir)*rmi*(CEnvR(N,Iz,Ir)-eye*EN*CEnvL(N,Iz,Ir))
     3         +UA(N,I2,Iz,Ir)*(C0Env(Iz,Irp)-C0Env(Iz,Irm))/twodrm)

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DV,CEnvR(N,Iz,Ir),CEnvL(N,Iz,Ir)
c        write(9,11)Iz,V0(IS2,Iz,Ir),C0Envt,C0Env(Iz,Ir)
c       endif


!---------------------------------------------------------------------
               endif ! DoEnv

c Rossby interactions between adjacent wavenumbers
              if(N.eq.1)then  !beta advection by aymmetric wind
                DU = DU + BRos*rm*V0(IS2,Iz,Ir)
                DV = DV - BRos*rm*U0(Iz,Ir)
              endif 
              if(N.gt.1.and.IsNL)then !beta advection by next lower wavenumber
	        N2=N-1
                DU = DU + 0.5*BRos*rm*VA(N2,I2,Iz,Ir)
                DV = DV - 0.5*BRos*rm*UA(N2,I2,Iz,Ir)
              endif ! (N 1 to NMode)

              if(N.lt.NMode.and.IsNL)then
                N2=N+1
                DU = DU + 0.5*BRos*rm*VA(N2,I2,Iz,Ir)
                DV = DV - 0.5*BRos*rm*UA(N2,I2,Iz,Ir)
              endif ! (N.lt.NMode)

c       if(Ir.eq.8.and.N.eq.1) then
c        write(9,11)Iz,DU,BRos
c       endif

c Calculate denominator for backwards time step
              call DoDen0(rm,twodts,DEN0)

c Add DuFort-Frankel terms to denominator
              DEN = DEN0 + EXTRA
     1            + (1.0/drm2 + 0.5*(ENSQ+1.0)*rmi2)*AK0(Iz,Ir)*twodts

c Calculate nonlinear terms

              if(IsEven.and.IsNL)then
                N1=Nhaf
                DDL1 = -eye*float(N1)*rmi
                UA1 = UA(N1,I2,Iz,Ir)
                VA1 = VA(N1,I2,Iz,Ir)
                UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1) 
                VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1) 

c Interactions on diagonal of forcing matrix
!-----------------------------------------------------------------------
        DU = DU  - 0.5*(
     1       UPr1*( UA(N1,I2,Iz,Irp)    - UA(N1,I2,Iz,Irm))/twodrm
     2      +VPr1*(-VA(N1,I2,Iz,Ir)*rmi + UA(N1,I2,Iz,Ir )*DDL1)      )

       DV = DV   - 0.5*(
     1      UPr1*(VA(N1,I2,Iz,Irp)     - VA(N1,I2,Iz,Irm))/twodrm
     2     +VPr1*(UA(N1,I2,Iz,Ir )*rmi + VA(N1,I2,Iz,Ir )*DDL1)       )
!-----------------------------------------------------------------------
                  if(DoEnv) then
!----------------------------------------------------------------------
      DU = DU - 0.5*( 
     1  +  UA1*( CEnvR(N1,Iz,Irp)    - CEnvR(N1,Iz,Irm))/twodrm 
     2  +  VA1*(-CEnvL(N1,Iz,Ir)*rmi + CEnvR(N1,Iz,Ir)*DDL1)         )

      DV = DV - 0.5*(
     1  +  UA1*(CEnvL(N1,Iz,Irp)    - CEnvL(N1,Iz,Irm))/twodrm 
     2  +  VA1*(CEnvR(N1,Iz,Ir)*rmi + CEnvL(N1,Iz,Ir)*DDL1)         )
!--------------------------------------------------------------------
                  endif  ! DoEnv
                endif    ! IsEven

c Interactions forcing higher wavenumbers
                if(IsPlus.and.IsNL)then
                  do N1=NStart,Nm1
                    DDL1 = -eye*float(N1)*rmi
                    UA1 = UA(N1,I2,Iz,Ir)
                    VA1 = VA(N1,I2,Iz,Ir)
                    UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1) 
                    VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1) 

		    N2 = N-N1
                    DDL2 = -eye*float(N2)*rmi
                    UA2 = UA(N2,I2,Iz,Ir)
                    VA2 = VA(N2,I2,Iz,Ir) 
                    UPr2 = UA2 + CEnvR(N2,Iz,Ir) - CCenR(N2,1) 
                    VPr2 = VA2 + CEnvL(N2,Iz,Ir) - CCenL(N2,1)

!-----------------------------------------------------------------------
        DU = DU  - 0.5*(
     1  (UPr1*( UA(N2,I2,Iz,Irp)    - UA(N2,I2,Iz,Irm))
     2  +UPr2*( UA(N1,I2,Iz,Irp)    - UA(N1,I2,Iz,Irm)))/twodrm
     4  +VPr1*(-VA(N2,I2,Iz,Ir)*rmi + UA(N2,I2,Iz,Ir )*DDL2)
     5  +VPr2*(-VA(N1,I2,Iz,Ir)*rmi + UA(N1,I2,Iz,Ir )*DDL1)   )

       DV = DV   - 0.5*(
     1 (UPr1*(VA(N2,I2,Iz,Irp)    - VA(N2,I2,Iz,Irm))
     2 +UPr2*(VA(N1,I2,Iz,Irp)    - VA(N1,I2,Iz,Irm)))/twodrm
     4 +VPr1*(UA(N2,I2,Iz,Ir)*rmi + VA(N2,I2,Iz,Ir)*DDL2)
     5 +VPr2*(UA(N1,I2,Iz,Ir)*rmi + VA(N1,I2,Iz,Ir)*DDL1)    )
!-----------------------------------------------------------------------


                     if(DoEnv)then
!----------------------------------------------------------------------
      DU = DU - 0.5*(
     1  (UA1*( CEnvR(N2,Iz,Irp)    - CEnvR(N2,Iz,Irm))
     2  +UA2*( CEnvR(N1,Iz,Irp)    - CEnvR(N1,Iz,Irm)))/twodrm
     7  +VA1*(-CEnvL(N2,Iz,Ir)*rmi + CEnvR(N2,Iz,Ir)*DDL2)
     8  +VA2*(-CEnvL(N1,Iz,Ir)*rmi + CEnvR(N1,Iz,Ir)*DDL1)   )

      DV = DV - 0.5*(
     1  (UA1*(CEnvL(N2,Iz,Irp)    - CEnvL(N2,Iz,Irm))
     2  +UA2*(CEnvL(N1,Iz,Irp)    - CEnvL(N1,Iz,Irm)))/twodrm
     7  +VA1*(CEnvR(N2,Iz,Ir)*rmi + CEnvL(N2,Iz,Ir)*DDL2)
     8  +VA2*(CEnvR(N1,Iz,Ir)*rmi + CEnvL(N1,Iz,Ir)*DDL1)     )
!-----------------------------------------------------------------------
                      endif ! DoEnv
		    enddo !N1
                  endif !IsPlus

c Interactions forcing lower wavenumbers
                if(IsMinus.and.IsNL)then
                  do N1=1,Nend
                    DDL1 = -eye*float(N1)*rmi
                    UA1 = UA(N1,I2,Iz,Ir)
                    VA1 = VA(N1,I2,Iz,Ir)
                    UPr1 = UA1 + CEnvR(N1,Iz,Ir) - CCenR(N1,1) 
                    VPr1 = VA1 + CEnvL(N1,Iz,Ir) - CCenL(N1,1) 

		    N2 = N+N1
                    DDL2 = -eye*float(N2)*rmi
                    UA2 = UA(N2,I2,Iz,Ir)
                    VA2 = VA(N2,I2,Iz,Ir) 
                    UPr2 = UA2 + CEnvR(N2,Iz,Ir) - CCenR(N2,1) 
                    VPr2 = VA2 + CEnvL(N2,Iz,Ir) - CCenL(N2,1)

!-----------------------------------------------------------------------
        DU = DU  - 0.5*(
     1  (conjg(UPr1)*     ( UA(N2,I2,Iz,Irp)-UA(N2,I2,Iz,Irm))
     2  +      UPr2 *conjg( UA(N1,I2,Iz,Irp)-UA(N1,I2,Iz,Irm)))/twodrm
     3  +conjg(VPr1)*     (-VA(N2,I2,Iz,Ir)*rmi+UA(N2,I2,Iz,Ir)*DDL2)
     4  +      VPr2 *conjg(-VA(N1,I2,Iz,Ir)*rmi+UA(N1,I2,Iz,Ir)*DDL1) )

       DV = DV   - 0.5*(
     1  (conjg(UPr1)*     (VA(N2,I2,Iz,Irp)-VA(N2,I2,Iz,Irm))
     2  +      UPr2 *conjg(VA(N1,I2,Iz,Irp)-VA(N1,I2,Iz,Irm)))/twodrm
     3  +conjg(VPr1)*     (UA(N2,I2,Iz,Ir)*rmi+VA(N2,I2,Iz,Ir)*DDL2)
     4  +      VPr2 *conjg(UA(N1,I2,Iz,Ir)*rmi+VA(N1,I2,Iz,Ir)*DDL1) )
!--------------------------------------------------------------------
                    if(DoEnv)then 
!--------------------------------------------------------------------
       DU = DU - 0.5*(
     6  +(conjg(UA1)*     ( CEnvR(N2,Iz,Irp)-CEnvR(N2,Iz,Irm)) 
     7  +       UA2 *conjg( CEnvR(N1,Iz,Irp)-CEnvR(N1,Iz,Irm)))/twodrm
     8  + conjg(VA1)*     (-CEnvL(N2,Iz,Ir)*rmi+CEnvR(N2,Iz,Ir)*DDL2)
     9  +       VA2 *conjg(-CEnvL(N1,Iz,Ir)*rmi+CEnvR(N1,Iz,Ir)*DDL1) )

        DV = DV - 0.5*(
     7  +(conjg(UA1)*     (CEnvR(N2,Iz,Irp)-CEnvR(N2,Iz,Irm)) 
     8  +       UA2 *conjg(CEnvR(N1,Iz,Irp)-CEnvR(N1,Iz,Irm)))/twodrm
     9  + conjg(VA1)*     (CEnvR(N2,Iz,Ir)*rmi+CEnvL(N2,Iz,Ir)*DDL2)
     *  +       VA2 *conjg(CEnvR(N1,Iz,Ir)*rmi+CEnvL(N1,Iz,Ir)*DDL1)  )
!-----------------------------------------------------------------------
                   endif ! DoEnv
                 enddo    !N1
               endif !IsPlus
c March tangential and tangential wind forward one minor time step,
c using same denominator 
	      UA(N,I3,Iz,Ir) = (UA(N,I1,Iz,Ir) + DU*twodts)/DEN
	      VA(N,I3,Iz,Ir) = (VA(N,I1,Iz,Ir) + DV*twodts)/DEN
            enddo      !Ir
           enddo      !Iz
 
c Impose boundary conditions
	    call DoBCUV(UA,VA,I2,I3,N,Cgr)

	  enddo        !N

c Apply Asselin-Robert filter to all wavenumbers
          call Robert(UA,VA,HA,I1,I2,I3)

	enddo          !It
	
        return
!---------------------------------------------------------------!
!              VARIABLE DICTIONARY: MARCH			!
!  AK0          Variable horizontal mixing coefficient          !
!  CCen		Complex center velocity				!
!  CCenL	Tangential component of center velocity		!
!  CCenR	Radial component of center velocity		!
!  CEnvL	Tangential component of envir. wind		!
!  CEnvR	Radial component of envir. wind 		!
!  DDL1		Factor for WN1 azimuthal deriveative		!
!  DDL2		Factor for WN2 azimuthal deriveative		!
!  DEN		Denominator for DuFort-Frankel and backwards	!
!               time differencing				!
!  DEN0		Denominator for backward difference only	!
!  DH		Complex depth tendency				!
!  drm		Radial mesh interval in meters			!
!  drm2		Square if radial mesh interval in meters	!
!  dts		Minor time step in seconds			!
!  DU		Complex radial wind tendency			!
!  DV		Complex tangential wind tendency		!
!  E0		Mean-flow inertia parameter			!
!  EN		Floating-point tangential wavenumber		!
!  ENSQ		Square of EN					!
!  Faze		Time dependent part of mass source sink		!
!  HBar0	Time averaged pressure at current grid point	!
!  HBarP	Time averaged pressure at next grid point	!
!  HBarM	Time averaged pressure at last grid point	!
!  HEnv		Environmental height 				!
!  It		Counter for loop over minor time steps		!
!  N		Tangential wavenumber				!
!  NNts		Number of minor time steps per major time step	!
!  Qn		Complex mass source sink 			!
!  Qon		TRUE means mass source sink is nonzero		!
!  rm		Radius in meters				!
!  rmi		Inverse of radius in meters			!
!  rmi2		Inverse square of the radius in meters		!
!  rmm		Radius in meters at previous graid point	!
!  rmp		Radius in meters at next grid point		!
!  RPow		Power of radius needed to calculate environmental
!               streamfunction					!
!  TCen		Time in decimal hours since end of last major	!
!		time step					!
!  TIMEh	Time in decimal hours at the end of the last 	!
!   		major time step					!
!  twodrm 	Twice radial mesh interval in meters		!
!  twodts	Twice the minor time step in seconds		!
!  Z0		Mean-flow absolute vorticity			!
!  C0Env	Axisymmetric environmental-flow			!
!								!
!---------------------------------------------------------------!
	end


        subroutine SwapI(I1,I2,I3)
!-----------------------------------------------------------!
!  Circualrly cycles indices for time levels in leapfrog    !
!  I1: earliest, I2: middle, I3: latest			    !
!-----------------------------------------------------------!
        IStore = I1
        I1 = I2
        I2 = I3
        I3 = IStore
        return

        end


        subroutine Robert(UA,VA,HA,I1,I2,I3)
!-----------------------------------------------------------!
! Loops over all radial mesh points to apply Asselin-       !
! Robert time filter to perturbation depth and wind         !
! components                                                !
!-----------------------------------------------------------!
	parameter (IzMx=2,IrMain=1001,Parm=0.10,Parm0=1.0-2.0*Parm)
        parameter (NMode=3)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1            HA(NMode,3,IzMx,0:IrMain)

        do N = 1, NMode
          do Iz = 1,IzMx
            do Ir = 0, IrMain
              UA(N,I2,Iz,Ir)=Parm0*UA(N,I2,Iz,Ir)
     1                      +Parm*(UA(N,I1,Iz,Ir)+UA(N,I3,Iz,Ir))
              VA(N,I2,Iz,Ir)=Parm0*VA(N,I2,Iz,Ir)
     1                      +Parm*(VA(N,I1,Iz,Ir)+VA(N,I3,Iz,Ir))
              HA(N,I2,Iz,Ir)=Parm0*HA(N,I2,Iz,Ir)
     1                      +Parm*(HA(N,I1,Iz,Ir)+HA(N,I3,Iz,Ir))
            enddo
          enddo
        enddo
        return
        end

	subroutine DoBCH(HA,I2,I3,N,Cgr)
!-----------------------------------------------------------!
! Applies center and outer boundary conditions to           !
! perturbation depth. Near the center H varies as R**N,     !
! where N is tangentail wavenumber. At the domain periphery,!
! perturbations advect out of the domain with the shallow   !
! water gravity wave speed based on the fluid's resting depth
!-----------------------------------------------------------!
	parameter (IzMx=2,IrMain=1001,
     1            NMode=3,IrLast=IrMain-1,
     2             IrInside=IrLast-1,Gee=9.8)
        real Cgr(IzMx)
	complex*8 HA(NMode,3,IzMx,0:IrMain)
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)

c Make indices of inner boundary and first interior points
       if(N .eq. 1)then
        IrFirst = N 
       else
        IrFirst = N + 1
       endif
        IrBound = N

c Apply inner boundary condition
       do Iz = 1,IzMx
         do Ir = 1, IrBound
            HA(N,I3,Iz,Ir) = HA(N,I3,Iz,IrFirst)
     1          *(RADIUS(Ir)/RADIUS(IrFirst))**N
         enddo

c At center point 
	 HA(N,I3,Iz,0) = (0.0,0.0)     !At center point where r=0

c Calculate  outward advection rate
	 COORS = Cgr(Iz)*dts/drm

c Use inward (upstream) difference for boundary condition
	 HA(N,I3,Iz,IrMain) =  
     1   (1.0-COORS)*HA(N,I2,Iz,IrMain) + COORS*HA(N,I2,Iz,IrLast)
       enddo
       return
       end

	subroutine DoBCUV(UA,VA,I2,I3,N,Cgr)
!-----------------------------------------------------------!
! Applies center and outer boundary conditions to           !
! perturbation radial and tangential wind. Near the center, 
! the wind approaches a nondivergent average (V-iU)/2 of    !
! the first interior point winds for wavenumber one and     !
! zero for higher wavenumbers. At the domain periphery,     !
! perturbations advect out of the domain with the shallow   !
! water gravity wave speed based on the fluid's resting depth
!-----------------------------------------------------------!
	parameter (IzMx=2,IrMain=1001,
     1            NMode=3,IrLast=IrMain-1,
     2             IrInside=IrLast-1,
     3             W1=0.90,W2=1.0-W1)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain)
     1            ,eye,UVCen
        real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),Cgr(IzMx)
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	parameter (eye=(0.0,1.0))
c Set up indices near center
       if(N .eq. 1)then
        IrFirst = N 
       else
        IrFirst = N + 1
       endif
        IrBound = N
        IrX = N - 1

c Approximate flow across center
        do Iz = 1,IzMx
          UVCen = 0.5*(VA(N,I3,Iz,IrBound)-eye*UA(N,I3,Iz,IrBound))

	  if (N.eq.1)then

c At center, wavenuber one is uniform flow
	    VA(N,I3,Iz,0) = UVCen
	    UA(N,I3,Iz,0) = eye*UVCen

c At boundary point, use average of uniform flow and adacent point
c	    VA(N,I3,Iz,1) = 0.5*(VA(N,I3,Iz,IrFirst)+UVCen)
c	    UA(N,I3,Iz,1) = 0.5*(UA(N,I3,Iz,IrFirst)+eye*UVCen)

	  else

c At center, wavenumers > one are zero
            VA(N,I3,Iz,0) =  (0.0,0.0)
	    UA(N,I3,Iz,0) =  (0.0,0.0)

c At boundary point, use average of r**(N-1) flow and adacent point
            fac =  (RADIUS(IrBound)/RADIUS(IrFirst))**(N-1)
   	   VA(N,I3,Iz,IrBound) = 0.5*(VA(N,I3,Iz,IrFirst)+fac*UVCen)
	   UA(N,I3,Iz,IrBound) = 0.5*(UA(N,I3,Iz,IrFirst)+fac*eye*UVCen)

c Extrapolate using r**(N-1) variation between center and boundary 
            do Ir = 1, IrX
              fac =  (RADIUS(Ir)/RADIUS(IrFirst))**(N-1)
  	      VA(N,I3,Iz,Ir) = fac*UVCen
	      UA(N,I3,Iz,Ir) = fac*eye*UVCen
            enddo
	  endif

c Calculate  outward advection rate
	  COORS = Cgr(Iz)*dts/drm 

c Use inward (upstream) difference for boundary condition
	  UA(N,I3,Iz,IrMain) = 
     1      (1.0-COORS)*UA(N,I2,Iz,IrMain) + COORS*UA(N,I2,Iz,IrLast)
	  VA(N,I3,Iz,IrMain) = 
     1      (1.0-COORS)*VA(N,I2,Iz,IrMain) + COORS*VA(N,I2,Iz,IrLast)
 
c BC for symmetric vortex
        enddo      ! Iz loop
	return
	end

	subroutine ShoSet(NLU,FCor,BRos,Cgr,Rho,AK,FAK,Njts,IsDyMo,
     1       IsBeta,IsEnv,IsQn,IsNL,IsVORt,IsFt,IsDNM,TDNM,
     2       XCen,IsIC,Y0IC,H0IC,R0IC,WIC,RxIC)
!-----------------------------------------------------------!
! Records parameters of the computation of the file         !
! designated by NLU                                         !
!-----------------------------------------------------------!
	parameter (IzMx=2,NX=2)
        COMMON /STAMP/ FDATE,FTIME,IDString,IDif
	common /TEMP0/TIMEh0,dth
	common /SPONGE/RSPONGE,WSPONGE,DSPONGE
        common /ExMix/Amix,Smix,Incr
        CHARACTER FDATE*9,FTIME*8,IDString*20,IDif*6
	LOGICAL IsBeta,IsEnv,IsNL,IsVORt,IsFt,IsQn,IsDyMo,IsIC,
     1          IsDNM
        complex Y0IC,H0IC
	real*4 XCen(IzMx,2),Cgr(IzMx),Rho(IzMx+1)

c Displays simulation ID, start time, and parameters 
	write(NLU,'('' Simulation: '',A20)')IDString
	write(NLU,'('' Begun at: '',A8,1x,A9)')FTIME,FDATE
        write(NLU,'('' Differencing scheme: '',A6)')IDif 
	TIMEn=TIMEh0+dth*Njts
	write(NLU,'('' Running for '',I6,'' major time steps.'')')Njts
	write(NLU,'('' From hour '',f7.2,'' to hour '',f7.2)')TIMEh0,TIMEn
	write(NLU,'('' Coriolis param = '',g13.6,
     1            ''  Rossby param = '',g13.6)')FCor,BRos

c Displays logical variables that define forcing and initial conditions
	call ShoSwitch(' Beta effect:        ',IsBeta,NLU)
	call ShoSwitch(' Environmental flow: ',IsEnv,NLU)
	call ShoSwitch(' Mass source/sink:   ',IsQn,NLU) 
	call ShoSwitch(' Initial condition:  ',IsIC,NLU) 
	call ShoSwitch(' Dynamic centering:  ',IsDyMo,NLU)
	call ShoSwitch(' Nonlinear Terms:    ',IsNL,NLU) 
	call ShoSwitch(' Prognostic Vortex:  ',IsVORt,NLU) 
	call ShoSwitch(' Prognostic Coriolis:',IsFt,NLU) 
	write(NLU,'('' Diffusion constant:  '',f6.1, '' Sym. Factor: '',
     1    f5.3, '' Ex Mix A,S,I '',2f4.0,I3)')AK,FAK,AMix,SMix,Incr
	write(NLU,'('' Sponge-zone dissipation: '',g13.6)')DSPONGE
 	write(NLU,'('' Sponge zone starts at: '',f10.1,
     1          '' m; transition is '',f10.1, '' m wide. '')')
     2              RSPONGE,WSPONGE      !23FEB95
	write(NLU,'('' Gravity-wave speed(Layer 1,2): '',2g13.6)')Cgr 
	write(NLU,'('' Layer Density (Layer 1,2,3): '',3g13.6)')Rho 
	write(NLU,'('' Initial positions(L1): '',1x,2g13.6)')XCen(1,1),
     1                      XCen(1,2) 
	write(NLU,'('' Initial positions(L2): '',1x,2g13.6)')XCen(2,1),
     1                      XCen(2,2) 

c Displays parameters of initial condition if one is used
        if(IsIC)then
          write(NLU,'('' Initial streamfunction amplitude: ''
     1                   2(1x,g13.6))')Y0IC
          write(NLU,'('' Initial depth amplitude: ''
     1                   2(1x,g13.6))')H0IC
          write(NLU,'('' Transition radius and width: '',
     1                   2(1x,g13.6))')R0IC,WIC
          write(NLU,'('' Outer exponential decay constant: '',
     1                    g13.6)')RxIC
        endif

c Displays parameters of highest--mode damping, if used
        if(IsDNM)then
          write(NLU,'('' Highest mode damping time: '',f7.2,
     1                '' days. '')')TDNM
        endif

c Displays parameters of mass source sink, if used
	call ShoQn(IsQn,NLU)

	return
	end

	subroutine DoDen0(R,dt,DEN0)
!-----------------------------------------------------------!
! Computes denominator for backward time step on Newtonian  !
! dissipation rate. This rate increases on a ramp function  !
! of width WSPONGE from zero to DSPONGE. The denominator is !
! one plus the product of the dissipation  rate with the    !
! time step.	 (Modified 23FEB95)			    !	
!-----------------------------------------------------------!
	parameter(pihaf=1.5707963)
	common /SPONGE/RSPONGE,WSPONGE,DSPONGE
	arg = (R-RSPONGE)/WSPONGE
	if(arg.lt. 0.0)then
	  DEN0 = 1.0 
        else if(arg.lt.1.0)then
	  DEN0 =1.0+DSPONGE*dt*arg**3*(10.0-arg*(15.0-arg*6.0))
	else
	  DEN0 = 1.0+DSPONGE*dt
	endif
	return
	end


	subroutine ShoStep(UA,VA,HA,U0,V0,H0,I1,I2,I3,IS2,IS3,Ijts,
     1                     Ijts0,NSho,NBeg,TIMEh,FCOR,BROS,XRay,DXCen,
     2                     XCen,CCenL,CCenR,QDuff,
     3                     C0Env,CEnvL,CEnvR,HSym,H0Env,HEnv,
     2                     AK,FAK,IsEnv,IsQn,IsIC,IsVORt,IsFt)
!---------------------------------------------------------------------
!234567890123456789012345678901234567890123456789012345678901234567890
!        1         2         3         4         5         6         7
!---------------------------------------------------------------!
!  Displays summaries of the current major time step on 	!
!  "AJAX.log" & trakXXX.out, and displays perturbation height   !
!  and winds plus header information on uvhXXX.out every NSho   !
!  major time steps. Diagnostic variables are computed with     !
!  current UA,VA,HA,and V0, but with U0 and H0 from beginning   !
!  of last step. ie V0 and H0 are not balanced. 21mar02 rwj     !
!---------------------------------------------------------------!  
       parameter(IzMx=2,NX=2,NMode=3,IrMain=1001,IrVor=125,Pi=3.14159,
     1             ItERam=240,IrERam=125,IrSp=IrMain-IrERam,
     2             MERamFlx=IrSp/IrERam,gee=9.8)
	real*4 XRay(IzMx,2,0:NX),XCen(IzMx,2),DXCen(IzMx,2),
     1         C0Env(IzMx,0:IrMain),HSym(IzMx),QDuff(IzMx,0:IrMain)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1           HA(NMode,3,IzMx,0:IrMain),Faze(NMode),
     2           VPr(NMode),UPr(NMode),HPr(NMode),CCen,
     3           CCenR(NMode,IzMx),CCenL(NMode,IzMx),
     4           HEnv(NMode,IzMx,0:IrMain),
     5           CEnvR(NMode,IzMx,0:IrMain),CEnvL(NMode,IzMx,0:IrMain),
     6           RHRay(MERamFlx),RHTot,RHOO,RHN,X1,X2,CEnvT,eye
        real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         RAMRay(MERamFlx),EWavRay(0:NMode,MERamFlx),
     2         FlxLr(0:NMode,MERamFlx),FlxE(0:NMode,MERamFlx),
     3         EWav(NMode),EWavO(NMode),EWavN(NMode),
     4         EnWav(10),EnWavO(10),EnWavN(10),
     5         BMotRay(MERamFlx),H0Env(IzMx,0:IrMain)
        parameter (eye=(0.0,1.0))
	common /LONGS/dtjMs,dtjMs2
	common /TEMP0/TIMEh0,dth
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
	COMMON /MaxiMum/UVMax(NMode,IzMx),HMax(NMode,IzMx),YMax(IzMx),
     1         FlxLrMx(0:NMode,IzMx),FLxEMx(0:NMode,IzMx),
     2         FlxLrMn(0:NMode,IzMx),FLxEMn(0:NMode,IzMx),
     3         EWavMx(0:NMode,IzMx),C2,C2d,C2t,
     4         ALrMx(IzMx),ALrMn(IzMx),BMotMx(IzMx),BMotMn(IzMx)
        common /Diags/QDbeta(IzMx,0:IrMain),QDuaha(IzMx,0:IrMain)
     1           ,QDmix(IzMx,0:IrMain),QDuvh(IzMx,0:IrMain)
     2           ,QDsym(IzMx,0:IrMain),QDfcor(IzMx,0:IrMain)
     3           ,QDuf(IzMx,0:IrMain),QDHsym(IzMx,0:IrMain)
     4           ,QDuv(IzMx,0:IrMain),QDuvhs(IzMx,0:IrMain)
     5           ,QDuvor(IzMx,0:IrMain),QDuvoh(IzMx,0:IrMain)
     6           ,DEN3(IzMx,0:IrMain)
	logical IsEnv,IsQn,Qon,IsIC,IsVORt,IsFt,DoERam,IsNL
	character ctime*8,StartNam*55

c Get current wall-clock time
	call TIME(ctime)

c Reduced diffusion for axisymmetric flow
        AK0 = FAK*AK

c Record environment flow, complex environmental height gradient and XRay's
        If(TIMEh . eq. TIMEh0) then

c Displays parameters of environmental flow, if used
          call ShoEnv(IsEnv,6)
          call ShoEnv(IsEnv,10)
 
c Display complex height gradient
          rm = RADIUS(10)
          X1 = 1000000.*HEnv(1,1,10)/rm
          X2 = 1000000.*HEnv(1,2,10)/rm
          write(6,12)X1,X2
          write(10,12)X1,X2
   12    format(1x,'Complex height grad. L1 L2',4(f8.2,1x),'M/1000Km')

c Set up XRay to reflect environment flow assuming start at zero for L1
c and at upper displaced vortex for L2
         do Iz = 1,IzMx
          do Ix = 0,Nx
            CEnvT = CEnvL(1,Iz,0)
            XRay(Iz,1,Ix) = XCen(Iz,1)+3.6*dth*real(CEnvT)*float(Nx-Ix)   
            XRay(Iz,2,Ix) = XCen(Iz,2)+3.6*dth*aimag(CEnvT)*float(Nx-Ix)   
          enddo
         enddo

c Compute initial track velocity
     	 CCenL(1,1) = -1000.0*CMPLX(XRay(1,1,NX)-XRay(1,1,NX-1),
     1          XRay(1,2,NX)-XRay(1,2,NX-1))/DTJMS
         CCenR(1,1) = eye*CCenL(1,1)
	 CCenL(1,2) = -1000.0*CMPLX(XRay(2,1,NX)-XRay(2,1,NX-1),
     1          XRay(2,2,NX)-XRay(2,2,NX-1))/DTJMS
         CCenR(1,2) = eye*CCenL(1,2)

c Display initial positions on setXXX and ajax.log
       	 write(6,'('' Initial positions (Km), L1, 0-NX, X and Y): '')')
         write(6,'(3(1x,f7.2))')((XRay(1,I,N),N=0,NX),I=1,2)
	 write(6,'('' Initial positions (Km), L2, 0-NX, X and Y): '')')
	 write(6,'(3(1x,f7.2))')((XRay(2,I,N),N=0,NX),I=1,2)
       	 write(10,'('' Initial positions (Km), L1, 0-NX, X and Y): '')')
         write(10,'(3(1x,f7.2))')((XRay(1,I,N),N=0,NX),I=1,2)
	 write(10,'('' Initial positions (Km), L2, 0-NX, X and Y): '')')
	 write(10,'(3(1x,f7.2))')((XRay(2,I,N),N=0,NX),I=1,2)

c Display Print Interval
         Ns = NSho
         Hr = float(Ns)*DTJMS/3600.
         Beg = NBeg*Hr/Ns
       write(6,'('' Print Interval'',i6,'' Steps'',f8.3,'' Hr'',
     1           ''  Beginning at '',f8.3,'' Hr'')')Ns,Hr,Beg
       write(10,'('' Print Interval'',i6,'' Steps'',f8.3,'' Hr'',
     1           ''  Beginning at '',f8.3,'' Hr'')')Ns,Hr,Beg
         Hr = float(ItEram)*DTJMS/3600.
         M = ItEram
       write(6,'('' Diag. Interval'',i4,'' Steps'',f8.3,'' Hr'')')M,Hr
       write(10,'('' Diag. Interval'',i4,'' Steps'',f8.3,'' Hr'')')M,Hr
       endif  !  TIMEh = TIMEh0

c Record on trakXXX.out

c Compute track velocity
     	 CCenL(1,1) = -1000.0*CMPLX(XRay(1,1,NX)-XRay(1,1,NX-1),
     1          XRay(1,2,NX)-XRay(1,2,NX-1))/DTJMS
         CCenR(1,1) = eye*CCenL(1,1)
	 CCenL(1,2) = -1000.0*CMPLX(XRay(2,1,NX)-XRay(2,1,NX-1),
     1          XRay(2,2,NX)-XRay(2,2,NX-1))/DTJMS
         CCenR(1,2) = eye*CCenL(1,2)

c Compute time varying part of mass source sink
        call MakQnT(Faze,Qon,IsQn,TIMEh,TCen)

c Write time, track, motion, and centering information to track file 
      do Iz = 1,IzMx
	write(7,35)Ijts,TIMEh,Iz,XCen(Iz,1),XCen(Iz,2),RMWR(Iz),
     1                   VMaxR(Iz),DXCen(Iz,1),DXCen(Iz,2)
  35	format(1x,I6,1x,f7.3,1x,I1,2(1x,f12.6),2(1x,f6.1),2(1x,f11.6))

c Record time and centering errror on "AJAX.log"
c        if(mod(Ijts,6).eq.0)then
	  write(6,36)Ijts,TIMEh,DXCen(Iz,1),DXCen(Iz,2),ctime
c        endif
      enddo

  36    format(' Tstep: ',I6,', t= ',f8.3,
     1         'h, DXCen: ',g10.3,1x,g10.3,', Clock =',a8)

c compute maximum separation of upper vortex from lower
        C2Sep = SQRT(DXCen(2,1)**2 + DXCen(2,2)**2)
        C2 = AMAX1(C2,C2Sep)
        if(C2 .eq. C2Sep) then
         C2t = TIMEh
         C2d = 0.0
         if(DXCen(2,2) .lt. 0.0) C2d = 180.
         if(DXCen(2,1) .ne. 0.0) then
           C2d = 90. - 180./3.1416*atan(DXCen(2,2)/DXCen(2,1))
           if(DXCen(2,1) .lt. 0.0) then
            C2d = C2d +180.
           endif
         endif
        endif

c Calculate relative angular momentum, kinetic energy and wave fluxes
c integrating radially using the trapezoidal rule. Do every ItERam
c major time steps. Also update restart file.
        if((mod(Ijts,ItEram).eq.0))then

c Initialize RAM, Coriolis torque, and wave energy at level 1
         do Iz = 1,IzMx
 	  RAM = 0.0			
          BMot = 0.0
          RHTot = (0.0,0.0)
	  RamO = 0.0
          BMotO= 0.0
          RHOO = (0.0,0.0)
          do N = 1,NMode
            EWav(N) = 0.0
          enddo
          UPr(1) = UA(1,I3,Iz,0) - CCenR(1,1) + CEnvR(1,Iz,0)
          VPr(1) = VA(1,I3,Iz,0) - CCenL(1,1) + CEnvL(1,Iz,0)
          EWavO(1) = 0.5*H0(Iz,0)*
     1            (UPr(1)*conjg(UPr(1))+VPr(1)*conjg(VPr(1)))
          do N = 2,NMode
            EWavO(N) = 0.0
          enddo

c Loop over gridpoints to calculate RAM, C-torque, & energy
	  do Ir = 1,IrSp
	    RM = RADIUS(Ir)
            Fac = Pi * (RM-0.5*drm)* drm	!Factor for trap rule
	    RamN   = H0(Iz,Ir)*RM*V0(IS3,Iz,Ir)	!New Lr incriment
            RHN = rm*HA(1,I3,Iz,Ir)		!New r times HA increment

c Initialize F term in Coriolis torque
            SUM1 = U0(Iz,Ir)*H0(Iz,Ir)

c Loop over  wavenumbers for F term summation and wave energy
            do N = 1, NMode
          SUM1 = SUM1 + 0.5*real( UA(N,I3,Iz,Ir)*conjg(HA(N,I3,Iz,Ir)))

c Calculate winds in prime coordinates
              UPr(N) = UA(N,I3,Iz,Ir) - CCenR(N,1) + CEnvR(N,Iz,Ir)
              VPr(N) = VA(N,I3,Iz,Ir) - CCenL(N,1) + CEnvL(N,Iz,Ir)
              HPr(N) = HA(N,I3,Iz,Ir) 

c Sum energies
              EWavN(N) = 0.5*(H0(Iz,Ir)*
     1                     (UPr(N)*conjg(UPr(N))+VPr(N)*conjg(VPr(N))) 
     2                     + gee*HPr(N)*conjg(HPr(N))                 )
              EWav(N) = EWav(N) + Fac*(EWavO(N)+EWavN(N))
              EWavO(N)=EWavN(N)
            enddo  !N
 

c Initialize sum for beta term in coriolis torque
         SUM2 = 0.5*real(UA(1,I3,Iz,Ir)*H0(Iz,Ir) + 
     1                   U0(Iz,Ir)*HA(1,I3,Iz,Ir))

c Loop over wavenumbers for beta term
            do N = 2,NMode
              N1 = N-1
              SUM2 = SUM2 + 0.25*real(
     1                   conjg(UA(N1,I3,Iz,Ir))*      HA(N ,I3,Iz,Ir) 
     1                  +      UA(N ,I3,Iz,Ir) *conjg(HA(N1,I3,Iz,Ir))) 
            enddo

c Calculate coriolis torque at new mesh interval
            BMotN = rm*(FCor*SUM1 + rm*BRos*SUM2)

c Sum for integrations of Lr, Coriolis torque, R time HBar
            RAM  = RAM  + Fac*(RamO  + RamN)
            BMot = BMot + Fac*(BMotO + BMotN)
            RHTot= RHTot+ Fac*(RHOO   + RHN)

c Move current values to old values
	    RAMO =  RAMN		   	   
            BMotO = BMotN
            RHOO = RHN

c Check to see if budgets are computed at this radius
            doERam = (mod(Ir,IrERam).eq.0).and.(Ir.ne.0) 
            if(doERam)then

c Save values if so.
              IERamFlx = Ir/IrERam
              RamRay(IERamFlx) = RAM
              BMotRay(IERamFlx)= BMot
              RHRay(IERamFlx)  = RHTot
              EWavRay(0,IERamFlx)=0.0
              do N = 1,NMode
                EWavRay(N,IERamFlx)=EWav(N)
                EWavRay(0,IERamFlx)=EWavRay(0,IERamFlx)+EWav(N)
              enddo 	!N
            endif	!doERam       
          enddo		!Ir

c Latch maximum values
          ALrMx(Iz) = amax1(ALrMx(Iz),RAM)
          ALrMn(Iz) = amin1(ALrMn(Iz),RAM)
          BMotMx(Iz) = amax1(BMotMx(Iz),BMot)
          BMotMn(Iz) = amin1(BmotMn(Iz),BMot)
          do N = 0, NMode
            EWavMx(N,Iz) = amax1(EWavMx(N,Iz),EWavRay(N,MERamFlx))
          enddo

c Loop over radii for budgets
          do IERam = 1, MERamFlx
            Ir = IrERam * IERam
            Irp = Ir + 1
            Irm = Ir - 1
            RM = RADIUS(Ir)
            rmp = rm + drm
            rmm = rm - drm
            Fac = Pi * RM

c Initialize sums for energy and angular momentum fluxes 
            FLxE(0,IERam)=0.0
            FLxLr(0,IERam)= -Fac*AK0*H0(Iz,Ir)*(rmp*V0(Is3,Iz,Irp) -
     1                       rmm*V0(Is3,Iz,Irm))/drm

c Loop over wavenumbers for fluxes
            do N = 1, NMode

c Calculate winds in unprime coordinates
              UPr(N) = UA(N,I3,Iz,Ir) - CCenR(N,1) + CEnvR(N,Iz,Ir)
              VPr(N) = VA(N,I3,Iz,Ir) - CCenL(N,1) + CEnvL(N,Iz,Ir)
              HPr(N) = HA(N,I3,Iz,Ir) 

c Calculate Lr and E fluxes for each wavenumber
              FlxLr(N,IERam)= Fac*RM*
     1                  ( V0(IS3,Iz,Ir)*real(UPr(N)*conjg(HPr(N)))
     2                  + H0(Iz,Ir)    *real(VPr(N)*conjg(UPr(N)))
     3                  + U0(Iz,Ir)    *real(HPr(N)*conjg(VPr(N))))
          FlxE(N,IERam) = gee*Fac*H0(Iz,Ir)*real(UPr(N)*conjg(HPr(N)))

c Sum to get two-mode part of total fluxes
              FLxE(0,IERam) = FLxE(0,IERam) +FLxE(N,IERam)
              FLxLr(0,IERam)= FLxLr(0,IERam)+FLxLr(N,IERam)

c Latch extreme values of fluxes
              FlxLrMx(N,Iz) = amax1(FlxLrMx(N,Iz),FlxLr(N,IERam))
              FlxEMx(N,Iz)  = amax1(FlxEMx(N,Iz), FlxE(N,IERam) )
              FlxLrMn(N,Iz) = amin1(FlxLrMn(N,Iz),FlxLr(N,IERam))
              FlxEMn(N,Iz)  = amin1(FlxEMn(N,Iz), FlxE(N,IERam) )
            enddo 	!N


c Initialize sum for 3-mode part of Lr flux
            SUM1 = 0.0

c Loop over wavenumbers for 3-mode contributions
            do N1 = 1, NMode
              do N2 = 1,NMode

c Calcuate minus the third wave number when first two add
                N3 = N1 + N2

c Find plus-plus-minus interactions
                if (N3.le.NMode)then
                  SUM1 = SUM1 + 
     1                   0.5*real(HPr(N1)*UPr(N2)*conjg(VPr(N3)) )
                endif

c Calculate minus the third wavenumber when first two subtract
                N3 = N1 - N2

c Find plus-minus-minus interactions
                if(N3.gt.0)then
                  SUM1 = SUM1 + 
     1                  0.5*real(HPr(N1)*conjg(UPr(N2)*VPr(N3)) )
                endif	!N3>0

c Find plus-minus-plus interactions
                if(N3.lt.0)then
                  N3 = abs(N3)
                  SUM1 = SUM1 + 
     1                  0.5*real(HPr(N1)*conjg(UPr(N2))*VPr(N3) )
                endif	!N3<0
              enddo	!N2
            enddo	!N1

c Calculate Lr flux
c H0 and V0 are not balanced unless IS2 is used for V0  !21mar02
            FlxLr(0,IERam) = FlxLr(0,IEram) + 
     1            Fac*RM*(2.0*H0(Iz,Ir)*U0(Iz,Ir)*V0(IS3,Iz,Ir)+SUM1)
          enddo 	!IERam

c Find extreme energy and angular momentum fluxes
          do IERam = 1, MERamFlx
            FlxLrMx(0,Iz) = amax1(FlxLrMx(0,Iz),FlxLr(0,IERam))
            FlxEMx(0,Iz)  = amax1(FlxEMx(0,Iz), FlxE(0,IERam) )
            FlxLrMn(0,Iz) = amin1(FlxLrMn(0,Iz),FlxLr(0,IERam))
            FlxEMn(0,Iz)  = amin1(FlxEMn(0,Iz), FlxE(0,IERam) )
          enddo

c Write output to .diag file
    	  write(9,34)Ijts,TIMEh,FCor,HSym,H0(1,1),H0(2,1)
  34	  format(1x,I6,1x,f7.3,1x,5(g13.6))
          write(9,33)(RamRay(IERam),IERam=1,MERamFlx)
          write(9,33)(BMotRay(IERam),IERam=1,MERamFlx)
          write(9,33)(RHRay(IERam),IERam=1,2)
          write(9,33)(RHRay(IERam),IERam=3,4)
          write(9,33)(RHRay(5),CCenL(1,1))
  33      format(3x,5(1x,g13.6))
          do N = 0, NMode
            write(9,32)N,(EWavRay(N,IEram),IEram=1,MEramFlx)
            write(9,32)N,(FlxLr(N,IEram),IEram=1,MEramFlx)
            write(9,32)N,(FlxE(N,IEram),IEram=1,MEramFlx)
          enddo
  32      format(1x,I2,5(1x,g13.6))


c Initialize wave energy at level 1
          do N = 1,10
            EnWav(N) = 0.0
          enddo
          UPr(1) = UA(1,I3,Iz,0) 
          VPr(1) = VA(1,I3,Iz,0) 
          EnWavO(1) = 0.5*H0(Iz,0)*
     1            (UPr(1)*conjg(UPr(1))+VPr(1)*conjg(VPr(1)))
          do N = 2,10
            EnWavO(N) = 0.0
          enddo

c Loop over gridpoints to calculate energy for 2000 km domain 
          Ir2000 = 500
	  do Ir = 1,Ir2000
	    RM = RADIUS(Ir)
            Fac = Pi * (RM-0.5*drm)* drm	!Factor for trap rule

c Loop over  wavenumbers for F term summation and wave energy
            do N = 1, NMode

c Recover winds and heights
              UPr(N) = UA(N,I3,Iz,Ir)
              VPr(N) = VA(N,I3,Iz,Ir)
              HPr(N) = HA(N,I3,Iz,Ir)

c Sum energies
              EnWavN(N) = 0.5*(H0(Iz,Ir)*
     1                     (UPr(N)*conjg(UPr(N))+VPr(N)*conjg(VPr(N))) 
     2                     + gee*HPr(N)*conjg(HPr(N))                 )
              EnWav(N) = EnWav(N) + Fac*(EnWavO(N)+EnWavN(N))
              EnWavO(N)=EnWavN(N)

c Also look for maximum wind, height components
	      UVMax(N,Iz) = AMAX1( UVMax(N,Iz),ABS(REAL(UA(N,I3,Iz,Ir)))
     1                          ,ABS(AIMAG(UA(N,I3,Iz,Ir)))
     2                          ,ABS(REAL(VA(N,I3,Iz,Ir)))
     3                          ,ABS(AIMAG(VA(N,I3,Iz,Ir))) )
	      HMax(N,Iz) = AMAX1( HMax(N,Iz),ABS(REAL(HA(N,I3,Iz,Ir)))
     1                        ,ABS(AIMAG(HA(N,I3,Iz,Ir))) )
            enddo  !N

          enddo		!Ir

          write(20,41)TIMEh,(EnWav(N),N=1,5)
          write(21,41)TIMEh,(EnWav(N),N=6,10)
         enddo         !Iz

   41     format(1x,f7.3,5(1x,g13.6))

        endif   ! mod(Ijts,ItERam)=0

c Is it time to display perturbation variables yet?
	if((Ijts.ne.Ijts0).and.(mod(Ijts,NSho).eq.0).and.Ijts.ge.NBeg
     1     .or.((Ijts.eq.Ijts0).and.IsIC))then

c Open UVH output files
          call OpenUVH(.FALSE.,.FALSE.)

c Loop over wavenumbers
          do N = 0,NMode
            ILU= 30 + N

c Write header and loop over layers
	   call ShoFlag(ILU)
	    write(ILU,'(1x,I6,1x,f8.3,1x,f6.1,1x,4(F10.3,1x))')
     1           Ijts,TIMEh,drm,XCen(1,1),XCen(1,2),XCen(2,1),XCen(2,2)
	    write(ILU,'(5(1x,g13.6),i3)')CCenL(1,1),FCOR,
     1                                   BROS,C0Env(1,25),N
	    write(ILU,'(4(1x,g13.6))')0.0,0.0,0.0,0.0
            do In = 1, Nmode
	      write(ILU,'(4(1x,g13.6))')CEnvL(In,1,0),CEnvL(In,2,0)
            enddo

c Loop over radial grid points write variables
           do Iz = 1,IzMx 

c U0,V0 and H0 are at beginning of last step, UA,VA,HA are at the end
	    do Ir = 0, IrMain
              R = RADIUS(Ir)
	      Rkm = 0.001*R
              if(N.eq.0)then 
  	      rm = amax1(R,1.0)
                write(ILU,20)Ir,Rkm,U0(Iz,Ir),V0(IS2,Iz,Ir),H0(Iz,Ir)
     1                      ,V0(IS2,Iz,Ir)/rm,QDuff(Iz,Ir)
                write(ILU,22)QDuv(Iz,Ir),QDuvor(Iz,Ir),QDuvoh(Iz,Ir)
     1                      ,QDuf(Iz,Ir),QDsym(Iz,Ir),QDfcor(Iz,Ir)
     2                      ,QDmix(Iz,Ir),QDbeta(Iz,Ir),Den3(Iz,Ir)
     3                      ,QDuvh(Iz,Ir)
              else
                write(ILU,21)Ir,Rkm,UA(N,I3,Iz,Ir),VA(N,I3,Iz,Ir)
     1                             ,HA(N,I3,Iz,Ir)

              endif

            enddo   !Ir
           enddo   !Iz
	  enddo   !N
          call CloseUVH
	endif

 20     format(1x,I4,1x,f6.0,2(1x,f11.7),1x,f11.4,1x,g11.4,1x,1p,g12.5)
 21     format(1x,I4,1x,f6.0,1p,6(1x,g14.7))
 22     format(1x,1p,8(g12.5,1x),0p,F12.8,1x,1p,g12.5)
	return
	end

	subroutine ShoSwitch(String,Switch,NLU)
!---------------------------------------------------------------!
!  Displays a logical variable as 'ON' when it is true and 'OFF'!
!  when it is false--with an identifying string		!
!---------------------------------------------------------------!
	character String*20
	logical switch
	if(Switch)THEN
           write(NLU,'(A20,'' ON'')')String
	ELSE
	   write(NLU,'(A20,'' OFF'')')String
	ENDIF
	RETURN
	END

	subroutine RFix
!---------------------------------------------------------------!
!  Change the result of function RADIUS to be meters instead of !
!  kilometers.							!
!---------------------------------------------------------------!  
	common /DMAIN/ dR
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	dR = drm
	return
	end

	subroutine RUnFix
!---------------------------------------------------------------!
!  Change the result of function RADIUS to be km  instead of 	!
!  meters.							!
!---------------------------------------------------------------!  
	common /DMAIN/ dR
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	dR = 0.001*drM
	return
	end

	subroutine ShoVor(NLU,U0,V0,H0,UA,VA,HA,IS2,AK,FAK,
     1                   IsShoVor,IsGau,IsRNK,IsMRnK)
!---------------------------------------------------------------!
! Displays vortex parameters, structure (if IsShoVor is TRUE) on!
! file designated by NLU. Calculates relative angular momentum 	!
! and diplays it.						!
!---------------------------------------------------------------!
	parameter (IzMx=2,IrMain=1001,Pi=3.14159,IrVor=125,NMode=3)
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
	common /STRUC/VORP1(IzMx),VORP2(IzMx),IsExp(IzMx),xV,V9(IzMx)
     1               ,A9(IzMx),Del(IzMx),Alph(IzMx)
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /DMAIN/ dR
        common /ExMix/Amix,Smix,Incr
	logical IsShoVor,IsExp,IsGau,IsRNK,IsMRnK
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain)
     1         ,AK0(IzMx,0:IrMain)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1            HA(NMode,3,IzMx,0:IrMain)
	parameter(eps=0.0001)


        do Iz = 1,2
        do Ir = 0,IrMain
          AK0(Iz,Ir) = FAK*AK
        enddo
        enddo

c Find maximun wind radius for upper and lower vortices and enhance mixing


        do Iz = 1,2
         drk = drm/1000.
         RMaxW = RMWR(Iz)
         if(RMW(Iz) .gt. RMWR(Iz)) RMaxW = RMW(Iz)
        LpIndx = RMaxW/drk
        LpIndx = LpIndx - Incr
        do i = 1,LpIndx
          AK0(Iz,i) = Smix*AK0(Iz,i)
        enddo
          AK0(Iz,LpIndx+1) = Smix*.8*AK0(Iz,LpIndx+1)
          AK0(Iz,LpIndx+2) = Smix*.6*AK0(Iz,LpIndx+2)
          AK0(Iz,LpIndx+3) = Smix*.4*AK0(Iz,LpIndx+3)
          AK0(Iz,LpIndx+4) = Smix*.2*AK0(Iz,LpIndx+4)
        enddo



        AK0(1,0) = 0.0
        AK0(2,0) = 0.0
c        AK0(1) = AK0(1)*10.
c        AK0(2) = AK0(2)*10.
c        AK0(3) = AK0(3)*10.
c        AK0(4) = AK0(4)*8.
c        AK0(5) = AK0(5)*6.
c        AK0(6) = AK0(6)*4.
c        AK0(7) = AK0(7)*2.

c Write vortex structure to file if appropriate
	if(IsShoVor)then
	  call ShoFlag(NLU)
          do Iz = 1,IzMx
           do Ir = 0, IrMain
            R = RADIUS(Ir)
	    rm = amax1(R,1.0)
	    R = 0.001*R
            call DoDen0(rm,twodts,DEN0)
            DEN = DEN0 + AK0(Iz,Ir)*twodts*(1.0/drm2+0.5/(rm*rm))
            write(NLU,10) Ir,R,U0(Iz,Ir),V0(IS2,Iz,Ir),H0(Iz,Ir),
     1                      V0(IS2,Iz,Ir)/rm,DEN
	  enddo
         enddo
10	  Format(1X,I4,1x,f6.0,1x,f4.1,1x,f11.7,1x,f11.4,
     1                         1x,g10.3,1x,f10.8)
          call ShoFlag(NLU)
          do Iz = 1,IzMx
           do Ir = 0, IrMain
            R = RADIUS(Ir)
	    rm = amax1(R,1.0)
	    R = 0.001*R
            write(NLU,11) Ir,R,UA(1,1,Iz,Ir),VA(1,1,Iz,Ir),
     1                    HA(1,1,Iz,Ir)
	  enddo
         enddo
11	  Format(1X,I4,1x,f6.0,6(1x,g14.7))
        else
c Write parameters to file
c Compute max wind and radius for Rankine vortex
          RMWR(1) = 0.0
          VMaxR(1) = 0.0
          RMWR(2) = 0.0
          VMaxR(2) = 0.0
          do Iz = 1,IzMx
          do Ir = 0,IrMain
            if(V0(1,Iz,Ir) .gt. V0(1,Iz,Ir-1)) then
              VMaxR(Iz) = V0(1,Iz,Ir)
              RMWR(Iz) = RADIUS(Ir)/1000.
            endif
          enddo
          enddo
	write(NLU,'('' Central latitude: '',f7.3)')aLAT
        write(NLU,'('' RMW1: '',f5.1,'' VMax1: '',f5.1)')RMW(1),VMax(1)
        write(NLU,'('' RMW2: '',f5.1,'' VMax2: '',f5.1)')RMW(2),VMax(2)
       if(IsRNK) then
      write(NLU,'('' RMW1: '',f5.1,'' VMax1: '',f7.3)')RMWR(1),VMaxR(1)
      write(NLU,'('' RMW2: '',f5.1,'' VMax2: '',f7.3)')RMWR(2),VMaxR(2)
       endif
        write(NLU,'('' Boundary fluid depth L1 & L2: '',2(g13.6))')DEPTH
        write(NLU,'('' Center fluid depth L1 & L2: '',2(g13.6))')
     1                 H0(1,0),H0(2,0)
	write(NLU,'('' Vortex radius: '',f7.1,
     1          ''Domain radius: '',f7.1)'),RVor,RMain
	write(NLU,'('' drm = '',g13.6)')drm
            if(IsGau)then
	write(NLU,'('' Gaussian vortex Mallen et al 2004 '')')
            else if(IsExp(1))then
	write(NLU,'('' Vortex has smoothed 1st order discontinuity ''
     1                     ''at Rmax '')')
	write(NLU,'('' Power-law exponent in inner vortex L1 & L2: '',
     1                     2(f5.2))')VORP2
	write(NLU,'('' Exponential decay length L1:'',f10.2,
     1              '' L2'',f10.2)')VORP1(1)*RMW(1),VORP1(2)*RMW(2)
            endif
            if(.not.IsGau .and. .not.IsExp(1) .and. .not.IsRNK
     1          .and. .not. IsMRnK) then
	write(NLU,'('' Ooyama vortex '')')
            endif
        if(IsRNK) then 
         write(NLU,'('' Smoothed Rankine Vortex, Del: '',2(f7.3))')Del
        endif
        if(IsMRnK) then 
           write(NLU,'('' Modified Rankine Vortex, Alph: '',2(f7.3))')
     1                  Alph
        endif
c Present program does not support Lr0 vortex or anticyclone 08 Jul 04
c            if(.not.IsRNK)then
c             if((.not.IsExp(2)).or.(V9(2).gt.eps))then
c	write(NLU,'('' Power-law exponent in outer vortex: ''
c     1                   ,f5.2)')xV
c             endif
c    	     if(IsExp(1) .and. .not.IsExp(2))then
c	write(NLU,'('' Exponential decay length L1:'',f10.2)')
c     1                       VORP1(1)*RMW(1)
c             endif
c            else
c	write(NLU,'('' Rankine Vortex Is Used'')')
c            endif

        write(NLU,'('' Maximum anticyclonic wind L1: '',f5.2, 
     1            '' at radius: '',f6.1)')V9(1)*VMax(1),A9(1)*RMW(1)
        write(NLU,'('' Maximum anticyclonic wind L2: '',f5.2, 
     1            '' at radius: '',f6.1)')V9(2)*VMax(2),A9(2)*RMW(2)
             TVor = IrVor*drm/1000.
	write(NLU,'('' Vortex tracking radius Km: '',f7.1)')TVor


c Calculate relative angular momentum integrating radially using
c the trapezoidal rule
            do Iz = 1,IzMx
      	    RAM = 0.0	                !Initialize RAM and
	    AnRamO = 0.0		!previous grid point value
	     do Ir = IrVor, 0, -1	!loop over grid points
	      RM = RADIUS(Ir)		!make radius
	      AnRamN = H0(Iz,Ir)*RM*RM*V0(IS2,Iz,Ir) !RAM at current grid point
              RAM = RAM + Pi*dR*(AnRamO + AnRamN) !Sum for integration
	      AnRAMO = AnRAMN		!Current point becomes previous
					! point for next iteration
	     enddo
             if(Iz .eq. 1) then
               write(NLU,'('' RAM1 = '',g13.6)')RAM !Write RAM to file
             else
               write(NLU,'('' RAM2 = '',g13.6)')RAM !Write RAM to file
             endif
            enddo 
        endif
	return
	end

	subroutine ReadSet(Njts,XRay,XCen,IsDyMo,FCor0,FCor
     *          ,XCen0,BRos,Cgr,Rho,AK,FAK
     1          ,TIMEh,Ijts0,NSho,NBeg,IsBeta,IsEnv,IsQn,IsRead
     2          ,IsShoVor,IsIC,IsNL,IsVORt,IsFt,IsGau,IsDNM,TDNM,IsRNK
     3          ,IsMRnK,Y0IC,H0IC,R0IC,WIC,RxIC)

!---------------------------------------------------------------!
! Reads problem setup from ajaxXXX.dat				!
!---------------------------------------------------------------!
	parameter(IzMx=2,NX=2,IrMain=1001,NMode=3)
	parameter(F0=1.4584E-04,RadDeg=0.0174533,REarth=6371000.0) 
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
	common /STRUC/VORP1(IzMx),VORP2(IzMx),IsExp(IzMx),xV,V9(IzMx)
     1               ,A9(IzMx),Del(IzMx),Alph(IzMx)
	common /DMAIN/ dR
	common /TEMP0/TIMEh0,dth
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /LONGS/dtjMs,dtjMs2
	common /SPONGE/RSPONGE,WSPONGE,DSPONGE
        COMMON /STAMP/ FDATE,FTIME,IDString,IDif
	COMMON /MaxiMum/UVMax(NMode,IzMx),HMax(NMode,IzMx),YMax(IzMx),
     1         FlxLrMx(0:NMode,IzMx),FLxEMx(0:NMode,IzMx),
     2         FlxLrMn(0:NMode,IzMx),FLxEMn(0:NMode,IzMx),
     3         EWavMx(0:NMode,IzMx),C2,C2d,C2t,
     4         ALrMx(IzMx),ALrMn(IzMx),BMotMx(IzMx),BMotMn(IzMx)
        common /RUDID/RunID,FloID
        common /ExMix/Amix,Smix,Incr
        CHARACTER FDATE*9,FTIME*8,IDString*20,IDif*6,
     1      RunID*10,FloID*10,DataName*50
	real*4 XRay(IzMx,2,0:NX),XCen(IzMx,2),XCen0(2),Rho(3),Cgr(IzMx)
	LOGICAL IsBeta,IsEnv,IsNL,IsQn,IsRead,IsShoVor,IsDyMo,IsIC
     1          ,IsVORt,IsFt,IsDNM,IsExp,IsGau,IsRNK,IsMRnK
        complex Y0IC,H0IC

c Set up date/time stamp and differencing scheme ID
        CALL DATE(FDATE) 
        CALL TIME(FTIME)
        Write(Idif,'(''NJAXN'',I1)')NMode

c Define and open set-up data file
        IDX = index(RunID,' ')-1
        DataName='al0:[hrd.rjones.troy]AJAX'//
     1            RunID(:IDX)//'.DAT'
        open(5,access='SEQUENTIAL',form='FORMATTED',
     1       status='OLD',err=99,iostat=IOS,file=DataName)

c Read in set-up parameters
	read (5,*)Vmax,V9,aLAT,Depth,xV
	read (5,*)RMW,RVor,RMain,VORP1,VORP2,Del,Alph,IsExp
	read (5,*)TIMEh0,Nnts,dts,Ijts0,Njts,NSho,NBeg
	read (5,*)AK,FAK,DSPONGE,WSPONGE,Rho 
 	read (5,'(A20)')IDString
	read (5,*)IsBeta,IsEnv,IsQn,IsIC,IsRead,
     1            IsShoVor,IsDyMo,IsNL,IsVORt,IsFt,IsGau,IsRNK,IsMRnK
        read (5,*)AMix,SMix,Incr,H0ICI,R0IC,WIC,RxIC
        Y0ICR = 0.0  !These 4 data are no longer inputed, 11 Nov 09 RWJ 
        Y0ICI = 0.0  !Space is now used for enhanced inner core mixing
        H0ICR = 0.0
        H0ICI = 0.0
        Y0IC = cmplx(Y0ICR,Y0ICI)
        H0IC = cmplx(H0ICR,H0ICI)
	TIMEh = TIMEh0
        NBeg = NBeg*NSho


c Set up temproral and spatial differencing intervals
	dR = RMain/(FLOAT(IrMain)-0.5)
	drm = 1000.0*dR
	twodrm = 2.0*drm
	drm2 = drm*drm
	twodts = 2.0*dts
	dtjMs =Nnts*dts
	dtjMs2 = dtjMs*dtjMs
	dth = dtjMs/3600.

c Set up sponge annulus dimen in m
	RSPONGE = 1000.0*(RMain - 2. - WSPONGE) !07SEP01
	WSPONGE = 1000.0*WSPONGE
        SIG121 = 9.8*(Rho(1) - Rho(2))/Rho(1)
        SIG131 = 9.8*(Rho(1) - Rho(3))/Rho(1)
        SIG232 = 9.8*(Rho(2) - Rho(3))/Rho(2)
        bee = SIG131*Depth(1) + SIG232*DEPTH(2)
        ac = SIG232*SIG121*DEPTH(1)*DEPTH(2)
	Cgr(1) = SQRT(0.5*(bee - SQRT(bee**2 - 4.*ac)))
        Cgr(2) = SQRT(0.5*(bee + SQRT(bee**2 - 4.*ac)))

c Read in initial position for upper layer displaced vortex
	read(5,*)((XRay(2,J,I),I = 0, NX),J = 1, 2)


c Read highest--mode dissipation parameters
        read(5,*)IsDNM,TDNM

c Read mass source-sink and environmnetal flow parameters
	call ReadQn
	call ReadEnv

c Initialize Coriolis, Rossby parameters
	FCor0 = F0 * SIN(RadDeg * aLAT)
        FCor=FCor0
	if(IsBeta)then
	  BRos = F0 * COS(RadDeg * aLAT)/REarth
	else
	  BRos = 0.0
	endif

c Initialize values of maximum perturbation quantities
       do Iz = 1,IzMx
       do N = 1,NMode
	UVMax(N,Iz) = 0.0
	HMax(N,Iz) = 0.0
       enddo
	YMax(Iz) = 0.0
        BMotMx(Iz) = -1.0E30
        BMotMn(Iz) =  1.0E30
        ALrMx(Iz) = -1.0E30
        ALrMn(Iz) =  1.0E30
        do N = 0, NMode
          FlxLrMx(NMode,Iz) = -1.0E30
          FlxLrMn(Nmode,Iz) =  1.0E30
          FlxEMx(NMode,Iz) = -1.0E30
          FlxEMn(Nmode,Iz) =  1.0E30
          EWavMx(NMode,Iz) = -1.0E30
        enddo
       enddo    !Iz
        close(5)
	return
 99     write(6,'('' Error in opening setup file. '')')
        write(6,'('' IO status = '',I3)')IOS
        stop 99
!-----------------------------------------------------------------------!
!		VARIABLE DICTIONARY: READSET				!
!									!
!  AK		Diffusion coefficient					!
!  ALat		Central latitude for Coriolis and Rossby parameters	!
!  AMix         Asymmetric mixing factor for inner core                 !
!  BRos		Rossby parameter					!
!  Cgr		Shallow water gravity-wave speed			!
!  DEPTH	Resting depth of fluid					!
!  DR 		Radial mesh interval (km)				!
!  drm		Radial mesh interval in meters				!
!  drm2		Square of the radial mesh interval in meters		!
!  DSPONGE	Maximum Newtonian disspation rate in the sponge annulus !
!  dth		Major time step in hours				!
!  dtjms	Major time step in seconds				!
!  dtjms2	Square of major time step in seconds			!
!  dts		Minor time step in seconds				!
!  FAK          Factor for diffusion coefficient for symetric vortex    !
!  FCor		Coriolis parameter					!
!  FDATE	Wall-clock date on which the simulation began		!
!  FTIME	Wall-clock time at which the simulation began		!
!  HOIC		Complex amplitude of initial height perturbation	!
!  HOICI	Imaginary part of HOIC					!
!  HOICR	Real part of HOIC					!
!  HMax		Maximum perturbation height				!
!  IDif		String identifying time marching or wave truncation     !
!  IDString	String identifying simulation				!
!  Ijts0	Number of first time step				!
!  Incr         Inner core extra mixing ends at Rmax - Incr + 4 points  !   
!  IrMain	Maximum index for radial grid				!
!  IrVor	Index at which the vortex goes to zero			!
!  IsBeta       TRUE means beta effect active				!
!  IsDymo       TRUE means dynamic centering active             	!
!  IsEnv        TRUE means environmental flow active            	!
!  IsNL         TRUE means nonlinear terms active                       !
!  IsIC         TRUE means initial condition active             	!
!  IsQn         TRUE means mass source-sink active			!
!  IsGau        TRUE means that Gaussian vortex is used (Mallem)        !
!  IsRNK        TRUE means Rankine vortex at both levels                !
!  IsRead       TRUE means read IC from file (not implemented)  	!
!  IsShoVor     TRUE means mean vortex written to diagnostic file	!
!  Ix		Index for loop over initial positions			!
!  Njts		Number of major time steps simulated            	!
!  Nnts		Number of minor time steps in a majot time step         !
!  NSho		Number of major time steps between output to    	!
!		uvhXXX.out file						!
!  NBeg         Integer multiple of NSho where uvhXXX output begins     !
!  ROIC		Radius of max streamfunction and depth in IC 		!
!		cartoons						!
!  RMain	Radius of the domain					!
!  RMW		Radius of maximim wind in km				!
!  RVor		Outer bound of the vortex in km				!
!  RxIC		Exponential decay constant in outer tail of IC		!
!  SMix         Symmetric mixing factor for inner core                  !
!  TCen		IN THIS ROUTINE time before initial time for finding	!
!		initial positions on predefined track			!
!  TIMEh	Time in hours at the end of major time steps		!
!  TIMEh0	Initial time in hours					!
!  twodrm	Twice radial mesh interval in meters			!
!  twodts	Twice minor time step in seconds			!
!  UVMax	Maximum perturbation wind component			!	
!  VMax		Maximum tangential wind in m/s				!
!  VORP2	Second derivative of V0 near RMW			!
!  V9		Maximum anticyclonic wind (N/D)				!
!  WIC		Width of quadratic transition in initial condition	!
!  WSPONGE	Width of the sponge annulus in meters			!
!  xV		Exponent for wind profile in outer vortex		!
!  YOIC		Complex amplitude of initial stramfunction		!
!  YOICI	Imaginary part of YOIC					!
!  YOICR	Real part of YOIC					!
!  YMax		Maximum perturbation streamfunction			!
!-----------------------------------------------------------------------!
	end

	subroutine ReadQn
!---------------------------------------------------------------!
! Reads parameters for mass source-sink from "dapXXX.dat"	!
!---------------------------------------------------------------!
	parameter (IzMx=2,NMode=3)
	complex Q0(NMode)
	common /QCOMMT/FreQ,TQST,TQRI,TQND
	common /QCOMMR/Q0,RQ,AQ
	read (5,*)FreQ,TQST,TQRI,TQND
	read (5,*)RQ,AQ
	do N=1,Nmode
	 read (5,*)AR,AI
         Q0(N) = cmplx(AR,AI)
	enddo
	return
!---------------------------------------------------------------!
!              VARIABLE DICTIONARY: READQN			!
!  AQ	Radial width of mass source sink			!
!  FreQ Rotation frequency of mass source sink			!
!  N	Tangential wave number					!
!  Q0	Complex amplitude of mass source sink for each tangential
!       wavenumber						!
!  RQ   Radius of the center of the mass source sink		!
!  TQND	Time in h when mass source sink turns off		!
!  TQRI	Rise time in h for mass source sink 			!
!  TQST	Time in h when mass source sink turns on		!
!---------------------------------------------------------------!
	end 

	subroutine ShoQn(IsQn,NLU)
!---------------------------------------------------------------!
!  Displays parameters of mass source sink on file designated 	!
!  by NLU							!
!---------------------------------------------------------------!
	parameter (IzMx=2,NMode=3)
	complex Q0(NMode)
	common /QCOMMT/FreQ,TQST,TQRI,TQND
	common /QCOMMR/Q0,RQ,AQ
	logical IsQn
	if(IsQn)then
	 write (NLU,'('' Mass source-sink''/ '' Frequency: '',f6.2)')FreQ
	 write (NLU,'('' Half width: '',g10.3,
     1         '' Central radius: '',g10.3)')AQ,RQ
	 write (NLU,'('' Start, rise, and end times:'',3(1x,f7.3))')
     1                            TQST,TQRI,TQND
	 write (NLU,'(5x,''Amplitudes: '')')
	 do N = 1,NMode
	   write (NLU,'(1x,I2,'':'',2(1x,f8.5))')N,Q0(N)
	 enddo
	endif
	return
	end 

	subroutine MakQnT(Faze,Qon,IsQn,TIMEh,TCen)
!---------------------------------------------------------------!
!  Calculates time dependent part of mass source sink, screens  !
!  out times before switched on or after switched off		!
!---------------------------------------------------------------!
        parameter(IzMx=2,NMode=3)
	complex Faze(NMode),CX
	common /QCOMMT/FreQ,TQST,TQRI,TQND
	logical Qon
	if(IsQn)then

c Calculate time in h of this minor time step
  	  TIME = TIMEh + TCen

c TRUE means time is after start but not after end
	  Qon = (TIME.GT.TQST).AND.(TIME.LT.TQND)

c Calcuate time variation 
	  if(Qon)then

c Linear rise
	    if(TIME.LT.TQST+TQRI)then
	      fac = (TIME-TQST)/TQRI

c Linear fall
	    else if(TIME.GT.TQND-TQRI)then
	      fac = (TQND-TIME)/TQRI

c Steady between rise and fall
	    else
	      fac = 1.0
	    endif

c Calculate rotation
            CX = cexp(cmplx(0.0,FreQ*(TIME-TQST)))
            do N = 1, NMode
	      Faze(N)=fac*CX**N
            enddo 
	  else
            do N = 1, NMode
	      Faze(N) = (0.0,0.0)
            enddo
          endif
        endif
	return
	end

	subroutine MakQnR(N,Qn,rm,Faze,Qon)
!---------------------------------------------------------------!
!  Combines spatial variation with  time dependent part of mass !
!  source sink, if time is after swithed on and before switched !
!  off								!
!---------------------------------------------------------------!
	parameter (IzMx=2,NMode=3,pi=3.14159)
	complex Q0(NMode),Faze(NMode),Qn,FazFac
	common /QCOMMR/Q0,RQ,AQ
	logical Qon

c Zero mass source sink initially and overwrite it with
c proper values if time is after start and before end and
c source sink is active
	Qn = (0.0,0.0)

c Turned on and time such that source-sink nonzero?
	if(Qon)then

c Calculate argument for spatial variation
  	  arg = (rm-RQ)/AQ

c Radius inside annulus source-sink occupies?
	  if(ABS(arg).LT.1.0)then

c Calculate radial structure
	    amp = 0.5*(1.0+cos(pi*arg))

c Multiply structure with wavenumber amplitudes and
c time variation
	    Qn = amp*Q0(N)*Faze(N)

          endif
        endif
	return
	end

	subroutine VorSet(U0,V0,H0,Rho,FCor,HSym,IsRead,IsGau,IsRNK,
     1                    IsMRnK)
	parameter (eps=1.0e-05,GeeHaf=0.5/9.8)
        parameter (IzMx=2,IrMain=1001,IrVor=125)
        CHARACTER FDATE*9,FTIME*8,IDString*20,IDif*6
	common /DIMPAR/RMW(IzMx),RMWR(IzMx),RVor,RMain,VMax(IzMx)
     1           ,VMaxR(IzMx),aLAT,DEPTH(IzMx)
	common /STRUC/VORP1(IzMx),VORP2(IzMx),IsExp(IzMx),xV,V9(IzMx)
     1               ,A9(IzMx),Del(IzMx),Alph(IzMx)
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
        COMMON /STADT/ FDATE,FTIME,IDString,IDif
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         HSym(IzMx),Rho(IzMx+1),Z(IzMx,0:IrMain)
        logical IsExp,IsLr0,IsRead,IsGau,IsRNK,IsOo,IsMRnK

c Return at once if reading a restart
	if(IsRead)RETURN

        IsOo = .False.

c Identify mean vortex
        IDif = 'VortN '

c Set up sigma's
       Sig11 = (Rho(1) - Rho(2))/Rho(1)
       Sig12 = (Rho(2) - Rho(3))/Rho(1)
       Sig22 = (Rho(2) - Rho(3))/Rho(2)

c Loop over 2 layers
       Do Iz = IzMx,1,-1
c Set up boundaries of eye, eyewall, and outer regions
        IsLr0 = V9(Iz).ge.eps
c This option will not work as presently configured 8 Jul 04  ie no power law
        cc = RVor/RMW(Iz)
        if(IsLr0)then
          POW = (V9(Iz)/(1.0+V9(Iz)))**(1.0/xV)
          A9(Iz) = (cc + POW)/(1.0+POW)
        else
          A9(Iz) = cc
        endif
        if((.not.IsExp(Iz)).or.IsLr0)then
          WW = 1.0/(1.0 + (A9(Iz)-1.0)*VORP2(Iz)/((1.0+V9(Iz))*xV))
	else
          WW = 1.0/(1.0+VORP1(Iz)*VORP2(Iz))
        endif
        call findx(WW,XX)
        aa = 1.0-XX
        bb = 2.0-XX
c remove ramp function and have first order discontinuity at RMax 
          aa = 1.0
          bb = 1.0
        write(6,'(3(2x,f10.3))')aa,bb,cc

c Calculate mean swirling wind as a function of radius
	do Ir = 1, IrMain
	Rnd = RADIUS(Ir)/RMW(Iz)
        if(Rnd.lt.aa)then
          VND = Rnd**VORP2(Iz)
        else if(Rnd.lt.bb)then
          X = (Rnd-aa)/(bb-aa)
          Vi = Rnd**VORP2(Iz)
	  if(IsExp(Iz).and.(.not.IsLr0))then
            Vo = exp(-(Rnd-1.0)/VORP1(Iz))
          else
            Vo = (1.0 + V9(Iz))*abs((A9(Iz)-Rnd)/(A9(Iz)-1.0))**xV - 
     1                               V9(Iz)
          endif
          VND = Vo + (Vi-Vo)*weight(X)
        else if(IsExp(Iz).and.(.not.IsLr0))then
          VND = exp(-(Rnd-1.0)/VORP1(Iz))
        else if(Rnd.le.A9(Iz))then
          VND = (1.0 + V9(Iz))*abs((A9(Iz)-Rnd)/(A9(Iz)-1.0))**xV - 
     1                              V9(Iz)
        else if((Rnd.lt.cc).and.(IsLr0))then
          XX = (Rnd - A9(Iz))/(cc-A9(Iz))
          WW = weight(XX)
          Vo = (1.0 + V9(Iz))*abs((A9(Iz)-Rnd)/(A9(Iz)-1.0))**xV - 
     1                             V9(Iz)   
          if(IsExp(Iz))then
            VND = Vo*WW - (1.0-WW)*V9(Iz)*exp(-(Rnd-A9(Iz))/VORP1(Iz))
          else
            VND = Vo*WW
          endif
        else
          if(IsExp(Iz))then
            VND = -V9(Iz)*exp(-(Rnd-A9(Iz))/VORP1(Iz))
          else
            VND = 0.0
          endif
        endif
c insert Rankine or modified Rankine vortex here 
         if(IsRNK .or. IsMRnK)then
           if(RnD .lt. 1.0)then
             VND = RnD
           else
             if(IsRNK)then
               VND = 1.0/Rnd
             else
               VND = 1.0/(RnD**Alph(Iz))
             endif
           endif
         endif
c Account for varying mesh interval and max wind radius for aiming V0(RMW)
c by scaling change from RMW of 40 km and drm of 4000 m.
         Fac = 1. + 0.1*(40./RMW(Iz))*(drm/4000.)
         if(Rnd .gt. 1.0) then
  	   V0(1,Iz,Ir)=VMax(Iz)*VND
         else
  	   V0(1,Iz,Ir)=Fac*VMax(Iz)*VND
         endif
        if(.not.IsGau .and. .not.IsExp(Iz) .and. .not. IsRNK
     1     .and. .not. IsMRnK) then
c insert Ooyama's vortex here and skip filter below
         V0(1,Iz,Ir) = VMax(Iz)*2.*Rnd/(1. + Rnd*Rnd)
         IsOo = .true.
        else
c insert Gaussian vortex from Mallen and skip filter 
         sig2 = 1.58520*1.58520
         rr = Radius(Ir)/RMW(Iz)
         if(IsGau) then
           V0(1,Iz,Ir) = (1. + 1./sig2)/rr*(1. - exp(-sig2*rr*rr/2.))
           V0(1,Iz,Ir) = VMax(Iz)*V0(1,Iz,Ir)

  	   V0(2,Iz,Ir)=V0(1,Iz,Ir)
	   V0(3,Iz,Ir)=V0(1,Iz,Ir)
         endif
        endif
	enddo      !Ir
	V0(1,Iz,0) = 0.0
	V0(2,Iz,0) = 0.0
	V0(3,Iz,0) = 0.0

c Restore V0 at RMW and smooth about RMW
       if(.not.IsOo .and. .not.IsGau) then
        Ir = RMW(Iz)*1000./drm
        V0(1,Iz,Ir) = VMax(Iz)
        V0(1,Iz,Ir-1)=.25*(V0(1,Iz,Ir)+V0(1,Iz,Ir-2))+.5*V0(1,Iz,Ir-1)
       V0(1,Iz,Ir-2)=.25*(V0(1,Iz,Ir-1)+V0(1,Iz,Ir-3))+.5*V0(1,Iz,Ir-2)
       V0(1,Iz,Ir-3)=.25*(V0(1,Iz,Ir-2)+V0(1,Iz,Ir-4))+.5*V0(1,Iz,Ir-3)
        V0(1,Iz,Ir+1)=.25*(V0(1,Iz,Ir)+V0(1,Iz,Ir+2))+.5*V0(1,Iz,Ir+1)
       V0(1,Iz,Ir+2)=.25*(V0(1,Iz,Ir+1)+V0(1,Iz,Ir+3))+.5*V0(1,Iz,Ir+2)
       V0(1,Iz,Ir+3)=.25*(V0(1,Iz,Ir+2)+V0(1,Iz,Ir+4))+.5*V0(1,Iz,Ir+3)
       endif


c Insert smoothed Rankine vortex here overiding Rankine vortex above
       if(IsRNK .and. .not. IsMRnK) then
         Z0 = 2.0*VMax(Iz)/(RMW(Iz)*1000.0) 
         R0 = RMW(Iz)*1000.0         
         do Ir = 0,IrMain
           rm = RADIUS(Ir)*1000.0
           Z(Iz,Ir) = Z0/2.0*(1.0 - tanh((rm - R0)/(R0*Del(Iz))))
c        if(Ir .lt. 15)then
c         dr = rm - R0
c         htan = tanh(dr/(r0*del))
c       write(10,'('' Ir,dr,htan,Z'',I5,3e12.5)')Ir,dr,htan,z(Iz,Ir)
c
c        endif
         enddo          !Ir
         do Ir = 1,IrMain
           R = RADIUS(Ir)
           RM = RADIUS(Ir-1)
           RZ = 0.5*(R*Z(Iz,Ir) + RM*Z(Iz,Ir-1))
           V0(1,Iz,Ir) = RM/R*V0(1,Iz,Ir-1) + RZ/R*drm
c        if(Ir .lt. 15)then
c       write(10,'('' Ir,R,RM,RZ,V'',I5,4e12.5)')Ir,R,RM,RZ,V0(1,Iz,Ir)
c
c        endif
         enddo          !Ir
       endif


c Propagate V0's to other time levels
        do Ir = 1,IrMain
          V0(2,Iz,Ir) = V0(1,Iz,Ir) 
          V0(3,Iz,Ir) = V0(1,Iz,Ir) 
        enddo

c Initialize height gradaient, depth at vortex boundary, and
c sum of squares of swirling wind
	R = RADIUS(IrMain)
	GradO = V0(1,Iz,IrMain)*(V0(1,Iz,IrMain)/(1000.0*R) + FCor)
        if(Iz .eq. 2) then
	  H0(Iz,IrMain) = HSym(2) + HSym(1)
        else
	  H0(Iz,IrMain) = HSym(1)
        endif

c Loop inward over grid points to calculate mean height, assuming
c gradient balance, and sum of squares of swirling wind
	do Ir = IrMain - 1, 1, -1
	  R = RADIUS(Ir)
	  GradN = V0(1,Iz,Ir)*(V0(1,Iz,Ir)/(1000.0*R) + FCor)
          if(Iz .eq.2) then
	    H0(Iz,Ir) = H0(Iz,Ir+1) - GeeHaf*drm*(GradO + GradN)/Sig22
          else
  	    H0(Iz,Ir) = H0(Iz,Ir+1) - GeeHaf*drm*(GradO + GradN)/Sig11
     1                + (H0(2,Ir+1) - H0(2,Ir))*Sig12/Sig11
          endif
	  GradO = GradN
	enddo

c Mean-flow height at vortex center
        if(Iz .eq. 2) then
	  H0(Iz,0) = H0(Iz,1) - GeeHaf*drm*GradO/Sig22
        else
	  H0(Iz,0) = H0(Iz,1) - GeeHaf*drm*GradO/Sig11
     1               + (H0(2,1) - H0(2,0))*Sig12/Sig11
        endif

c calculate h2 from h1+h2 and h1
        if(Iz .eq. 1)then
         do Ir = 0,IrMain
          H0(2,Ir) = H0(2,Ir) - H0(1,Ir) 
         enddo
        endif
       enddo   !Iz
       return
       end

       subroutine findx(WW,XX)
       parameter(eps=0.0001)
       logical done
       done = .FALSE.
       X1=0.0
       W1 = weight(X1)
       X2=1.0
       W2 = weight(X2)
       do while (.not.done)
         X3= 0.5*(X2+X1)
         W3 = weight(X3)
         if(W3.gt.WW)then
           X1 = X3
           W1 = W3
         else
           X2 = X3
           W2 = W3
         endif
         XX=X3
         done = abs(X1-X2).lt.eps
         write(6,'(4(2x,f8.3))')X1,W1,X2,W2
       enddo
       return       
       end

       function weight(X)
         weight = 1.0 - (10.0 - (15.0 - 6.0*X)*X)*X*X*X
       return
       end



	function RADIUS(Ir)
!---------------------------------------------------------------!
!	Returns radial coordinate, given radial index		!
!---------------------------------------------------------------!
 	common /DMAIN/dR
	RADIUS = dR * Real(Ir)
	return
	end
	
	subroutine TrakX(XRay,TIMEh,IsDyMo,Ijts0,Ijts)
!-----------------------------------------------------------------------!
!  If IsDyMo is TRUE, extrapolates the past track one major time step	!
!  into the fututre using linear extrapolation based upon the last two  !
!  corrected center positions; else evaluates the prespecified trak	!
!  function to get next center position					!
!-----------------------------------------------------------------------!
	parameter (IzMx=2,NX=2)
	common /TEMP0/TIMEh0,dth
	real*4 XRay(IzMx,2,0:NX)
	logical IsDyMo
	TIMEh = TIMEh0 + dth*float(Ijts - Ijts0)

c Dynamic centering active?
	if(IsDyMo)then

c Loop over x and y directions
	  do J = 1, 2

c Move positions back one location
	    XRay(1,J,0) = XRay(1,J,1)
	    XRay(1,J,1) = XRay(1,J,2)
	    XRay(2,J,0) = XRay(2,J,1)
	    XRay(2,J,1) = XRay(2,J,2)

c Extrapolate next position linearly
	    XRay(1,J,2) = 2.0*XRay(1,J,1) - XRay(1,J,0)
	    XRay(2,J,2) = 2.0*XRay(2,J,1) - XRay(2,J,0)
c            XRay(1,J,2) = XRay(1,J,1)
c           write(6,'('' TRAKX: '',I2,4g13.6)')J,(XRay(1,J,k),k=0,2)
	  enddo
 	endif 
	return
	end

	subroutine MakXC(IsAve,XRay,XCen,CCenL,CCenR)
!-----------------------------------------------------------------------!
!  Evaluates center position and speed at each minor time step by 	!
!  interpolation between the last corrected center and the extrapolated !
!  center at the end of the major time step				!
!-----------------------------------------------------------------------!
	common /LONGS/dtjMs,dtjMs2
	parameter (IzMx=2,NX=2,NMode=3)
	real*4 XRay(IzMx,2,0:NX),XCen(IzMx,2)
 	complex CCenR(NMode,IzMx),CCenL(NMode,IzMx),eye
 	parameter (eye=(0.0,1.0))
        logical IsAve

        if (IsAve)then
c Extrapolate x center position to  middle of major time step
	  XCen(1,1) = 0.5*(XRay(1,1,NX)+XRay(1,1,NX-1))
	  XCen(2,1) = 0.5*(XRay(2,1,NX)+XRay(2,1,NX-1))

c Extrapolate y center position to  middle of major time step
	  XCen(1,2) = 0.5*(XRay(1,2,NX)+XRay(1,2,NX-1))
	  XCen(2,2) = 0.5*(XRay(2,2,NX)+XRay(2,2,NX-1))
        else 
c Extrapolate x center position to end of major time step
	  XCen(1,1) = XRay(1,1,NX)
	  XCen(2,1) = XRay(2,1,NX)

c Extrapolate y center position to end of major time step
	  XCen(1,2) = XRay(1,2,NX)
	  XCen(2,2) = XRay(2,2,NX)
        endif

c Calculate speed in m/s

	CCenL(1,1) = -1000.0*CMPLX(XRay(1,1,NX)-XRay(1,1,NX-1),
     1          XRay(1,2,NX)-XRay(1,2,NX-1))/DTJMS
        CCenR(1,1) = eye*CCenL(1,1)
	CCenL(1,2) = -1000.0*CMPLX(XRay(2,1,NX)-XRay(2,1,NX-1),
     1          XRay(2,2,NX)-XRay(2,2,NX-1))/DTJMS
        CCenR(1,2) = eye*CCenL(1,2)

c Zero WN>1 part of vortex motion
        do N = 2, NMode
          CCenL(N,1) = (0.0,0.0)
          CCenR(N,1) = (0.0,0.0)
          CCenL(N,2) = (0.0,0.0)
          CCenR(N,2) = (0.0,0.0)
        enddo

        return
        end

	subroutine Fish1(UA,VA,I3,YA,Ijts,NSho,TIMEh)
!-----------------------------------------------------------------------!
!  Lindzen-Kuo solver. Yields wavenumber-one streamfunction by solving  !
!  the Poisson equation del-squared Psi = vorticity. Outward loop makes !
!  ALPHA and BETA such that Y(...,Ir)= ALPHA*Y(...,Ir+1)+BETA. Inward	!
!  loop substitutes Ys succsessively starting with the value determined !
!  at the outer boundary.						!
!-----------------------------------------------------------------------!
	complex*8 eye
	parameter(IzMx=2,IrMain=1001,IrVor=125,eye=(0.0,1.0))
	parameter(IrVorM=Irvor-1,IrVorP=IrVor+1,NMode=3)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1            YA(IzMx,0:IrVor),
     1            ALPHA(0:IrVor),BETA(0:IrVor),VOR,den,VBar
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	COMMON /MaxiMum/UVMax(NMode,IzMx),HMax(NMode,IzMx),YMax(IzMx),
     1         FlxLrMx(0:NMode,IzMx),FLxEMx(0:NMode,IzMx),
     2         FlxLrMn(0:NMode,IzMx),FLxEMn(0:NMode,IzMx),
     3         EWavMx(0:NMode,IzMx),C2,C2d,C2t,
     4         ALrMx(IzMx),ALrMn(IzMx),BMotMx(IzMx),BMotMn(IzMx)

c Loop over layers
       do Iz = 1,IzMx
	ALPHA(0)=(0.0,0.0)
	BETA(0) =(0.0,0.0)

c Outward loop
	do Ir = 1, IrVor
	  rm = RADIUS(Ir)

c Make vorticity
	  if (Ir.LE.2)then
	    VOR = (0.0,0.0)
	  else
    	    VOR = (VA(1,I3,Iz,Ir+1) - VA(1,I3,Iz,Ir-1))/twodrm + 
     1            (VA(1,I3,Iz,Ir)+eye*UA(1,I3,Iz,Ir))/rm
	  endif

c Make ALPHA and BETA
	  den = -(1.0/(rm*rm)+2.0/drm2) + 
     1          ALPHA(Ir-1)*(1.0/drm2-1.0/(rm*twodrm))
	  ALPHA(Ir) = -(1.0/drm2+1.0/(rm*twodrm))/den
	  BETA(Ir)  = (VOR - BETA(Ir-1)*
     1                 (1.0/drm2-1.0/(rm*twodrm)))/den
	enddo

c Find streamfunction at outer boundary by equating swirling 
c wind to gradient of streamfunction, knowing ALPHA and BETA
c at the boundary point.

c Calculate swirling wind between boundary and first point outside
	VBar=0.5*(VA(1,I3,Iz,IrVor)+VA(1,I3,Iz,IrVorP))

c Calculate streamfuncion at boundary point
	YA(Iz,IrVor)=(ALPHA(IrVor)*VBAR*drm + BETA(IrVor))/
     1                  (1.0 - ALPHA(IrVor))

c Loop in toward center, doing back substitution
	do Ir = IrVorM, 0, -1
	  YA(Iz,Ir) = ALPHA(Ir)*YA(Iz,Ir+1) + BETA(Ir)
	enddo
        if(mod(Ijts,NSho).eq.0)then
          do Ir = 0, IrVorM
            YMax(Iz) = amax1(YMax(Iz),cabs(YA(Iz,Ir)))
          enddo
        endif
       enddo    !Iz loop
      return
      end


	subroutine ShoDiag(NLU,YA,Ijts,NSho,TIMEh)
!-----------------------------------------------------------------------!
! Writes the wavenumber-one streamfunction used to find the center on	!
! the file identified by NLU. Retains maximum of streamfunction		!
!-----------------------------------------------------------------------!
	parameter(IzMx=2,IrVor=125,NMode=3)
	complex*8 YA(IzMx,0:IrVor)
	COMMON /MaxiMum/UVMax(NMode,IzMx),HMax(NMode,IzMx),YMax(IzMx),
     1         FlxLrMx(0:NMode,IzMx),FLxEMx(0:NMode,IzMx),
     2         FlxLrMn(0:NMode,IzMx),FLxEMn(0:NMode,IzMx),
     3         EWavMx(0:NMode,IzMx),C2,C2d,C2t,
     4         ALrMx(IzMx),ALrMn(IzMx),BMotMx(IzMx),BMotMn(IzMx)
	if( mod(Ijts,NSho).eq.0)then
          call OpenOut(NLU,'VORT ',.TRUE.)
	  call ShoFlag(NLU)
	  write(NLU,'('' Time = '',f8.3)')TIMEh
	  write(NLU,'('' Streamfunction: '')')
          do Iz = 1,IzMx
	  do Ir = 0, IrVor
	    Rkm = 0.001*RADIUS(Ir)
            write(NLU,21)Ir,Rkm,YA(Iz,Ir)
	  enddo
          enddo
          close(NLU)
	endif
 21     format(1x,I4,1x,f6.0,2(1x,g14.7))
	return
	end

	subroutine FindCen(YA,V0,IS3,AlfaCen,DXCen)
!-----------------------------------------------------------------------!
!  Determines alpha, the complex representation of the centering error, !
!  by a least-squares fit of the alpha-gyre streamfunction to the	!
!  perturbation wavenumber-one streamfunction from fish1		!
!-----------------------------------------------------------------------!
	complex*8 eye
	parameter(IzMx=2,IrMain=1001,IrVor=125,eye=(0.0,1.0))
	real*4 V0(3,IzMx,0:IrMain),DXCen(IzMx,2)
	real*8 SV02,SR02,SVR
	complex*8 YA(IzMx,0:IrVor),AlfaCen(IzMx)
	complex*16 SVY,SYR

c Loop over layers
       do Iz = 1,IzMx

c Initialize summed product of swirling wind with wn1 streamfunction
        SVY = (0.0,0.0)
        SYR = (0.0,0.0)
        SV02 = 0.0
        SR02 = 0.0
        SVR  = 0.0 
c Loop inward summing the product at each grid point
        do Ir = IrVor, 1, -1
          R = RADIUS(Ir)
          weight = WGT(Iz,Ir)
          SVY  = SVY  + weight*V0(IS3,Iz,Ir)*YA(Iz,Ir)
          SYR  = SYR  + weight*YA(Iz,Ir)*R
          SV02 = SV02 + weight*V0(IS3,Iz,Ir)**2
          SVR  = SVR  + weight*V0(IS3,Iz,Ir)*R
          SR02 = SR02 + weight*R*R
        enddo


c Calculate complex centering error in meters
	AlfaCen(Iz) =eye*(SVY*SR02-SYR*SVR)/(SVR*SVR-SV02*SR02)
C	AlfaCen(Iz) =-eye*SVY/SV02

c Express error as x and y components in kilometers
	DXCen(Iz,1) =  0.001*real(AlfaCen(Iz))
	DXCen(Iz,2) =  0.001*aimag(AlfaCen(Iz))
       enddo      !Iz
       return
       end

	subroutine FixVor(UA,VA,HA,I1,I2,I3,IS3,AlfaCen,U0,V0,H0,Cgr
     1                   ,FCor,IsDyMo,IsNL)
!-----------------------------------------------------------------------!
!  Corrects the perturbation fields for removal of the centering error  !
!-----------------------------------------------------------------------!
	complex*8 eye
        parameter(GeeI=1.0/9.8)
	parameter(IzMx=2,IrMain=1001,IrVor=125,eye=(0.0,1.0),NMode=3)
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         XCen(IzMx),Cgr(IzMx)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1            US(NMode,0:IrMain),VS(NMode,0:IrMain),
     2            HA(NMode,3,IzMx,0:IrMain),HS(NMode,0:IrMain),
     3            AlfaCen(IzMx),AL,ALI,CAL,CALI,
     4            UFix(NMode,3),VFix(NMode,3),HFix(NMode,3),
     5            AL2,AL2I,AL3,AL3I
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /TEMP0/TIMEh0,dth
	logical IsDyMo,IsNL
        integer IRay(3)

c Correct only if dynamic centering is on
	if (IsDyMo)then

c Put leap-frog time levels in an array
          IRay(1)=I1
          IRay(2)=I2
          IRay(3)=I3

c Loop over time levels
          do It = 1,3
            IN = IRay(It)
c
c set alpha to displace upper vortex relative to lower vortex
           AL = -AlfaCen(2)
           ALI=AL*eye
           CAL = conjg(AL)
           CALI = conjg(ALI)
c
c Loop over upper layer to add alpha gyre for displaced vortex
           do Iz = 2,IzMx

c Store UA,VA,HA for right side computes below
            do N = 1,NMode
            do Ir = 0,IrMain
              US(N,Ir) = UA(N,IN,Iz,Ir)
              VS(N,Ir) = VA(N,IN,Iz,Ir)
              HS(N,Ir) = HA(N,IN,Iz,Ir)
            enddo
            enddo
c
c Loop over radial grid points to add alpha gyre to upper layer
	    do Ir = 1,IrMain - 1
              rm = RADIUS(Ir)
              rmi = 1.0/rm
              rmi2 = rmi*rmi
             If(IsNL) then
              UA(1,IN,Iz,Ir) = UA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(US(2,Ir+1) - US(2,Ir-1))/twodrm
     2        + CAL*(-2.0*eye*US(2,Ir) - VS(2,Ir))*rmi)
              VA(1,IN,Iz,Ir) = VA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(VS(2,Ir+1) - VS(2,Ir-1))/twodrm  
     2        + CAL*(-2.0*EYE*VS(2,Ir) + US(2,Ir))*rmi)
              HA(1,IN,Iz,Ir) = HA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(HS(2,Ir+1) - HS(2,Ir-1))/twodrm
     2        + CAL*2.0*eye*HS(2,Ir)*rmi)

              do N = 2,NMode-1
                fNP = N+1
                fNM = N-1
                UA(N,IN,Iz,Ir) = UA(N,IN,Iz,Ir) - 0.5*(
     1            CALI*(US(N+1,Ir+1) - US(N+1,Ir-1))/twodrm 
     2          + CAL*(-fNP*eye*US(N+1,Ir) - VS(N+1,Ir))*rmi
     3          + ALI*(US(N-1,Ir+1) - US(N-1,Ir-1))/twodrm
     4          + AL*(-fNM*eye*US(N-1,Ir) - VS(N-1,Ir))*rmi)
                VA(N,IN,Iz,Ir) = VA(N,IN,Iz,Ir) -0.5*(
     1            CALI*(VS(N+1,Ir+1) - VS(N+1,Ir-1))/twodrm
     2          + CAL*(-fNP*eye*VS(N+1,Ir) + US(N+1,Ir))*rmi
     3          + ALI*(VS(N-1,Ir+1) - VS(N-1,Ir-1))/twodrm
     4          + AL*(-fNM*eye*VS(N-1,Ir) + US(N-1,Ir))*rmi)
                HA(N,IN,Iz,Ir) = HA(N,IN,Iz,Ir) - 0.5*(
     1            CALI*(HS(N+1,Ir+1) - HS(N+1,Ir-1))/twodrm
     2          - CAL*fNP*eye*HS(N+1,Ir)*rmi
     3          + ALI*(HS(N-1,Ir+1) - HS(N-1,Ir-1))/twodrm
     4          - AL*fNM*eye*HS(N-1,Ir)*rmi)
              enddo

              fNM = NMode-1
              UA(NMode,IN,Iz,Ir) = UA(NMode,IN,Iz,Ir) -0.5*(
     1          ALI*(US(NMode-1,Ir+1) - US(NMode-1,Ir-1))/twodrm
     2        + AL*(-fNM*eye*US(NMode-1,Ir) - VS(NMode-1,Ir))*rmi)
              VA(NMode,IN,Iz,Ir) = VA(NMode,IN,Iz,Ir) - 0.5*(
     1          ALI*(VS(NMode-1,Ir+1) - VS(NMode-1,Ir-1))/twodrm
     2        + AL*(-fNM*eye*VS(NMode-1,Ir) + US(NMode-1,Ir))*rmi)
              HA(NMode,IN,Iz,Ir) = HA(NMode,IN,Iz,Ir) - 0.5*(
     1          ALI*(HS(NMode-1,Ir+1) - HS(NMode-1,Ir-1))/twodrm
     2        - AL*fNM*eye*HS(NMode-1,Ir)*rmi)    
             
             endif

c              dH0dr=V0(IS3,Iz,Ir)*(V0(IS3,Iz,Ir)/rm + FCor)*GeeI
              dH0dr=(H0(Iz,Ir+1)-H0(Iz,Ir-1))/twodrm
	      UA(1,IN,Iz,Ir) = UA(1,IN,Iz,Ir) - ALI*(U0(Iz,Ir+1)
     1                     -U0(Iz,Ir-1))/twodrm + AL*V0(IS3,Iz,Ir)*rmi
	      VA(1,IN,Iz,Ir) = VA(1,IN,Iz,Ir) - AL*U0(Iz,Ir)*rmi
     1                     -ALI*(V0(IS3,Iz,Ir+1)-V0(IS3,Iz,Ir-1))/twodrm
	      HA(1,IN,Iz,Ir) = HA(1,IN,Iz,Ir) - dH0dr*ALI
            enddo ! Ir
           enddo  ! Iz
           N = 1
           Call DoBCH(HA,IN,IN,N,Cgr)
           Call DoBCUV(UA,VA,IN,IN,N,Cgr)
          enddo   ! It
        endif     ! IsDyMo
	return
	end
	subroutine FixSol(UA,VA,HA,I1,I2,I3,IS3,AlfaCen,U0,V0,H0
     1                   ,FCor,IsDyMo,IsNL)
!-----------------------------------------------------------------------!
!  Corrects the perturbation fields for removal of the centering error  !
!-----------------------------------------------------------------------!
	complex*8 eye
        parameter(GeeI=1.0/9.8)
	parameter(IzMx=2,IrMain=1001,IrVor=125,eye=(0.0,1.0),NMode=3)
	real*4 U0(IzMx,0:IrMain),V0(3,IzMx,0:IrMain),H0(IzMx,0:IrMain),
     1         XCen(IzMx)
	complex*8 UA(NMode,3,IzMx,0:IrMain),VA(NMode,3,IzMx,0:IrMain),
     1            US(NMode,0:IrMain),VS(NMode,0:IrMain),
     2            HA(NMode,3,IzMx,0:IrMain),HS(NMode,0:IrMain),
     3            AlfaCen(IzMx),AL,ALI,CAL,CALI,
     4            UFix(NMode,3),VFix(NMode,3),HFix(NMode,3),
     5            AL2,AL2I,AL3,AL3I
	common /DELTA/drm,twodrm,drm2,dts,twodts,Nnts
	common /TEMP0/TIMEh0,dth
	logical IsDyMo,IsNL
        integer IRay(3)

c Correct only if dynamic centering is on
	if (IsDyMo)then

c Put leap-frog time levels in an array
          IRay(1)=I1
          IRay(2)=I2
          IRay(3)=I3

c Loop over time levels
          do It = 1,3
            IN = IRay(It)
c
c Interpolate centering error to each time level
           AL = AlfaCen(1)*float(Nnts-3+It)/float(Nnts)
c           AL = AlfaCen(1)
           ALI=AL*eye
           CAL = conjg(AL)
           CALI = conjg(ALI)
c
c Loop over layers
           do Iz = 1,IzMx

c Store UA,VA,HA for right side computes below
            do N = 1,NMode
            do Ir = 0,IrMain
              US(N,Ir) = UA(N,IN,Iz,Ir)
              VS(N,Ir) = VA(N,IN,Iz,Ir)
              HS(N,Ir) = HA(N,IN,Iz,Ir)
            enddo
            enddo
c
c Loop over radial grid points and correct perturbations
	    do Ir = 1,IrMain - 1
              rm = RADIUS(Ir)
              rmi = 1.0/rm
              rmi2 = rmi*rmi
             If(IsNL) then
              UA(1,IN,Iz,Ir) = UA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(US(2,Ir+1) - US(2,Ir-1))/twodrm
     2        + CAL*(-2.0*eye*US(2,Ir) - VS(2,Ir))*rmi)
              VA(1,IN,Iz,Ir) = VA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(VS(2,Ir+1) - VS(2,Ir-1))/twodrm  
     2        + CAL*(-2.0*EYE*VS(2,Ir) + US(2,Ir))*rmi)
              HA(1,IN,Iz,Ir) = HA(1,IN,Iz,Ir) - 0.5*(
     1          CALI*(HS(2,Ir+1) - HS(2,Ir-1))/twodrm
     2        + CAL*2.0*eye*HS(2,Ir)*rmi)

              do N = 2,NMode-1
                fNP = N+1
                fNM = N-1
                UA(N,IN,Iz,Ir) = UA(N,IN,Iz,Ir) - 0.5*(
     1            CALI*(US(N+1,Ir+1) - US(N+1,Ir-1))/twodrm 
     2          + CAL*(-fNP*eye*US(N+1,Ir) - VS(N+1,Ir))*rmi
     3          + ALI*(US(N-1,Ir+1) - US(N-1,Ir-1))/twodrm
     4          + AL*(-fNM*eye*US(N-1,Ir) - VS(N-1,Ir))*rmi)
                VA(N,IN,Iz,Ir) = VA(N,IN,Iz,Ir) -0.5*(
     1            CALI*(VS(N+1,Ir+1) - VS(N+1,Ir-1))/twodrm
     2          + CAL*(-fNP*eye*VS(N+1,Ir) + US(N+1,Ir))*rmi
     3          + ALI*(VS(N-1,Ir+1) - VS(N-1,Ir-1))/twodrm
     4          + AL*(-fNM*eye*VS(N-1,Ir) + US(N-1,Ir))*rmi)
                HA(N,IN,Iz,Ir) = HA(N,IN,Iz,Ir) - 0.5*(
     1            CALI*(HS(N+1,Ir+1) - HS(N+1,Ir-1))/twodrm
     2          - CAL*fNP*eye*HS(N+1,Ir)*rmi
     3          + ALI*(HS(N-1,Ir+1) - HS(N-1,Ir-1))/twodrm
     4          - AL*fNM*eye*HS(N-1,Ir)*rmi)
              enddo

              fNM = NMode-1
              UA(NMode,IN,Iz,Ir) = UA(NMode,IN,Iz,Ir) -0.5*(
     1          ALI*(US(NMode-1,Ir+1) - US(NMode-1,Ir-1))/twodrm
     2        + AL*(-fNM*eye*US(NMode-1,Ir) - VS(NMode-1,Ir))*rmi)
              VA(NMode,IN,Iz,Ir) = VA(NMode,IN,Iz,Ir) - 0.5*(
     1          ALI*(VS(NMode-1,Ir+1) - VS(NMode-1,Ir-1))/twodrm
     2        + AL*(-fNM*eye*VS(NMode-1,Ir) + US(NMode-1,Ir))*rmi)
              HA(NMode,IN,Iz,Ir) = HA(NMode,IN,Iz,Ir) - 0.5*(
     1          ALI*(HS(NMode-1,Ir+1) - HS(NMode-1,Ir-1))/twodrm
     2        - AL*fNM*eye*HS(NMode-1,Ir)*rmi)    
             
             endif

c              dH0dr=V0(IS3,Iz,Ir)*(V0(IS3,Iz,Ir)/rm + FCor)*GeeI
              dH0dr=(H0(Iz,Ir+1)-H0(Iz,Ir-1))/twodrm
	      UA(1,IN,Iz,Ir) = UA(1,IN,Iz,Ir) - ALI*(U0(Iz,Ir+1)
     1                     -U0(Iz,Ir-1))/twodrm + AL*V0(IS3,Iz,Ir)*rmi
	      VA(1,IN,Iz,Ir) = VA(1,IN,Iz,Ir) - AL*U0(Iz,Ir)*rmi
     1                     -ALI*(V0(IS3,Iz,Ir+1)-V0(IS3,Iz,Ir-1))/twodrm
	      HA(1,IN,Iz,Ir) = HA(1,IN,Iz,Ir) - dH0dr*ALI
            enddo ! Ir
           enddo  ! Iz
          enddo   ! It
        endif     ! IsDyMo
	return
	end

	subroutine NewTrak(XRay,DXCen,XCen,IsDyMo)
!-----------------------------------------------------------------------!
!  Adds centering error  to current center position. Other bookkeeping  !
!  for track extrapolation happens in TrakX				!
!-----------------------------------------------------------------------!
	parameter (IzMx=2,NX=2)
        real*4 XRay(IzMx,2,0:NX),DXCen(IzMx,2),XCen(IzMx,2)
	logical IsDyMo

c Correct only if dynamic centering is active
	if(IsDyMo)then

c Correct x position, set vortex pos to end of major time step
	  XRay(2,1,NX) = XRay(1,1,NX) + DXCen(2,1)
	  XRay(1,1,NX) = XRay(1,1,NX) + DXCen(1,1)
          XCen(1,1)=XRay(1,1,NX)
          XCen(2,1)=XRay(2,1,NX)

c Correct y position, set vortex pos to end of major time step
	  XRay(2,2,NX) = XRay(1,2,NX) + DXCen(2,2)
	  XRay(1,2,NX) = XRay(1,2,NX) + DXCen(1,2)
          XCen(1,2)=XRay(1,2,NX)
          XCen(2,2)=XRay(2,2,NX)

	endif
	return
	end

	function WGT(Iz,Ir)
!-----------------------------------------------------------!
! Weighting function to increase the role of the stream-    !
! function near the vortex center in correcting the center  !
! position. Uses Witch of Agnesi function. Weight = 0.5    !
! at Ir = INT(A), 0.2 at Ir=INT(2*A), and 0.1 at Ir=INT(3A) !
!-----------------------------------------------------------!
	parameter (A=20.0)
        A2 = A*A
	WGT = A2/(float(Ir)**2+A2)
	return
	end

	subroutine FINIS(ILU,XCen,CCenL)
!-----------------------------------------------------------!
! Writes maximum wind, depth and streamfunction encountered !
! during the calculation at the bottom of "AJAX.log"        !
!-----------------------------------------------------------!
        parameter (IzMx=2,NMode=3)
        real XCen(IzMx,2)
        complex*8 CCenL(NMode,IzMx)
	COMMON /MaxiMum/UVMax(NMode,IzMx),HMax(NMode,IzMx),YMax(IzMx),
     1         FlxLrMx(0:NMode,IzMx),FLxEMx(0:NMode,IzMx),
     2         FlxLrMn(0:NMode,IzMx),FLxEMn(0:NMode,IzMx),
     3         EWavMx(0:NMode,IzMx),C2,C2d,C2t,
     4         ALrMx(IzMx),ALrMn(IzMx),BMotMx(IzMx),BMotMn(IzMx)
        COMMON /STAMP/ FDATE,FTIME,IDString,IDif
        CHARACTER FDATE*9,FTIME*8,IDString*20,IDif*6

c Print Maximum separation of upper vortex from lower
          write(ILU,'('' Maximum Upper Center Displacement: '',f9.2,
     1         '' Km at '',f6.1,'' Deg at '',f8.3,'' Hr'')')C2,C2d,C2t

          write(ILU,'('' End Track & Speed L1 X,Y:'',2(f10.2),'' Km'',
     1              2(f10.5),'' M/S'')')XCen(1,1),XCen(1,2),-CCenL(1,1)
          write(ILU,'('' End Track & Speed L2 X,Y:'',2(f10.2),'' Km'',
     1              2(f10.5),'' M/S'')')XCen(2,1),XCen(2,2),-CCenL(1,2)

c Print max/min U,V,H energy, angular momemtum and fluxes on new page
       if(ILU .eq. 6) then
         write(ILU,'('' Max-Min U,V,H, Energy  Lr, and Fluxes'')')
       else
         write(ILU,'(''1 Max-Min U,V,H, Energy  Lr, and Fluxes For:'',
     1                 5x,A8,1x,A9,1x,A6)')FTIME,FDATE,IDif
       endif
       do Iz = 1,IzMx
        write(ILU,'('' Data For Layer '',I2)')Iz
        do N = 1,NMode 
	write(ILU,'('' Maximum U('',2(I2),'') or V('',2(I2),''): ''
     1               ,g13.6)')N,Iz,N,Iz,UVMax(N,Iz)
	write(ILU,'('' Maximum H('',2(I2),''):'',g13.6)')N,Iz,HMax(N,Iz)
        enddo
	write(ILU,'('' Maximum Streamfunction: Layer'',I2,g13.6)')Iz,
     1                 YMax(Iz)
        write(ILU,'('' Max & min Lr: Layer'',I2,2(1x,g13.6))')Iz,
     1                 ALrMx(Iz),ALrMn(Iz)
        write(ILU,'('' Max & min beta*Cy: Layer'',I2,2(1x,g13.6))')Iz,
     1                 BMotMx(Iz),BMotMn(Iz)
!23456789012345678901234567890123456789012345678901234567890123456789012
!        1         2         3         4         5         6         7
        do N = 0, NMode
         write(ILU,'('' Wavenumber: '',I2)')N
         write(ILU,'('' Max wave energy: Layer'',I2,1x,g13.6)')
     1                   Iz,EWavMx(N,Iz)
         write(ILU,'('' Max & min energy flux: Layer'',I2,2(1x,g13.6))')
     1                   Iz,FlxEMx(N,Iz),FlxEMn(N,Iz)
         write(ILU,'('' Max & min Lr flux: Layer'',I2,2(1x,g13.6))')
     1                   Iz,FlxLrMx(N,Iz),FlxLrMn(N,Iz)
        enddo
       enddo     !Iz
       return
       end

      subroutine GetRun
      common /RUDID/RunID,FloID
      character RunID*10,FloID*10
      open(11,access='SEQUENTIAL',form='FORMATTED',
     1     status='OLD',err=98,iostat=IERR,
     2     file='al0:[hrd.rjones.troy]temp.dat')
      read(11,*,err=99)RunID,FLoID
      close(11)
      return
 98   write(6,'('' Error in opening runstring file'')')
      write(6,'('' IO status = '',I3)')IERR
      stop 
 99   write(6,'('' Error in recovering run specification. '')')
      stop 
      end


      subroutine OpenOut(ILU,FuncID,IsApp)
      common /RUDID/RunID,FloID
      character RunID*10,FloID*10,FuncID*10,OutName*50
      logical IsApp
      IDXF = EndDex(FuncID)
      IDXR = EndDex(RunID)
      OutName = 'al0:[hrd.rjones.troy]'// 
     1     FuncID(:IDXF)//RunID(:IDXR)//'.OUT'
      if (IsApp)then
        open(ILU,access='APPEND',form='FORMATTED',
     1     status='OLD',err=99,iostat=IOS,file=OutName)
      else
        open(ILU,access='SEQUENTIAL',form='FORMATTED',
     1     status='NEW',err=99,iostat=IOS,file=OutName)
        call ShoFlag(ILU)
      endif
      return
 99   write(6,'('' Error in opening '',A45)')OutName
      write(6,'('' IO status = '',I3)')IOS
      stop
      end

      subroutine OpenEnv
      common /RUDID/RunID,FloID
      character RunID*10,FloID*10,ENvName*50
      IDXF = EndDex(FloID)
      IDXR = EndDex(RunID)
      EnvName = 'al0:[hrd.rjones.troy]'//
     1     FloID(:IDXF)//'.DAT'
      open(4,access='SEQUENTIAL',form='FORMATTED',
     1     status='OLD',err=99,iostat=IOS,file=EnvName)
      return
 99   write(6,'('' Error in opening '',A45)')EnvName
      write(6,'('' IO status = '',I3)')IOS
      stop
      end

      subroutine OpenUVH(IsFirst,IsRead)
      common /RUDID/RunID,FloID
      character RunID*10,FloID*10,UVHName*50,BUFF*6,
     1   AccMode*10,StatMode*3
      logical IsFirst,IsRead,IsNew
      parameter (NMode=3)
      IsNew = (.not.IsRead).and.IsFirst
      IDXR = EndDex(RunID)
      if (IsNew)then
        AccMode='SEQUENTIAL'
        StatMode = 'NEW'
      else
        AccMode='APPEND    '
        StatMode = 'OLD'
      endif
      do N = 0,NMode
        ILU = 30 + N
        write(BUFF,'(i2,''.OUT'')')ILU
        UVHName = 'al0:[hrd.rjones.troy]UVH'
     1       //RunID(:IDXR)//BUFF
        open(ILU,access=AccMode,form='FORMATTED',
     1     status=StatMode,err=99,iostat=IOS,file=UVHName)
      enddo
      if(IsNew)call CloseUVH
      return
 99   write(6,'('' Error in opening '',A30)')UVHName
      write(6,'('' IO status = '',I3)')IOS
      stop
      end

      subroutine CloseUVH
      parameter(NMode=3)
      do N = 0,NMode
        ILU = 30 + N
        close(ILU)
      enddo
      return
      end

      function EndDex(IDString)
      character IDString*10
      IDX = index(IDString,' ')
      if (IDX.eq.0)then
        EndDex = 10
      else
        EndDex = IDX - 1
      endif
      return
      end

